import {
  ACCOUNT_LIST_API,
  CREATE_ORDER_API,
  ORDER_TYPE_LIST_API,
  STORE_LIST_API,
  USER_LIST_API,
} from "config/constant";
import { IStoreList, ICreateOrder } from "interfaces/APIInterface/ICreateOrder";
import { readUserId } from "./localStorage.service";
import { httpApi } from "api/http.api";

export const getUserList = (store: string, searchTerm: string, accountId: string) => {
  const userFilter: string =
    accountId == "" || accountId == undefined || accountId == "0"
      ? "UserName|PhoneNumber~sw~" + searchTerm + "," + "PortalId~eq~" + store
      : "UserName|PhoneNumber~sw~" +
        searchTerm +
        "," +
        "PortalId~eq~" +
        store +
        "," +
        "AccountId~eq~" +
        accountId;

  return httpApi
    .get(USER_LIST_API + "/" + readUserId(), {
      params: {
        filter: userFilter,
      },
    })
    .then((response) => response)
    .catch((error) => {
      throw error;
    });
};

export const getStoreList = (typeaheadRequestPayload: IStoreList) => {
  return httpApi
    .post(STORE_LIST_API, typeaheadRequestPayload)
    .then((response) => response)
    .catch((error) => {
      throw error;
    });
};

export const getAccountList = (store: string, accountId: string) => {
  const accountFilter: string =
    accountId == "" || accountId == undefined || accountId == "0"
      ? "PortalId~eq~" + store
      : "PortalId~eq~" + store + "," + "AccountId~eq~" + accountId;

  return httpApi
    .get(ACCOUNT_LIST_API, {
      params: {
        filter: accountFilter,
      },
    })
    .then((response) => response)
    .catch((error) => {
      throw error;
    });
};

export const getOrderTypeList = () => {
  return httpApi
    .get(ORDER_TYPE_LIST_API)
    .then((response) => response)
    .catch((error) => {
      throw error;
    });
};

export const createOrder = (createOrderPayload: ICreateOrder) => {
  return httpApi
    .post(CREATE_ORDER_API, createOrderPayload)
    .then((response) => response)
    .catch((error) => {
      throw error;
    });
};
