/* eslint-disable max-lines */
/* eslint-disable max-len */
import { httpApi } from "api/http.api";
import {
  DELETE_ORDER_FLAG_API,
  DELETE_ORDER_USER_GROUP_API,
  GET_ORDER_API,
  ORDER_STATUS_LIST_API,
  UPDATE_ORDER_FLAG_API,
  UPDATE_ORDER_OWNER_API,
  UPDATE_ORDER_API,
  UNASSOCIATED_ORDER_FLAG_API,
  ADD_ORDER_FLAG_API,
  GET_ORDER_STATUS_BY_ID_API,
  GET_ORDER_STATUS_BUTTON_LIST_API,
  UPDATE_ORDER_STATUS_API,
  GET_ORDER_CLASS_BUTTON_LIST_API,
  GET_BUTTON_DETAIL_BY_ID_API,
} from "config/constant";
import {
  ICompleteOrder,
  IIsPriceResetProductList,
  IProductList,
  IUpdateOrder,
} from "interfaces/ClientInterface/IEditOrder";
import { IAddUpdateOrderFlag } from "interfaces/ClientInterface/IOrderFlag";
import { IAssignUnassign } from "interfaces/APIInterface/IAssignTo";
import { IFollowUnfollow } from "interfaces/APIInterface/IFollowUnfollow";

export const getOrder = (orderId: string | undefined) => {
  return httpApi
    .get(GET_ORDER_API + "/" + orderId)
    .then((response) => response.data)
    .catch((error) => {
      throw error;
    });
};

export const getOrderStatus = () => {
  return httpApi
    .get(ORDER_STATUS_LIST_API + "/Orders")
    .then((response) => response.data)
    .catch((error) => {
      throw error;
    });
};

export const updateOrderFlag = (updateOrderFlagPayload: IAddUpdateOrderFlag) => {
  return httpApi
    .post(UPDATE_ORDER_FLAG_API, updateOrderFlagPayload)
    .then((response) => response.data)
    .catch((error) => {
      throw error;
    });
};

export const deleteOrderFlag = (orderFlagId: string | undefined) => {
  return httpApi
    .post(DELETE_ORDER_FLAG_API + "/" + orderFlagId)
    .then((response) => response.data)
    .catch((error) => {
      throw error;
    });
};

export const deleteOrderUserGroup = (orderUserGroupId: string | undefined) => {
  return httpApi
    .post(DELETE_ORDER_USER_GROUP_API + "/" + orderUserGroupId)
    .then((response) => response.data)
    .catch((error) => {
      throw error;
    });
};

export const updateOrderOwner = (updateOrderPayload: IAssignUnassign) => {
  return httpApi
    .post(UPDATE_ORDER_OWNER_API, updateOrderPayload)
    .then((response) => response.data)
    .catch((error) => {
      throw error;
    });
};

export const updateOrder = (updateOrderPayload: IUpdateOrder) => {
  return httpApi
    .post(UPDATE_ORDER_API, updateOrderPayload)
    .then((response) => response)
    .catch((error) => {
      throw error;
    });
};

export const updateOrderStatusByOrderId = (updateOrderPayload: IUpdateOrder) => {
  return httpApi
    .post(UPDATE_ORDER_STATUS_API, updateOrderPayload)
    .then((response) => response.data)
    .catch((error) => {
      throw error;
    });
};

export const unAssociatedOrderFlagList = (OrderId: string) => {
  return httpApi
    .get(UNASSOCIATED_ORDER_FLAG_API, {
      params: {
        expand: "",
        filter: "MappingId~eq~" + OrderId,
        sort: "",
        page: "",
      },
    })
    .then((response) => response.data)
    .catch((error) => {
      throw error;
    });
};

export const addOrderFlag = (addOrderFlagPayload: IAddUpdateOrderFlag) => {
  return httpApi
    .post(ADD_ORDER_FLAG_API, addOrderFlagPayload)
    .then((response) => response)
    .catch((error) => {
      throw error;
    });
};

export const getOrderStatusButtonList = (omsOrderStateId: number) => {
  return httpApi
    .get(GET_ORDER_STATUS_BUTTON_LIST_API + "/" + omsOrderStateId)
    .then((response) => response.data)
    .catch((error) => {
      throw error;
    });
};

export const getButtonDetailById = (buttonId: number, buttonType: string) => {
  return httpApi
    .get(GET_BUTTON_DETAIL_BY_ID_API + "/" + buttonId + "/" + buttonType)
    .then((response) => response.data)
    .catch((error) => {
      throw error;
    });
};

export const getOrderStatusById = (omsOrderStateId: number) => {
  return httpApi
    .get(GET_ORDER_STATUS_BY_ID_API + "/" + omsOrderStateId)
    .then((response) => response.data)
    .catch((error) => {
      throw error;
    });
};

export const getOrderClassButtonList = (omsOrderStateId: number) => {
  return httpApi
    .get(GET_ORDER_CLASS_BUTTON_LIST_API + "/" + omsOrderStateId)
    .then((response) => response.data)
    .catch((error) => {
      throw error;
    });
};

export const updateOrderFollowers = (followUnfollowPayload: IFollowUnfollow) => {
  return httpApi
    .post("/order/updateorderfollowers", followUnfollowPayload)
    .then((response) => response.data)
    .catch((error) => {
      throw error;
    });
};

export const updateLineItemPrice = (payload: IProductList) => {
  return httpApi
    .post("/Product/UpdatePrice", payload)
    .then((response) => response.data)
    .catch((error) => {
      throw error;
    });
};

export const updateLineItemQuantity = (payload: IProductList) => {
  return httpApi
    .post("/Product/UpdateQuantity", payload)
    .then((response) => response.data)
    .catch((error) => {
      throw error;
    });
};

export const updateLineItemStatus = (payload: IProductList) => {
  return httpApi
    .post("/Product/UpdateOrderStatus", payload)
    .then((response) => response.data)
    .catch((error) => {
      throw error;
    });
};

export const resetLineItemPrice = (payload: IIsPriceResetProductList) => {
  return httpApi
    .post("/Product/ResetProductPrice", payload)
    .then((response) => response.data)
    .catch((error) => {
      throw error;
    });
};

export const validateOrder = (orderId: string | undefined) => {
  return httpApi
    .get("/order/validateorder" + "/" + orderId)
    .then((response) => response.data)
    .catch((error) => {
      throw error;
    });
};

export const completeOrder = (completeOrderPayload: ICompleteOrder) => {
  return httpApi
    .post("/order/completeorder", completeOrderPayload)
    .then((response) => response.data)
    .catch((error) => {
      throw error;
    });
};

export const validateOrderLineItems = (orderId: string | undefined, orderProductId: string | undefined) => {
  return httpApi
    .get("/order/ValidateOrderLineItems" + "/" + orderId+ "/" + orderProductId)
    .then((response) => response.data)
    .catch((error) => {
      throw error;
    });
};
