/* eslint-disable max-len */
import { httpApi } from "api/http.api";
import {
  STORE_LIST_API,
  ORDER_LIST_API,
  USERGROUP_LIST_API,
  SAVEDVIEW_API,
  GETSAVEDVIEW_API,
  GETSAVEDVIEWLIST_API,
  DELETESAVEDVIEW_API,
  API_GATEWAY_URL,
  AssociatedUserGroups_LIST_By_UserId_API,
} from "config/constant";
import { IStoreList } from "interfaces/APIInterface/ICreateOrder";
import { readUserId } from "./localStorage.service";
import {
  ICreateMappingSavedView,
  IDeleteSavedView,
  IMultipleShareSavedView,
  IMultipleShareViewForEveryOne,
  IOrderListData,
  ISavedViewList,
  IUpdateViewPriorityList,
} from "interfaces/ClientInterface/IOrderList";
import {
  IDuplicateLineItemPayload,
  IDuplicateOrderPayload,
} from "interfaces/APIInterface/IOrderList";

export const getStoreList = (typeaheadRequestPayload: IStoreList) => {
  return httpApi
    .post(STORE_LIST_API, typeaheadRequestPayload, {
      headers: {
        "Znode-UserId": readUserId(),
      },
    })
    .then((response) => response)
    .catch((error) => {
      throw error;
    });
};
export const getOrderList = (orderRequestPayload: IOrderListData) => {
  return httpApi
    .post(ORDER_LIST_API, orderRequestPayload, {})
    .then((response) => response)
    .catch((error) => {
      throw error;
    });
};
export const getFiltereOrderList = (filterOrderRequestPayload: IOrderListData) => {
  return httpApi
    .post(ORDER_LIST_API, filterOrderRequestPayload, {})
    .then((response) => response)
    .catch((error) => {
      throw error;
    });
};
export const getUserGroupList = () => {
  return httpApi
    .get(USERGROUP_LIST_API)
    .then((response) => response)
    .catch((error) => {
      throw error;
    });
};
export const saveSavedView = (savedRequestPayload: ISavedViewList) => {
  return httpApi
    .post(SAVEDVIEW_API, savedRequestPayload, {})
    .then((response) => response)
    .catch((error) => {
      throw error;
    });
};
export const getSavedView = (getSavedViewRequestPayload: { viewId: number }) => {
  return httpApi
    .get(GETSAVEDVIEW_API + "/" + getSavedViewRequestPayload.viewId, {})
    .then((response) => response)
    .catch((error) => {
      throw error;
    });
};
export const getSavedViewList = (itemName: string) => {
  return httpApi
    .get(GETSAVEDVIEWLIST_API + "/" + itemName + "/" + readUserId())
    .then((response) => response)
    .catch((error) => {
      throw error;
    });
};

export const deleteSavedView = (deleteRequestSavedView: IDeleteSavedView) => {
  return httpApi
    .post(DELETESAVEDVIEW_API, deleteRequestSavedView, {})
    .then((response) => response)
    .catch((error) => {
      throw error;
    });
};
export const deleteSavedViewMapping = (deleteRequestSavedView: IDeleteSavedView) => {
  return httpApi
    .post("/savedview/deletecommerceportalview" + "/" + deleteRequestSavedView.ids)
    .then((response) => response)
    .catch((error) => {
      throw error;
    });
};

export const duplicateOrder = (duplicateOrderPayload: IDuplicateOrderPayload) => {
  return httpApi
    .post(`${API_GATEWAY_URL}/order/DuplicateOrder`, duplicateOrderPayload, {})
    .then((response) => response)
    .catch((error) => {
      throw error;
    });
};

export const duplicateLineItem = (duplicateLineItemPayload: IDuplicateLineItemPayload) => {
  return httpApi
    .post(`${API_GATEWAY_URL}/order/DuplicateLineItem`, duplicateLineItemPayload, {})
    .then((response) => response)
    .catch((error) => {
      throw error;
    });
};
export const createSavedViewMapping = (savedRequestPayload: ICreateMappingSavedView) => {
  return httpApi
    .post("/savedview/createsavedviewmapping", savedRequestPayload, {})
    .then((response) => response)
    .catch((error) => {
      throw error;
    });
};
export const UpdateViewPriority = (UpdateViewPriorityPayload: IUpdateViewPriorityList) => {
  return httpApi
    .post("/applicationsettings/updatepriority", UpdateViewPriorityPayload, {})
    .then((response) => response)
    .catch((error) => {
      throw error;
    });
};
export const getSavedViewUserGroupIds = (userGroupIds: string | null) => {
  return httpApi
    .get("/savedview/getsavedviewusergroupId" + "/" + userGroupIds)
    .then((response) => response)
    .catch((error) => {
      throw error;
    });
};
export const MultipleShareViewWithUserGroups = (requestMultipleShare: IMultipleShareSavedView) => {
  return httpApi
    .post("/savedview/shareviewtousergroups", requestMultipleShare, {})
    .then((response) => response)
    .catch((error) => {
      throw error;
    });
};
export const MultipleShareViewWithPublic = (
  requestMultipleShare: IMultipleShareViewForEveryOne
) => {
  return httpApi
    .post("/applicationsettings/shareviewtoeveryone", requestMultipleShare, {})
    .then((response) => response)
    .catch((error) => {
      throw error;
    });
};
export const getAssociatedUserGroupsListByUserId = () => {
  return httpApi
    .get(AssociatedUserGroups_LIST_By_UserId_API)
    .then((response) => response)
    .catch((error) => {
      throw error;
    });
};
