/* eslint-disable no-console */
/* eslint-disable max-lines-per-function */
import React, { useState } from "react";
import SelectInput from "components/Common/Select/Select";
import { Button, Drawer, Input, Space } from "antd";
import { SearchOutlined, FilterOutlined } from "@ant-design/icons";
import ProductFilters from "./ProductFilters";
import { ICategory } from "interfaces/APIInterface/IProducts";
import { SELECT_CATEGORY_PLACEHOLDER } from "components/Common/Product/Product.Constant";
import {
  IAddProductFilterProp,
  ISelectInputOption,
  ISelectInputOptionWithOrderBy,
} from "interfaces/ClientInterface/IProducts";
import { translate } from "i18n";

const AddProductFilter: React.FC<IAddProductFilterProp> = ({
  facets,
  categoryListData,
  searchKeyword,
  order,
  orderProductCatalogProfileData,
  setProductFacets,
  setCategory,
  onFilterApplied,
  fetchProductList,
  setSearchKeyword,
  currentPageSize,
  sortingColumnForProductFilter,
  setSortingColumnForProductFilter,
  handleSort,
  setCurrentPage,
  isProductFilter,
}) => {
  //const [shipTo, setShipTo] = useState("");
  const [open, setOpen] = useState<boolean>(false);

  const showDrawer = () => {
    setOpen(true);
  };

  const onClose = () => {
    setOpen(false);
  };

  /**
   * This function gets called on the category change from the dropdown list and fetch the product
   * list again with the changed category.
   */
  const onCategoryChange =  (categoryId: string, categoryName: string) => {
    const selectedCategory: ICategory = {
      PublishCategoryId: Number(categoryId),
      Name: categoryName,
    };
    setCurrentPage(1);
    setCategory(selectedCategory);
    if(isProductFilter){
      setProductFacets([]);
      onFilterApplied();
      fetchProductList(
        selectedCategory,
        order,
        orderProductCatalogProfileData,
        1,
        currentPageSize,
        sortingColumnForProductFilter.sortByColumnNameFilter,
        sortingColumnForProductFilter.sortTypeFilter,
        true,
      );
    }
    else{
      fetchProductList(
        selectedCategory,
        order,
        orderProductCatalogProfileData,
        1,
        currentPageSize,
        sortingColumnForProductFilter.sortByColumnNameFilter,
        sortingColumnForProductFilter.sortTypeFilter,
      );
    }
  };

  return (
    <Space size={"middle"}>
      <Input
        placeholder={translate("addProduct.searchProductPlaceholder")}
        suffix={
          <SearchOutlined
            style={{ color: "rgba(0,0,0,.45)" }}
            className="search-icon-style"
            onClick={() => onFilterApplied(false)}
          />
        }
        data-test-selector="txtSearchProducts"
        value={searchKeyword ?? ""}
        onChange={(e) => {
          setSearchKeyword(e?.target?.value);
        }}
        onClick={() => onFilterApplied(false)}
        allowClear={true}
      />
      <SelectInput
        placeholder={SELECT_CATEGORY_PLACEHOLDER}
        options={categoryListData}
        className="ship-inputs-width"
        showSearch={true}
        data-test-selector="drpCategory"
        onChange={(selectedText: string, option: ISelectInputOption): void => {
          const categoryValue = option?.value || "";
          const categoryLabel = option?.label || "";
          onCategoryChange(categoryValue, categoryLabel);
        }}
        allowClear={true}
        size={"large"}
      />
      <SelectInput
        placeholder={translate("addProduct.sortByPlaceholder")}
        options={[
          {
            value: "Price~DESC",
            label: translate("addProduct.dropdownValuePriceHighToLow"),
            sortByColumnNameFilter: "Price",
            sortTypeFilter: "DESC",
          },
          {
            value: "Price~ASC",
            label: translate("addProduct.dropdownValuePriceLowToHigh"),
            sortByColumnNameFilter: "Price",
            sortTypeFilter: "ASC",
          },
          {
            value: "ProductName~ASC",
            label: translate("addProduct.dropdownValueNameAToZ"),
            sortByColumnNameFilter: "ProductName",
            sortTypeFilter: "ASC",
          },
          {
            value: "ProductName~DESC",
            label: translate("addProduct.dropdownValueNameZToA"),
            sortByColumnNameFilter: "ProductName",
            sortTypeFilter: "DESC",
          },
        ]}
        className="ship-inputs-width"
        showSearch={true}
        data-test-selector="drpSortBy"
        onChange={(selectedText: string, option: ISelectInputOptionWithOrderBy): void => {
          const sortByColumnNameFilter = option?.sortByColumnNameFilter || "";
          if (sortByColumnNameFilter != "") {
            const sortTypeFilter = option?.sortTypeFilter || "";
            setSortingColumnForProductFilter({
              sortByColumnNameFilter: sortByColumnNameFilter,
              sortTypeFilter: sortTypeFilter,
            });
            option && handleSort(option.sortByColumnNameFilter, option.sortTypeFilter);
          }
        }}
        allowClear={true}
        size={"large"}
      />
      <Button icon={<FilterOutlined />} onClick={showDrawer}>
        {translate("addProduct.filterBtn")}
      </Button>
      <Drawer
        placement="right"
        closable={false}
        onClose={onClose}
        open={open}
        getContainer={false}
        className="product-fliter-drawer"
      >
        <ProductFilters
          setOpenDrawer={setOpen}
          setProductFacets={setProductFacets}
          onFilterApplied={onFilterApplied}
          facets={facets}
          isProductFilter={isProductFilter}
          facetsBeforeUpdate={facets}
        />
      </Drawer>
    </Space>
  );
};

export default AddProductFilter;
