import React from "react";
import { Typography, Space, Button } from "antd";
const { Title, Text } = Typography;
import { TitleHeader } from "components/Common/TitleHeader/TitleHeader";
import { useNavigate } from "react-router-dom";
import { IOrderSummaryProp } from "interfaces/ClientInterface/IEditOrder";
import { translate } from "i18n";

const AddProductsHeader = ({ orderSummary }: IOrderSummaryProp) => {
  const navigate = useNavigate();

  /**
   * This function is used to navigate to the edit order page.
   */
  const backToEditOrder = () => {
    navigate(-1);
  };

  return (
    <TitleHeader
      isBack={true}
      backClickHandler={backToEditOrder}
      title={
        <Space direction="horizontal" size={0} className="d-flex">
          <Space size={8} className="add-product-header">
            <Title level={4} className="m-0">
              <strong>{translate("addProduct.addProductsTitle")}</strong>
            </Title>
            <Text className="m-0">|</Text>
            <Text className="m-0 headerText">
              <strong>{translate("addProduct.orderTitle")}:</strong> {orderSummary?.ClassNumber}
            </Text>
            <Text className="m-0 headerText">
              <strong>{translate("addProduct.accountsTitle")}:</strong> {orderSummary?.AccountName}
            </Text>
            <Text className="m-0 headerText">
              <strong>{translate("addProduct.userTitle")}:</strong> {orderSummary?.FullName}
            </Text>
          </Space>
        </Space>
      }
      lhsColSize={18}
      rhsColSize={6}
      rhsContent={
        <Space size={0}>
          <Button data-test-selector={"btnBackToOrder"} onClick={backToEditOrder}>
            {translate("addProduct.backToOrderBtn")}
          </Button>
        </Space>
      }
    />
  );
};

export default AddProductsHeader;
