/* eslint-disable max-lines-per-function */
import React, { useState } from "react";
import { Button, Checkbox, Space, Typography } from "antd";
import Heading from "components/Common/Heading/Heading";
import { IProductFacet, IProductFacetAttributeValue } from "interfaces/APIInterface/IProducts";
import { IDrawerProp } from "interfaces/ClientInterface/IProducts";
import { CheckboxChangeEvent } from "antd/es/checkbox";
import { translate } from "i18n";

const { Text, Title } = Typography;

const ProductFilters = (props: IDrawerProp) => {
  const {
    setOpenDrawer,
    setProductFacets,
    onFilterApplied,
    facets,
    isProductFilter,
    facetsBeforeUpdate,
  } = props;

  const initialFacetsBeforeUpdate = [JSON.parse(JSON.stringify(facetsBeforeUpdate))];
  const [showClearFilterButton, setShowClearFilterButton] = useState(false);
  const [cancelButton, setCancelButton] = useState(true);

  /**
   * This function gets called on the Update Filter button click and calls the onFilterApplied()
   * which will fetch the product list again with the updated filters.
   */
  const updateFilterClickHandler = () => {
    setCancelButton(false);
    let selectedFacetsHeaderCount = 0;

    const updatedProductFacetList: IProductFacet[] = facets?.map((facetRecord) => {
      const filteredAttributeValues = facetRecord.AttributeValues?.filter(
        (value) =>
          value.ActionMode !== false && value.ActionMode !== null && value.ActionMode !== undefined
      );

      if (filteredAttributeValues && filteredAttributeValues.length > 0) {
        selectedFacetsHeaderCount++;
        return { ...facetRecord, ActionMode: "1" };
      } else {
        return { ...facetRecord, ActionMode: "0" };
      }
    });

    if (selectedFacetsHeaderCount > 0 || isProductFilter) {
      setProductFacets(updatedProductFacetList);
      setOpenDrawer(false);
      selectedFacetsHeaderCount > 0
        ? setShowClearFilterButton(true)
        : setShowClearFilterButton(false);
      onFilterApplied && onFilterApplied(false);
    }
  };

  const cancelButtonHandler = () => {
    const productFacetsBeforeUpdate: IProductFacet[] = initialFacetsBeforeUpdate.flat(2); 
    // Use flat(2) to remove two levels of nesting
    setProductFacets([]);
    if (cancelButton) {  
      onFilterApplied && onFilterApplied(true);
      setOpenDrawer(false);
    } else {
      setTimeout(() => {
        setProductFacets(productFacetsBeforeUpdate);
      });
      setCancelButton(false);
      setOpenDrawer(false);
    }
  };

  const clearFilterClickHandler = () => {
    setCancelButton(true);
    setProductFacets([]);
    setShowClearFilterButton(false);
    onFilterApplied && onFilterApplied(true);
  };

  return (
    <Space direction="vertical" size="large" className="d-flex ">
      <>
        {facets &&
          facets?.map((facet: IProductFacet, index: number) => {
            return (
              <Space
                key={index}
                direction="vertical"
                size="middle"
                className="d-flex item-container"
              >
                {facet?.AttributeValues &&
                facet?.AttributeValues?.length &&
                (facet?.ActionMode == "1" || facet?.ActionMode == null) ? (
                  <>
                    <Heading
                      titleClass="section-heading m-0"
                      titleText={facet.AttributeName}
                      textFontLevel={5}
                    />
                    <Space direction="vertical" size="middle" className="d-flex attribute-group">
                      {facet.AttributeValues &&
                        facet.AttributeValues?.map(
                          (attributeValue: IProductFacetAttributeValue, indexNumber: number) => {
                            if ((isProductFilter && attributeValue.IsChecked) || !isProductFilter) {
                              return (
                                <div
                                  key={indexNumber}
                                  className="attribute-item d-flex justify-between"
                                >
                                  <Checkbox
                                    onChange={(e: CheckboxChangeEvent) => {
                                      attributeValue.IsChecked = e.target.checked;
                                      attributeValue.ActionMode = e.target.checked;
                                    }}
                                    defaultChecked={attributeValue.ActionMode || false}
                                  >
                                    <Title level={5}>{attributeValue.Label}</Title>
                                  </Checkbox>
                                  <div className="item-counter">
                                    <Text>{attributeValue.FacetCount}</Text>
                                  </div>
                                </div>
                              );
                            }
                          }
                        )}
                    </Space>
                  </>
                ) : null}
              </Space>
            );
          })}
      </>
      <Space className="attribute-group filter-action d-flex justify-center align-center">
        <Button
          className="cancel-filter"
          onClick={() => {
            cancelButtonHandler();
          }}
        >
          {translate("addProduct.cancelBtn")}
        </Button>
        <Button type="primary" onClick={updateFilterClickHandler}>
          {translate("addProduct.updateFilterBtn")}
        </Button>
        {showClearFilterButton && (
          <Button onClick={clearFilterClickHandler}>
            {translate("addProduct.clearFilterBtn")}
          </Button>
        )}
      </Space>
    </Space>
  );
};

export default ProductFilters;
