import React from "react";
import { Image } from "antd";
import { translate } from "i18n";
import NoImage from "../../assets/images/no-image.png";
import { IProduct, IProductFacet } from "interfaces/APIInterface/IProducts";
import { THUMBNAIL_IMAGE_PATH } from "config/constant";

export const columns = [
  {
    title: translate("addProduct.productTableImageColumnTitle"),
    dataIndex: "ImageSmallPath",
    key: "ImageSmallPath",
    sorter: false,
    render: (text: string, record: IProduct) => {
      const imageData = record?.Attributes?.find((el: IProductFacet) => {
        return el?.AttributeCode == "ProductImage";
      });
      return {
        children: (
          <Image
            width={50}
            height={50}
            src={THUMBNAIL_IMAGE_PATH + imageData?.AttributeValues}
            fallback={NoImage}
            preview={false}
          />
        ),
      };
    },
  },
  {
    title: translate("addProduct.productTableProductNameColumnTitle"),
    dataIndex: "Name",
    key: "ProductName",
    width: "15rem",
    sorter: true,
    render: (text: string) => {
      return {
        children: (
          <div className="product-name" title={text}>
            {text}
          </div>
        ),
      };
    },
  },
  {
    title: translate("addProduct.productTableSkuColumnTitle"),
    dataIndex: "SKU",
    key: "SKU",
    sorter: false,
  },
  {
    title: translate("addProduct.productTablePriceColumnTitle"),
    dataIndex: "Price",
    key: "Price",
    sorter: true,
  },
];
