import { Table } from "antd";
import React from "react";
import { IProductListTableProps } from "interfaces/ClientInterface/IProducts";
import { columns } from "./Products.Constant";

export const ProductListTable: React.FC<IProductListTableProps> = ({
  productListData,
  onProductClick,
  currentPage,
  setCurrentPage,
  currentPageSize,
  setCurrentPageSize,
  totalProductCount,
  onPaginationChange,
  sortingColumn,
  setSortingColumn,
  handleSort,
}: IProductListTableProps) => {
  return (
    <Table
      size="small"
      rowKey={(record) => record?.ZnodeProductId}
      dataSource={productListData}
      columns={columns.map((column) => ({
        ...column,
        onHeaderCell: () => {
          return {
            onClick: () => {
              setSortingColumn({
                sortByColumnName: column.key,
                sortType: sortingColumn.sortType === "ASC" ? "DESC" : "ASC",
              });
              handleSort(column.key, sortingColumn.sortType === "ASC" ? "DESC" : "ASC");
            },
          };
        },
        //sortOrder: sortingColumn.sortType === "ASC" ? "ascend" : "descend",
      }))}
      pagination={{
        onChange: (page, pageSize) => {
          setCurrentPage(page);
          setCurrentPageSize(pageSize);
          onPaginationChange && onPaginationChange(page, pageSize);
        },
        position: ["bottomLeft"],
        current: currentPage,
        pageSize: currentPageSize,
        total: totalProductCount,
        //pageSizeOptions: ["5", "10", "20", "50", "70", "100"]
      }}
      scroll={{ x: "max-content" }}
      data-test-selector="tblList"
      className={"product-listing"}
      loading={
        (productListData && productListData.length) || productListData == null ? false : true
      }
      onRow={(row) => {
        return {
          onClick: () => {
            onProductClick(row);
          },
        };
      }}
    />
  );
};

export default ProductListTable;
