import React, { useContext } from "react";
import { Button, Space } from "antd";
import { formatSelector } from "utils";
import { IActionButtonsProps } from "interfaces/ClientInterface/IActionButtons";
import { IActionButtonList } from "interfaces/ClientInterface/IEditOrder";
import { translate } from "i18n";
import { AbilityContext } from "ability/can";
import { PERMISSION_CODE, PERMISSION_SUBJECT } from "ability/utils";
import { notificationController } from "../Notification/Notification";

export const ActionButtons: React.FC<IActionButtonsProps> = ({
  statusButtonList,
  classButtonList,
  onClick,
  onUpdateOrder,
  notesChildRef,
  getOrderDetails,
}: IActionButtonsProps) => {
  const ability = useContext(AbilityContext);
  const canCancelOrders = ability.can(PERMISSION_CODE.CANCEL_ORDERS, PERMISSION_SUBJECT.ORDERS);
  const validStatusButtonList = Array.isArray(statusButtonList) ? statusButtonList : [];
  const validClassButtonList = Array.isArray(classButtonList) ? classButtonList : [];
  const actionButtons = [...validStatusButtonList, ...validClassButtonList].sort((a, b) => {
    if (a?.DisplayOrder === b?.DisplayOrder) {
      return (a?.ButtonId || 0) - (b?.ButtonId || 0);
    } else {
      return (b?.DisplayOrder || 0) - (a?.DisplayOrder || 0);
    }
  });
  return (
    <Space size={10} className="flex-wrap justify-end">
      <Button
        type="primary"
        data-test-selector={"btnSave"}
        onClick={() => {
          onUpdateOrder("edit");
          notesChildRef;
          getOrderDetails();
        }}
      >
        {translate("editOrder.saveBtn")}
      </Button>
      <Button
        type="primary"
        data-test-selector={"btnSaveAndClose"}
        onClick={() => {
          onUpdateOrder("close");
          getOrderDetails();
        }}
      >
        {translate("editOrder.saveAndCloseBtn")}
      </Button>
      {actionButtons.map((item: IActionButtonList, i: number) => {
        if (item.IsClassButton == false) {
          if (ability.can(item?.PermissionCode, item?.TypeOfPermission)) {
            return (
              <Button
                key={`actionsButton${i}`}
                type="primary"
                ghost
                data-test-selector={`btn${formatSelector(item?.ButtonText)}`}
                onClick={() => {
                  if(!canCancelOrders){
                    notificationController.error({
                      message: translate("login.invalidLoginPermission"),
                      placement: "top",
                    });
                  }else{
                    onClick(item.ButtonId, "Status");
                  }
                  
                }}
              >
                {item.ButtonText}
              </Button>
            );
          }
        } else {
          return (
            <Button
              key={`actionsButton${i}`}
              type="primary"
              ghost
              data-test-selector={`btn${formatSelector(item?.ButtonText)}`}
              onClick={() => {
                if(!canCancelOrders){
                  notificationController.error({
                    message: translate("login.invalidLoginPermission"),
                    placement: "top",
                  });
                }else{
                  onClick(item.ButtonId, "Class");
                }
                
              }}
            >
              {item.ButtonText}
            </Button>
          );
        }
      })}
    </Space>
  );
};
