/* eslint-disable max-lines-per-function */
/* eslint-disable max-len */
/* eslint-disable max-lines */
import React, { useContext, useEffect, useState } from "react";
import { Button, Divider, Popover, Select, Space, Typography } from "antd";
import { AssignToPopOverProps } from "interfaces/ClientInterface/IAssignedTo";
import { CloseOutlined } from "@ant-design/icons";
import { CheckBoxComponent } from "../Checkbox/Checkbox";
import { CheckboxChangeEvent } from "antd/es/checkbox";
import { useParams } from "react-router-dom";
import { notificationController } from "../Notification/Notification";
import {
  IAssignUnassign,
  IUserGroupListItem,
  IUsersListItem,
} from "interfaces/APIInterface/IAssignTo";
import {
  AssignOwnerAndUserGroup,
  getUserGroupList,
  getUsersInMyTeam,
} from "api/services/assignTo.api";
import { readUserId , getUserDetails } from "api/services/localStorage.service";
import { PureAbility } from "@casl/ability";
import { AbilityContext } from "ability/can";
import {
  checkAssignToMePermission,
  checkAssignToMyTeamPermission,
} from "components/Orders/Order.Constant";
import { translate } from "i18n";
import { useAppSelector } from "hooks/reduxHooks";

const { Text } = Typography;

/**
 *
 * @param icon - antd icon component
 * @param open - boolean state for visibility of the icon
 * @param setOpen - setter method for managing the state of the pop over
 * @returns This code exports a functional component called `AssignToPopOver`that displays
 * a form for assigning a task to a user or user group.
 */

export default function AssignToPopOver({
  icon,
  open,
  setOpen,
  popOverTitle,
  updateDataAfterSave,
  isEditPermission,
  notesChildRef,
  getOrderDetails,
}: AssignToPopOverProps) {
  const IsDelegateToMeCheck = useAppSelector(
    (state) => state?.permission?.permissionsList?.IsDelegatedToMe
  );
  const ability: PureAbility<[string, string]> = useContext(AbilityContext);
  const canAssignToMyTeamPermission = checkAssignToMyTeamPermission(ability);
  const canAssignToMePermission = checkAssignToMePermission(ability);
  const { orderId } = useParams<Record<string, string | undefined>>();
  const [isMyself, setIsMyself] = useState(false as boolean);
  const [user, setUser] = useState("");
  const [userId, setUserId] = useState(0 as number);
  const [userGroup, setUserGroup] = useState("");
  const [userGroupList, setUserGroupList] = useState<IUserGroupListItem[]>([]);
  const [usersInUserGroupList, setUsersInUserGroup] = useState<IUsersListItem[]>([]);
  // eslint-disable-next-line no-unused-vars
  const [isInputEmpty, setIsInputEmpty] = useState(false);

  const [loader, setLoader] = useState({
    UserGroupLoading: false,
    userLoading: false,
    onSaveLoader: false,
  });

  const hide = () => {
    clearFields();
    setOpen(false);
  };

  const clearFields = () => {
    setUser("");
    setUserGroup("");
    setIsMyself(false);
    //To clear validation.
    setIsInputEmpty(false);
  };

  useEffect(() => {
    if (isMyself) {
      setUser("");
    }
  }, [isMyself]);

  const handleOpenChange = (newOpen: boolean) => {
    clearFields();
    setOpen(newOpen);
  };

  const setLoading = (key: string, loaderState: boolean) => {
    setLoader((prevState) => ({
      ...prevState,
      [key]: loaderState,
    }));
  };

  const fetchUserGroupList = () => {
    setLoading("UserGroupLoading", true);

    getUserGroupList(orderId)
      .then((response) => {
        const data = response?.data?.UserGroupsList;
        setUserGroupList(data);
        setLoading("UserGroupLoading", false);
      })
      .catch(() => {
        setLoading("UserGroupLoading", false);
      });
  };

  const fetchUsersInUserGroupList = () => {
    setLoading("userLoading", true);
    getUsersInMyTeam()
      .then((response) => {
        const data = response?.data?.UsersInMyTeamModels;
        setUsersInUserGroup(data);
        setLoading("userLoading", false);
      })
      .catch(() => {
        setLoading("userLoading", false);
      });
  };

  const assignTo = isMyself && userId ? userId : user;

  const onAssignUnassign = () => {
    if (!assignTo && !userGroup) {
      setIsInputEmpty(true);
      notificationController.error({
        message: translate("assignedTo.inputRequired"),
        placement: "top",
      });
      return;
    }
    setLoader((prevState) => ({
      ...prevState,
      onSaveLoader: true,
    }));
    const assignUnassignPayload: IAssignUnassign = {
      OrderIds: orderId,
      AssignTo: Number(assignTo),
      CPUserGroupId: Number(userGroup),
      UserId: readUserId(),
    };

    AssignOwnerAndUserGroup(assignUnassignPayload)
      .then((response) => {
        if ((isMyself || user) && userGroup) {
          notificationController.success({
            message: translate("assignedTo.ownerAndUserAssignedSuccessMessage"),
            placement: "top",
          });
          getOrderDetails();
        } else if (userGroup) {
          notificationController.success({
            message: translate("assignedTo.userAssignedSuccessMessage"),
            placement: "top",
          });
          getOrderDetails();
        } else if (isMyself || user) {
          notificationController.success({
            message: translate("assignedTo.ownerAssignedSuccessMessage"),
            placement: "top",
          });
          getOrderDetails();
        }
        const data = response?.data;
        updateDataAfterSave && updateDataAfterSave(data?.AssignTo, userGroup);
        setOpen(false);
        setIsMyself(false);
        setUserGroup("");
        setUser("");
        setLoader((prevState) => ({
          ...prevState,
          onSaveLoader: false,
        }));
      })
      .catch(() => {
        notificationController.error({
          message: translate("assignedTo.failedToAssignOwnerErrorMessage"),
        });
        setLoader((prevState) => ({
          ...prevState,
          onSaveLoader: false,
        }));
      });
    notesChildRef;
  };

  return (
    <div>
      {isEditPermission ? (
        <Popover
          overlayClassName={isInputEmpty ? "error-popover-wrapper" : ""}
          title={
            <Space direction="vertical" className="d-flex">
              <Space direction="horizontal" className="d-flex justify-between">
                <Text>{translate("assignedTo.titleAssignTo")}</Text>
                <CloseOutlined onClick={hide} />
              </Space>
              <Divider className="m-0" />
            </Space>
          }
          content={
            <Space size={8} direction="vertical">
              {(canAssignToMePermission || IsDelegateToMeCheck) && (
                <CheckBoxComponent
                  name={"Myself"}
                  checked={isMyself}
                  closable={false}
                  dataTestSelector={"chkMyself"}
                  onChangeHandle={(e: CheckboxChangeEvent) => {
                    fetchUsersInUserGroupList();
                    if(usersInUserGroupList.length >0){
                      const filterUserId = usersInUserGroupList.filter((item) =>
                      // eslint-disable-next-line
                      //@ts-ignore
                      item.UserName === JSON.parse(getUserDetails()).UserName ? item.UserId : ""
                      );
                      setUserId(filterUserId[0].UserId);
                      setIsMyself(e.target.checked);
                      setIsInputEmpty(false);
                    }
                  
                  }}
                />
              )}

              {canAssignToMyTeamPermission && (
                <Select
                  placeholder={translate("assignedTo.placeholderSelectUser")}
                  options={usersInUserGroupList}
                  showSearch={true}
                  data-test-selector="drpUser"
                  onChange={(value) => {
                    setUser(value);
                    setIsInputEmpty(false);
                  }}
                  value={user || undefined}
                  allowClear={true}
                  style={{ width: 180 }}
                  onClick={fetchUsersInUserGroupList}
                  disabled={isMyself}
                  loading={loader?.userLoading}
                  fieldNames={{ label: "UserName", value: "UserId" }}
                  listHeight={128}
                  // eslint-disable-next-line
                  filterOption={(input, option?: any) =>
                    option?.UserName?.toLowerCase()?.indexOf(input?.toLowerCase()) >= 0
                  }
                />
              )}

              <Select
                placeholder={translate("assignedTo.placeholderSelectUserGroup")}
                options={userGroupList}
                showSearch={true}
                data-test-selector="drpUserGroup"
                onChange={(value) => {
                  setUserGroup(value);
                  setIsInputEmpty(false);
                }}
                value={userGroup || undefined}
                allowClear={true}
                style={{ width: 180 }}
                onClick={fetchUserGroupList}
                loading={loader?.UserGroupLoading}
                fieldNames={{ label: "GroupName", value: "CPUserGroupId" }}
                listHeight={128}
                // eslint-disable-next-line
                filterOption={(input, option?: any) =>
                  option?.GroupName?.toLowerCase()?.indexOf(input?.toLowerCase()) >= 0
                }
              />
              <Button
                loading={loader?.onSaveLoader}
                type="primary"
                data-test-selector={"btnSave"}
                onClick={onAssignUnassign}
              >
                {translate("assignedTo.btnSave")}
              </Button>
            </Space>
          }
          trigger="click"
          open={open}
          onOpenChange={handleOpenChange}
          placement="rightTop"
        >
          <Space size={8} className="assigned-title">
            {popOverTitle}
            {icon}
          </Space>
        </Popover>
      ) : (
        <Space size={8} className="assigned-title">
          {popOverTitle}
          {icon}
        </Space>
      )}
    </div>
  );
}
