import React, { useContext } from "react";
import { Button, Card, Space } from "antd";
import { PlusOutlined } from "@ant-design/icons";
import "../../Dashboard/Dashboard.scss";
import { ICard } from "interfaces/ClientInterface/ICard";
import { AbilityContext } from "ability/can";
import { PERMISSION_CODE, PERMISSION_SUBJECT } from "ability/utils";

export default function CardComponent(props: ICard) {
  const ability = useContext(AbilityContext);
  const canCreateOrder = ability.can(PERMISSION_CODE.CREATE_ORDERS, PERMISSION_SUBJECT.ORDERS);
  const {
    cardTitle,
    addButtonLabel,
    addButtonUrl,
    addButtonDataTestSelector,
    viewAllLabel,
    viewAllUrl,
    viewAllDataTestSelector,
    children,
  } = props;
  return (
    <Card
      title={
        <Space size={8}>
          {cardTitle}
          <span>{canCreateOrder && "|"}</span>
          {canCreateOrder && (
            <Button
              href={addButtonUrl}
              data-test-selector={addButtonDataTestSelector}
              type="primary"
              size="small"
            >
              <PlusOutlined /> {addButtonLabel}
            </Button>
          )}
        </Space>
      }
      extra={
        <>
          <a href={viewAllUrl} data-test-selector={viewAllDataTestSelector}>
            {viewAllLabel}
          </a>
        </>
      }
    >
      {children}
    </Card>
  );
}
