import React from "react";
import { Checkbox, Space } from "antd";
import { CloseCircleOutlined, StopFilled } from "@ant-design/icons";
import { CheckBoxComponentProps } from "interfaces/ClientInterface/ICheckbox";

export const CheckBoxComponent: React.FC<CheckBoxComponentProps> = ({
  name,
  onChangeHandle,
  closable,
  defaultChecked,
  disabled,
  checked,
  onCancelHandle,
  dataTestSelector,
  id,
  isOverridden = false,
  onOverriddenHandle,
}: CheckBoxComponentProps) => {
  const onCancelPress = () => {
    onCancelHandle && onCancelHandle(id as string);
  };

  const onOverriddenPress = () => {
    onOverriddenHandle && onOverriddenHandle(id as string);
  };

  return (
    <Space size={2}>
      <Checkbox
        checked={checked}
        disabled={disabled}
        defaultChecked={defaultChecked}
        onChange={onChangeHandle}
        data-test-selector={dataTestSelector}
      >
        {name}
      </Checkbox>
      {closable && <CloseCircleOutlined onClick={onCancelPress} />}
      {isOverridden && (
        <StopFilled style={{ color: "#FF4D4F", marginLeft: "4px" }} onClick={onOverriddenPress} />
      )}
    </Space>
  );
};
