import React from "react";
import { Table } from "antd";
import { IList } from "interfaces/ClientInterface/IList";

export default function List(props: IList) {
  const {
    columns,
    data,
    pagination,
    paginationPosition = "bottomRight",
    classSelector,
    isLoading,
    rowSelection,
    sortingColumn,
    setSortingColumn,
    currentPage,
    setCurrentPage,
  } = props;

  return (
    <>
      <Table
        dataSource={data}
        columns={columns.map((column) => ({
          ...column,
          onHeaderCell: () => {
            return {
              onClick: () => {
                setSortingColumn({
                  sortByColumnName: column.key,
                  sortType: sortingColumn.sortType === "ASC" ? "DESC" : "ASC",
                });
              },
            };
          },
        }))}
        pagination={
          pagination && {
            position: [paginationPosition],
            current: currentPage,
            showSizeChanger: true,
            onChange: (page) => {
              setCurrentPage && setCurrentPage(page);
            },
          }
        }
        scroll={{ x: "max-content" }}
        data-test-selector="tblList"
        className={classSelector}
        loading={isLoading}
        rowSelection={rowSelection}
        rowKey={(record) => record.OrderId}
      />
    </>
  );
}
