/* eslint-disable no-unused-vars */
import React from "react";
import { Col, Row, Space, Typography } from "antd";
import {
  IConfigurableProductModel,
  IDictionary,
  IProductDetailsProp,
} from "interfaces/APIInterface/IProducts";
import { IConfigurableAttributeProp, ISelectedVariant } from "interfaces/ClientInterface/IProducts";
import { getConfigurableProductDetails } from "api/services/addProduct.api";
import { notificationController } from "components/Common/Notification/Notification";
import { TOP_PLACEMENT } from "config/constant";
import { COLOR_VARIANT_CODE, SIZE_VARIANT_CODE } from "../Product.Constant";
import { translate } from "i18n";
import { getGlobalSetting } from "api/services/localStorage.service";

const { Text } = Typography;
const ColorSwatch: React.FC<IConfigurableAttributeProp> = ({
  configurableAttributes,
  setProduct,
  selectedVariant,
  setSelectedVariant,
  configurableProductModel,
}: IConfigurableAttributeProp) => {
  /**
   * This function gets called on the product color variant selection and
   * sets the selected variant details and gets the configurable product details
   */
  const colorSelectHandler = (attributeValue: string) => {
    setSelectedVariant((prevState: ISelectedVariant) => ({
      ...prevState,
      color: attributeValue,
    }));

    const selectedAttributes: IDictionary<string> = {};
    selectedAttributes[COLOR_VARIANT_CODE] = attributeValue;
    selectedAttributes[SIZE_VARIANT_CODE] = ""; //selectedVariant.size;

    const productAttributes: IConfigurableProductModel = {
      Codes: `${COLOR_VARIANT_CODE},${SIZE_VARIANT_CODE}`,
      IsProductEdit: false,
      IsQuickView: false,
      IsQuote: false,
      LocaleId: configurableProductModel?.localeId,
      ParentOmsSavedCartLineItemId: null,
      ParentProductId: configurableProductModel?.parentProductId,
      ParentProductSKU: configurableProductModel?.parentProductSKU,
      PortalId: configurableProductModel?.portalId,
      PublishCatalogId: configurableProductModel?.publishCatalogId,
      Sku: configurableProductModel?.sku,
      SelectedAttributes: selectedAttributes,
      SelectedCode: COLOR_VARIANT_CODE,
      SelectedValue: attributeValue,
      Values: "", //`${attributeValue},${selectedVariant.size}`,
      IsNAAttributeAvailable:false,
    };

    const globalSettings = getGlobalSetting() ? JSON.parse(getGlobalSetting() || "") : {};
    const priceRoundOff = globalSettings?.PriceRoundOff;

    /**
     * This function is used to get the specific configurable product details
     */
    getConfigurableProductDetails(productAttributes)
      .then((response) => {
        const productDetails: IProductDetailsProp = response.PublishProduct;

        const Price =
          productDetails.SalesPrice == null
            ? productDetails?.RetailPrice
            : productDetails?.SalesPrice;
        const productPrice = typeof Price === "number" ? Price?.toFixed(priceRoundOff) : Price;

        const formattedPriceTiers =
          productDetails && productDetails?.TierPriceList?.length > 0
            ? productDetails?.TierPriceList?.map((tier) => ({
              ...tier,
              Price:
                  typeof tier.Price === "number"
                    ? parseFloat(tier?.Price).toFixed(priceRoundOff)
                    : tier?.Price,
            }))
            : [];

        setProduct((prevState: IProductDetailsProp) => ({
          ...prevState,
          Name: productDetails.Name,
          OriginalImagePath: productDetails.OriginalImagepath,
          SKU: productDetails.SKU,
          Quantity: productDetails.Quantity,
          RetailPrice: productDetails.RetailPrice,
          SalesPrice: productDetails.SalesPrice,
          ConfigurableProductSKU: productDetails.ConfigurableProductSKU,
          PublishProductId: productDetails.PublishProductId,
          Price: productPrice,
          TierPriceList: formattedPriceTiers,
        }));
      })
      .catch((error) => {
        notificationController.error({ message: error.message, placement: TOP_PLACEMENT });
      });
  };

  return (
    <Row className="color-swatch">
      <Col span={6} className="d-flex align-center">
        <Text className="text-color inp-label">
          <strong>{translate("common.titleColor")}:</strong>
        </Text>
      </Col>
      <Col span={18}>
        <Space size={5}>
          {configurableAttributes.map((e, i) => {
            return (
              <div
                key={i}
                className="color-swatch-container d-flex"
                onClick={() => colorSelectHandler(e.AttributeValue)}
              >
                {/* <div
                  className={
                    e.AttributeValue === (selectedVariant && selectedVariant.color)
                      ? "c-addon-item active"
                      : "c-addon-item"
                  }
                  style={{ background: e.SwatchText }}
                  title={e.AttributeValue}
                ></div> */}
              </div>
            );
          })}
        </Space>
      </Col>
    </Row>
  );
};

export default ColorSwatch;
