import {
  IRowPriceColumnItem,
  IRowQuantityColumnItem,
  ICollapseItem,
} from "interfaces/ClientInterface/IProducts";
import {
  IConfigurableAttribute,
  IPriceTier,
  IProductAttribute,
  IConfigurableAttributeList,
  IOrderProductAttributeValue,
  ICustomAttribute,
} from "interfaces/APIInterface/IProducts";
import { getPriceWithCurrency } from "utils";
import { Znode_NA_Code } from "config/constant";

export const ATTRIBUTE_CODE_SHORT_DESCRIPTION = "ShortDescription";
export const ATTRIBUTE_CODE_LONG_DESCRIPTION = "LongDescription";
export const ATTRIBUTE_CODE_PRODUCT_SPECIFICATION = "ProductSpecification";
export const ATTRIBUTE_CODE_SHIPPING_INFORMATION = "ShippingInformation";
export const COLOR_VARIANT_CODE = "Color";
export const SIZE_VARIANT_CODE = "Size";
export const SELECT_CATEGORY_PLACEHOLDER = "Select Category";
export const TIER_QUANTITY_LABEL_KEY = "tierQuantity";
export const TIER_QUANTITY_TITLE = "Tier Quantity";
export const TIER_Price_TITLE = "Tier Price";
export const ADD_PRODUCT_FAILED = "Failed to add the product to the order.";
export const GET_ORDER_DETAILS_FAILED = "Failed to load the order details.";
export const GET_ORDER_STATUS_FAILED = "Failed to load the order status.";
export const GET_PRODUCT_FLAGS_FAILED = "Failed to load the product flags.";
export const ADD_FLAG_SUCCESS = "Flag added successfully.";
export const ADD_FLAG_FAILED = "Failed to add flag.";
export const ADD_NOTES_HERE_PLACEHOLDER = "Add notes here";
export const UPDATE_PRODUCT_FAILED = "Failed to update the product.";
export const UPDATE_PRODUCT_SUCCESS = "Order product details has been updated successfully.";
export const DEFAULT_PRODUCT_QUANTITY =1;
export const ERROR_PRODUCT_NOT_PRESENT = "Product is not present to add in quick list";
export const QUICK_ADD_PRODUCTS_FAILED = "Failed to add the products to the order.";
export const QUICK_ADD_PRODUCTS_SUCCESS = "Products added to the order successfully.";
export const ERROR_INVALID_EXTENSION_SELECTED = "Please upload a CSV or XLSX file";
export const ERROR_QUICK_LIST_LIMIT = "Maximum 50 Products can be added into the Quick List.";
export const ERROR_INVALID_SKU = "The entered SKU is invalid";

/**
 * This function is used to get the AttributeValue by the AttributeCode.
 */
export const getAttributeValue = (attributes: IProductAttribute[], key: string) => {
  return attributes != null && attributes != undefined
    ? (attributes.find((f) => f.AttributeCode === key) as IProductAttribute)?.AttributeValues
    : "";
};

/**
 * This function is used to get the list of AttributeValues by the AttributeCode.
 */
export const getConfigurableAttributeValues = (attributes: IProductAttribute[]) => {
  const attributeValues = attributes
    .filter(attribute => attribute.ConfigurableAttribute?.length > 0)
    .map(attribute => attribute.AttributeCode);

  return attributeValues;
};
// eslint-disable-next-line max-len
export const  CheckConfiguarableNAAttribute = (customattirbutesData: ICustomAttribute[], isProductNa: boolean, setshowStock: React.Dispatch<React.SetStateAction<boolean>>)=>
{
  if (customattirbutesData.length != 0) {
    isProductNa = CheckNAAttributeValue(isProductNa, customattirbutesData);
    if (isProductNa) {
      setshowStock(true);
    }
    else {
      setshowStock(false);
    }
  }
  return isProductNa;
};
// eslint-disable-next-line no-unused-vars, max-len
export const NAConfigurableAttributePrice=(customattirbutesData: ICustomAttribute[], productPrice: string) =>{
  let isProductNa = false;
  if (customattirbutesData.length != 0) {
    isProductNa = CheckNAAttributeValue(isProductNa, customattirbutesData);
    if (isProductNa) productPrice = "";

  }
  return { isProductNa, productPrice} ;
};

/**
 * This function is used to get the AttributeValue by the AttributeCode.
 */
export const getAttributeValueForVariants = (attributes: IProductAttribute[], keys: string[]) => {
  const attributeValues = attributes
    .filter(attribute => keys.includes(attribute.AttributeCode))
    .map(attribute => attribute.AttributeValues);

  return attributeValues;
};
// eslint-disable-next-line max-len
export const getCustomAttributeValueForVariants = (attributes: IOrderProductAttributeValue[], keys: string[]) => {
  const sortedData = [...attributes].sort((a, b) => a.AttributeCode.localeCompare(b.AttributeCode));
  const sortedKeys = [...keys].sort();
  const attributeValues = sortedData
    .filter(attribute => sortedKeys.includes(attribute.AttributeCode))
    .map(attribute => attribute.AttributeValue);
  return attributeValues;
};
/**

/**
 * This function is used to get the Configurable Product Attributes Details
 * (like Color and Size) by the AttributeCode.
 */
export const getConfigurableAttributeDetails = (attributes: IProductAttribute[], key: string) => {
  const configurableAttributes: IConfigurableAttribute[] = [];

  if (attributes != null && attributes != undefined) {
    const productAttribute = attributes.find((f) => f.AttributeCode === key) as IProductAttribute;

    if (productAttribute != null && productAttribute.ConfigurableAttribute?.length > 0) {
      productAttribute.ConfigurableAttribute.forEach((configAttribute) => {
        const configurableAttribute: IConfigurableAttribute = {
          AttributeCode:configAttribute.AttributeCode,
          AttributeValue: configAttribute.AttributeValue,
          SwatchText: configAttribute.SwatchText,
          SelectValues:[],
          IsNAAttributeAvailable:false
        };

        configurableAttributes.push(configurableAttribute);
      });
    }
  }

  return configurableAttributes;
};

/** This function is used to get the Configurable Product Attributes Details
 * (like Color and Size) by the AttributeCode.
 */
export const getConfigurableAttributeVariantDetails = (
  attributes: IProductAttribute[], 
  keys: string[]
): IConfigurableAttributeList[] => {
  const configurableAttributesList: IConfigurableAttributeList[] = [];

  if (attributes && keys?.length > 0) {
    keys.forEach((element) => {
      const productAttribute = attributes.find(
        (f) => f.AttributeCode === element
      ) as IProductAttribute;
      if (productAttribute && productAttribute.ConfigurableAttribute?.length > 0) {
        const configurableAttributes: IConfigurableAttribute[] = [];

        // Add "N/A" at the first index
        configurableAttributes.push({
          AttributeCode:"",
          AttributeValue: Znode_NA_Code,
          SwatchText: Znode_NA_Code ,
          SelectValues: [],
          IsNAAttributeAvailable:false,
        });

        // Add the existing attributes in between
        configurableAttributes.push(
          ...productAttribute.ConfigurableAttribute.map((configAttribute) => ({
            AttributeCode:configAttribute.AttributeCode,
            AttributeValue: configAttribute.AttributeValue,
            SwatchText: configAttribute.SwatchText,
            SelectValues: configAttribute.SelectValues,
            IsNAAttributeAvailable: configAttribute.IsNAAttributeAvailable,
          }))
        );

        

        configurableAttributesList.push({ ConfigurableAttributeList: configurableAttributes });

      }
    });
  }

  return configurableAttributesList;
};

/**

/**
 * This function is used to create the Collapse Item object with the provided details
 * which will be used to show the collapsible panel with the details.
 */
export const getCollapseItem = (
  key: string,
  title: string,
  classSelector: string,
  attributeCodeName: string,
  attributes: IProductAttribute[]
) => {
  const colItem: ICollapseItem = {
    key: key,
    title: title,
    content: getAttributeValue(attributes, attributeCodeName),
    classSelector: classSelector,
  };

  return colItem;
};

/**
 * This function is used to create the Quantity Tiers data source to be displayed on the Table.
 */
export const getQuantityRowColumns = (tierPriceList: IPriceTier[]) => {
  const columnList: IRowQuantityColumnItem[] = [
    {
      key: TIER_QUANTITY_LABEL_KEY,
      dataIndex: TIER_QUANTITY_LABEL_KEY,
      title: TIER_QUANTITY_TITLE,
    },
  ];

  tierPriceList?.forEach((priceRecord, index) => {
    const quantity = priceRecord.Quantity ? Number(priceRecord.Quantity) : 0;

    const currentColumn: IRowQuantityColumnItem = {
      title: quantity,
      dataIndex: TIER_QUANTITY_LABEL_KEY + quantity,
      key: index?.toString(),
    };

    columnList.push(currentColumn);
  });

  return columnList;
};

/**
 * This function is used to create the Price Tiers data source to be displayed on the Table.
 */
export const getPriceRowColumns = (tierPriceList: IPriceTier[], currencySuffix: string) => {
  const columnList: IRowPriceColumnItem = {
    tierQuantity: TIER_Price_TITLE,
  };

  tierPriceList?.forEach((priceRecord) => {
    columnList[TIER_QUANTITY_LABEL_KEY + priceRecord.Quantity] = getPriceWithCurrency(
      currencySuffix,
      priceRecord.Price
    );
    return;
  });

  return columnList;
};

// eslint-disable-next-line max-len
export const CheckNAAttributeValue= (isProductNa: boolean, customattirbutesData: ICustomAttribute[]) => {
  isProductNa = customattirbutesData.some((x) => x.AttributeValues == Znode_NA_Code);
  return isProductNa;
};
