/* eslint-disable no-unused-vars */
/* eslint-disable max-lines-per-function */
import React, { ChangeEvent, ChangeEventHandler, useState } from "react";
import ProductTitle from "./ProductTitle";
import ProductImage from "./ProductImage";
import ProductDescription from "./ProductDescription";
import ProductSku from "./ProductSku";
import ProductPrice from "./ProductPrice";
import ProductQuantity from "./Quantity";
import Heading from "../Heading/Heading";
import { Button, Col, Row, Space, Typography } from "antd";
import {
  IAddProductProp,
  IProductVariant,
  IConfigurableAttributeList,
  IProductAttribute,
  ICustomAttribute,
} from "interfaces/APIInterface/IProducts";
import {
  IRowPriceColumnItem,
  IRowQuantityColumnItem,
  ISetProductProp,
  ICollapseItem,
} from "interfaces/ClientInterface/IProducts";
import ProductTier from "./ProductTier";
import ProductSpecification from "./ProductSpecification";
import "./Product.scss";
import TextArea from "antd/es/input/TextArea";
import { useNavigate } from "react-router-dom";
import { notificationController } from "../Notification/Notification";
// eslint-disable-next-line max-len
import { DEFAULT_EMPTY_GUID,  Znode_NA_Code, THUMBNAIL_IMAGE_PATH, TOP_PLACEMENT } from "config/constant";
import {
  ADD_NOTES_HERE_PLACEHOLDER,
  ADD_PRODUCT_FAILED,
  ATTRIBUTE_CODE_LONG_DESCRIPTION,
  ATTRIBUTE_CODE_PRODUCT_SPECIFICATION,
  ATTRIBUTE_CODE_SHIPPING_INFORMATION,
  ATTRIBUTE_CODE_SHORT_DESCRIPTION,
  getAttributeValue,
  getCollapseItem,
  getPriceRowColumns,
  getQuantityRowColumns,
  getConfigurableAttributeVariantDetails,
  CheckNAAttributeValue,
  
} from "./Product.Constant";
import { readUserId } from "api/services/localStorage.service";
import { addProduct } from "api/services/addProduct.api";
import { ROUTES_PATH } from "routes/Routes.Constant";
import { translate } from "i18n";
import Variants from "./AddOn/Variants";

const { Text } = Typography;

const ProductDetail: React.FC<ISetProductProp> = ({
  product,
  orderId,
  quantity,
  productNote,
  selectedVariant,
  configurableProductModel,
  setProduct,
  setIsProductAdded,
  setQuantity,
  setProductNote,
  setSelectedVariant,
  editQuantity,
  setEditQuantity,
  variant,
  selectCustomAttribute,
  setCustomatrribute,
  showStock,
  setshowStock,  
  ParentProductImage,
}: ISetProductProp) => {
  const navigate = useNavigate();
  const {
    PublishProductId,
    Name,
    SKU,
    Price,
    Attributes,
    TierPriceList,
    Quantity,
    IsConfigurableProduct,
    ConfigurableProductSKU,
    CurrencySuffix,
    VersionId,
  } = product;
   
  /**
   * This function is used to create the Collapse Item objects with the provided details
   * which will be used to show the collapsible panel with the details.
   */
  const productSpecificationData: ICollapseItem[] = [
    getCollapseItem(
      "productDetails",
      "Product Details",
      "product-details-tab",
      ATTRIBUTE_CODE_LONG_DESCRIPTION,
      Attributes
    ),
    getCollapseItem(
      "specifications",
      "Specifications",
      "product-specifications-tab",
      ATTRIBUTE_CODE_PRODUCT_SPECIFICATION,
      Attributes
    ),
    getCollapseItem(
      "shipping",
      "Shipping",
      "product-shipping-tab",
      ATTRIBUTE_CODE_SHIPPING_INFORMATION,
      Attributes
    ),
  ];

  const productVariants: IConfigurableAttributeList[] = getConfigurableAttributeVariantDetails(
    Attributes,
    variant
  );

  const productQuantityTierColumn: IRowQuantityColumnItem[] = getQuantityRowColumns(TierPriceList);
  const productPriceTierColumn: IRowPriceColumnItem = getPriceRowColumns(
    TierPriceList,
    CurrencySuffix
  );

  /**
   * This function is used when the user needs to navigate to the Edit Product of the order.
   */
  const handleEditProduct = (orderProductId: string, childSKU: string) => {
    navigate(`/${ROUTES_PATH.EDIT_PRODUCT}/${orderProductId}/${childSKU}`);
  };

  /**
   * This function is used when the product needs to be added to the order.
   */
  const addProductToOrder = (isAddEdit: boolean) => {
    const customeProductAttribute: ICustomAttribute[] = [];
    let IsProductNa=false;
    if(selectCustomAttribute.length>0){
      IsProductNa = CheckNAAttributeValue(IsProductNa, selectCustomAttribute);
    }
    
    const productVariant: IProductVariant = {
      ZnodeProductId:
            !IsProductNa  ? PublishProductId : product.ConfigurableProductId,
      GroupingCode: "",
      IsAddOn: false,
      ParentDetail: "",
      Customization: "",
      Quantity: quantity,
      Price: Price,
      ProductNote: productNote,
      Attributes: product?.Attributes,
      NAAttribute: !IsProductNa ? customeProductAttribute : selectCustomAttribute,
      ParentProductId:configurableProductModel?.parentProductId,  
    };

    const productModel: IAddProductProp = {
      OrderId: orderId,
      VersionId: VersionId,
      ProductVariantDetails: [productVariant],
      UserId: readUserId(),
      OrderProductId: DEFAULT_EMPTY_GUID,
      OrderProductAttributeValueId: null,
      SKU: product.SKU,
      ConfigurableProductSKU: product.ConfigurableProductSKU,      
    };

    addProduct(productModel)
      .then((response) => {
        if (response.StatusModel && response.StatusModel.Status) {
          if (isAddEdit) {
            handleEditProduct(response.StatusModel.Id, productModel.ConfigurableProductSKU);
          } else {
            setIsProductAdded(true);
          }
        } else {
          notificationController.error({ message: ADD_PRODUCT_FAILED, placement: TOP_PLACEMENT });
        }
      })
      .catch(() => {
        notificationController.error({ message: ADD_PRODUCT_FAILED, placement: TOP_PLACEMENT });
      });
  };

  const onProductNoteChange: ChangeEventHandler = (event: ChangeEvent<HTMLInputElement>) => {
    setProductNote(event.target.value);
  };

  const getImageUrl = () => {
    if(product.ImageThumbNailPath !="" )
    {
      return product.ImageThumbNailPath;
    }else{
      const imageData = product?.Attributes?.find((el: IProductAttribute) => {
        return el?.AttributeCode == "ProductImage";
      });
      return THUMBNAIL_IMAGE_PATH + imageData?.AttributeValues;
    }
  };
  return (
    <Space direction="vertical" size={30} className="d-flex">
      <Row gutter={[10, 15]}>
        <Col span={6}>
          <ProductImage
            imageUrl={getImageUrl()}
            imageHeight="100%"
            imageWidth="auto"
            isPreview={false}
            className="product-image"
            alt={translate("products.altTextProductImage")}
          />
        </Col>
        <Col span={13}>
          <Space direction="vertical" size={5} className="d-flex">
            <ProductTitle titleClass="product-name m-0" titleText={Name} textFontLevel={5} />
            <ProductSku
              labelClass="product-sku text-color"
              productSku={IsConfigurableProduct ? ConfigurableProductSKU : SKU}
            />
            <ProductDescription
              descClass="product-desc text-color"
              descriptionData={getAttributeValue(Attributes, ATTRIBUTE_CODE_SHORT_DESCRIPTION)}
            />
            <Space size={"small"}>
              <ProductQuantity
                quantity={quantity}
                setQuantity={setQuantity}
                editQuantity={editQuantity}
                setEditQuantity={setEditQuantity}
              />
              <Button
                type="primary"
                data-test-selector={"btnAdd"}
                onClick={() => addProductToOrder(false)}
              >
                {translate("products.btnAdd")}
              </Button>
              <Button
                type="primary"
                data-test-selector={"btnAddAndEdit"}
                onClick={() => addProductToOrder(true)}
                className="z-index-99"
              >
                {translate("products.btnAddAndEdit")}
              </Button>
            </Space>
          </Space>
        </Col>
        <Col span={5}>
          <ProductPrice
            priceClass="product-price  m-0"
            priceFontLevel={3}
            price={Price}
            currency={CurrencySuffix}
            inStockQuantity={Quantity} 
            IsNAAttributeAvailable={false}  
            showStock={showStock}        />
        </Col>
      </Row>
      <Row gutter={[30, 30]}>
        {productVariants && productVariants?.length > 0 ? (
          <Col span={24}>
            <Space direction="vertical" size={5} className="d-flex">
              <Heading
                titleClass="section-heading m-0"
                titleText="Product Variants"
                textFontLevel={5}
              />
              {variant && variant?.length > 0
                ? variant.map((item, index: number) => (
                  <Variants
                    key={index}
                    configurableAttributes={productVariants[index]?.ConfigurableAttributeList}
                    setProduct={setProduct}
                    selectedVariant={selectedVariant}
                    setSelectedVariant={setSelectedVariant}
                    configurableProductModel={configurableProductModel}
                    variant={variant}
                    index={index}
                    selectCustomAttribute={selectCustomAttribute}
                    setCustomatrribute={setCustomatrribute}
                    setshowStock={setshowStock}
                    ParentProductImage={ ParentProductImage}
                  />
                ))
                : null}
            </Space>
          </Col>
        ) : null}
        {productQuantityTierColumn?.length > 1 ? (
          <Col span={24}>
            <ProductTier
              productQuantityTierColumn={productQuantityTierColumn}
              productPriceTierColumn={productPriceTierColumn}
            />
          </Col>
        ) : null}
        <Col span={24}>
          <Row>
            <Col span={6} className="d-flex align-start">
              <Text className="text-color inp-label">
                <strong>{translate("products.titleItemNote")}:</strong>
              </Text>
            </Col>
            <Col span={14}>
              <TextArea
                rows={4}
                placeholder={ADD_NOTES_HERE_PLACEHOLDER}
                value={productNote}
                onChange={onProductNoteChange}
              />
            </Col>
          </Row>
        </Col>
        <Col span={24} className="product-specification">
          <ProductSpecification productSpecificationData={productSpecificationData} />
        </Col>
      </Row>
    </Space>
  );
};

export default ProductDetail;
