import React from "react";
import { InputNumber, Space, Typography } from "antd";
import { ISpaceProps } from "interfaces/ClientInterface/IProducts";
import { DEFAULT_PRODUCT_QUANTITY } from "./Product.Constant";
import { translate } from "i18n";

const { Text } = Typography;

const ProductQuantity = (props: ISpaceProps) => {
  const { spaceDirection, className, size, quantity, setQuantity, setEditQuantity } = props;

  /**
   * This function is used to set the Quantity of the product to be added to the order
   * on quantity change event.
   */
  const onQuantityChangeHandler = (value: number | null) => {
    //if (value) {
    setQuantity(value);
    setEditQuantity(value);
    // }
  };

  return (
    <Space direction={spaceDirection} size={size} className={className}>
      <Text className="text-color inp-label">
        <strong>{translate("products.textQuantity")}:</strong>
      </Text>
      <InputNumber
        min={0}
        defaultValue={DEFAULT_PRODUCT_QUANTITY}
        size={"middle"}
        className="quantity-inp"
        value={quantity}
        onChange={(value: number | null) => onQuantityChangeHandler(value)}
        controls={true}
      />
    </Space>
  );
};

export default ProductQuantity;
