import React from "react";
import { Button, Col, Row, Space } from "antd";
import { ArrowLeftOutlined } from "@ant-design/icons";
import { useNavigate } from "react-router-dom";
import { TitleHeaderProps } from "interfaces/ClientInterface/ITitleHeader";
import "./TitleHeader.scss";

export const TitleHeader: React.FC<TitleHeaderProps> = ({
  title,
  subTitle,
  isBack = false,
  rhsContent = "",
  lhsColSize,
  rhsColSize,
  backClickHandler,
}: TitleHeaderProps) => {
  const navigate = useNavigate();

  const onBackPress = () => {
    if (backClickHandler) {
      backClickHandler();
    } else {
      navigate(-1);
    }
  };

  return (
    <Row className="header-container" justify="space-between" align="middle">
      <Col
        span={lhsColSize ? lhsColSize : 12}
        lg={lhsColSize ? lhsColSize : 12}
        md={lhsColSize ? lhsColSize : 12}
        sm={24}
        xs={24}
      >
        <Space size={8} className="back-button-item">
          {isBack && (
            <Button
              type="text"
              className="arrow-container"
              onClick={onBackPress}
              data-test-selector="btnBack"
            >
              <ArrowLeftOutlined />
            </Button>
          )}
          <div className="header-title d-flex">{title}</div>
          <div>{subTitle}</div>
        </Space>
      </Col>
      <Col
        span={rhsColSize ? rhsColSize : 12}
        className="d-flex justify-end"
        lg={rhsColSize ? rhsColSize : 12}
        md={rhsColSize ? rhsColSize : 12}
        sm={24}
        xs={24}
      >
        {rhsContent && rhsContent}
      </Col>
    </Row>
  );
};
