/* eslint-disable max-lines */
import React, { useEffect, useRef, useState } from "react";
import { Space, Typography, notification } from "antd";
import CollapseComponent from "components/Common/Collapse/Collapse";
import OrderSummaryHeader from "./OrderSummary/OrderSummaryHeader";
import TabComponent from "components/Common/Tabs/TabsComponent";
import Shipping from "./Shipping/Shipping";
import {
  IOrder,
  IOrderData,
  IUpdateOrder,
  OrderStatusListProps,
  IOrderStatus,
  IProductList,
  IActionButtonList,
  IActionButton,
  ICompleteOrder,
  IorderStatusSendEmail,
  IEditOrderError,
} from "interfaces/ClientInterface/IEditOrder";
// eslint-disable-next-line @typescript-eslint/no-unused-vars
import { useNavigate, useParams } from "react-router-dom";
import Payment from "./Payment/Payment";
import { IUserGroup } from "interfaces/APIInterface/IUserGroup";
import "../Common/DuplicateModal/DuplicateModal.scss";
import {
  addOrderFlag,
  completeOrder,
  getButtonDetailById,
  getOrder,
  getOrderClassButtonList,
  getOrderStatus,
  getOrderStatusButtonList,
  getOrderStatusById,
  unAssociatedOrderFlagList,
  updateOrder,
  updateOrderStatusByOrderId,
  validateOrder,
  validateOrderLineItems,
} from "api/services/editOrder.api";
import { notificationController } from "components/Common/Notification/Notification";
import {
  IAddUpdateOrderFlag,
  IOrderFlag,
  IUnAssociatedOrderFlagList,
} from "interfaces/ClientInterface/IOrderFlag";
import NotesAndLog from "./NotesAndLog/NotesAndLog";
import OrderFlagsContent from "./OrderFlags/OrderFlagsContent";
import OrderSummaryContent from "./OrderSummary/OrderSummaryContent";
import ModalComponent from "components/Common/Modal/Modal";
import { ORDER_CLASS, ORDER_ORIGIN } from "config/constant";
import { OrderFlagsList } from "./OrderFlags/OrderFlagsList";
import { readUserId } from "api/services/localStorage.service";
import OrderFlagsHeader from "./OrderFlags/OrderFlagsHeader";
import { calculate } from "api/services/calculateOrder.api";
import { ICalculate } from "interfaces/APIInterface/ICalculate";
import { ROUTES_PATH } from "routes/Routes.Constant";
import { ProductList } from "./Products";
import { ActionButtons } from "components/Common/ActionButtons/ActionButtons";
import { translate } from "i18n";
import AssignedTo from "components/Common/AssignedTo/AssignedTo";
import { httpApi } from "api/http.api";
import { InfoCircleOutlined } from "@ant-design/icons";
import { EditOrderTitleHeader } from "./EditOrderTitleHeader";
import { checkPermissionToShow, isObjectEmpty } from "utils";
import { useAppDispatch, useAppSelector } from "hooks/reduxHooks";
import { getPermissions } from "store/slices/permission.slice";
import StatusTag from "components/Common/Status/StatusTag";
import { getStatusDropDownStyle } from "components/Common/Status/Status.Constant";
import { setOrderDetails } from "store/slices/editOrder.slice";
import { getEditOrderPermissionsData } from "api/services/permission.api";
import { IEditOrderPermissions } from "interfaces/ClientInterface/IEditOrder";

const { Title } = Typography;
/**
 * @returns This function returns a React component that renders an Edit Order details Page
 * with various collapsible sections and tabs
 */
// eslint-disable-next-line max-lines-per-function
const EditOrder: React.FC = () => {
  const navigate = useNavigate();
  const dispatch = useAppDispatch();
  //child reference of noteAndLog Component
  // eslint-disable-next-line @typescript-eslint/no-explicit-any
  const notesChildRef: any = useRef();
  const priceNoteChangeInfo = useAppSelector((state) => state.editOrder.priceNoteChange);
  const isEditPermission = useAppSelector((state) => state.permission.isEditPermission);
  const [order, setOrder] = useState({} as IOrder);
  const [searchInput, setSearchInput] = useState("");
  const [orderStatusList, setOrderStatusList] = useState<OrderStatusListProps[]>([]);
  const [orderUserGroup, setOrderUserGroup] = useState<IUserGroup[]>([]);
  const [orderFlag, setOrderFlag] = useState<IOrderFlag[]>([]);
  const { orderId } = useParams<Record<string, string | undefined>>();
  const [isModalVisible, setIsModalVisible] = useState(false as boolean);
  const [unAssociatedOrderFlag, setUnAssociatedOrderFlag] = useState<IUnAssociatedOrderFlagList[]>(
    []
  );
  const [initialOrderTypeCode, setInitialOrderTypeCode] = useState<string>("");
  const [initialAccountId, setInitialAccountId] = useState({} as number);
  const [initialAssignedUserId, setInitialAssignedUserId] = useState({} as number);

  const [orderData, setOrderData] = useState<IOrderData>({
    storeId: 0,
    storeName: "",
    accountId: 0,
    accountName: "",
    userId: 0,
    userName: "",
    orderTypeCode: "",
    orderTypeName: "",
    isOrderTypeChanged: false,
  });
  const [selectedRowKeys, setSelectedRowKeys] = useState<React.Key[]>([]);
  const [orderCalculation, setOrderCalculation] = useState({} as ICalculate);
  const [statusButtonList, setStatusButtonList] = useState<IActionButtonList[]>([]);
  const [classButtonList, setClassButtonList] = useState<IActionButtonList[]>([]);
  const [productList, setProductList] = useState<Array<IProductList>>([]);
  const [orderStatusSendEmail, setorderStatusSendEmail] = useState<IorderStatusSendEmail[]>([]);
  const [isCalledByEditOrder, setIsCalledByEditOrder] = useState<boolean>(false);
  const [editOrderError, setEditOrderError] = useState<IEditOrderError>({
    userError: "",
    orderTypeError: "",
  });
  const [preserveOrderStatus, setPreserveOrderStatus] = useState<number>(0);
  const [showEditOrder, setShowEditOrder] = useState<boolean>(false);
  const [getPermissionsData, setGetPermissionData] = useState<IEditOrderPermissions>();

  useEffect(() => {
    getOrderDetails();
    getOrderStatusList();
    getShippingDetails();
    fetchEditPermissions();
    // eslint-disable-next-line react-hooks/exhaustive-deps
  }, [orderId]);

  //trigger change in order data and save it to redux state
  useEffect(() => {
    if (!isObjectEmpty(order)) {
      dispatch(setOrderDetails(order));
    }
    // eslint-disable-next-line react-hooks/exhaustive-deps
  }, [order]);

  useEffect(() => {
    getShippingDetails();
    // eslint-disable-next-line react-hooks/exhaustive-deps
  }, [order?.ShipDate]);

  useEffect(() => {
    if (getPermissionsData?.IsView === false) {
      navigate(`${ROUTES_PATH.NOT_AUTHORISED}`);
    } else {
      setShowEditOrder(true);
    }
  }, [getPermissionsData, navigate]);

  const fetchEditPermissions = () => {
    getEditOrderPermissionsData(orderId).then((response) => {
      const data = response?.ItemLevelPermissions;
      dispatch(getPermissions({ ...data }));
      setGetPermissionData(data);
    });
  };

  const getOrderDetails = () => {
    getOrder(orderId)
      .then((response) => {
        const data: IOrder = response?.Order;
        setOrder((prevState) => ({
          ...prevState,
          ...data,
        }));
        getOrderStatusButtons(data?.OmsOrderStateId);
        getOrderClassButtons(data?.OmsOrderStateId);
        getOrderStatusDetailByStatusId(data?.OmsOrderStateId);
        setOrderData({
          storeId: data?.PortalId,
          storeName: data?.StoreName,
          accountId: data?.AccountId,
          accountName: data?.AccountName,
          userId: data?.UserId,
          userName: data?.UserName,
          orderTypeCode: data?.OrderType,
          orderTypeName: data?.OrderTypeName,
        });
        setInitialOrderTypeCode(data?.OrderType);
        setInitialAccountId(data?.AccountId);
        setInitialAssignedUserId(data?.UserId);
        setPreserveOrderStatus(data?.OmsOrderStateId);
        const parseData = JSON.parse(data?.OrderDetail);
        getOrderUserGroup(parseData[0].OrderUserGroup);
        getOrderFlag(parseData[0].OrderFlag);
        calculateOrder();
      })
      .catch(() => {
        notificationController.error({
          message: translate("editOrder.failedToLoadOrderDetailsErrorMessage"),
        });
      });
  };

  const getOrderDetailsWithFlag = () => {
    getOrder(orderId)
      .then((response) => {
        const data: IOrder = response?.Order;
        const parseData = JSON.parse(data?.OrderDetail);
        getOrderUserGroup(parseData[0].OrderUserGroup);
        getOrderFlag(parseData[0].OrderFlag);
      })
      .catch(() => {
        notificationController.error({
          message: translate("editOrder.failedToLoadOrderDetailsErrorMessage"),
        });
      });
  };

  const getOrderStatusList = () => {
    getOrderStatus()
      .then((response) => {
        const data: OrderStatusListProps[] = response?.StatusList;
        setOrderStatusList(data);
        setorderStatusSendEmail(response?.StatusList);
      })
      .catch(() => {
        notificationController.error({
          message: translate("editOrder.failedToLoadOrderStatusErrorMessage"),
        });
      });
  };

  const getOrderUserGroup = (orderDetail: IUserGroup[]) => {
    setOrderUserGroup(orderDetail);
  };

  const getOrderFlag = (orderDetail: IOrderFlag[]) => {
    const filteredOrderDetail = [
      ...orderDetail.filter((item) => !item.IsActiveOverridden),
      ...orderDetail.filter((item) => item.IsActiveOverridden),
    ];
    filteredOrderDetail.sort((a, b) => (a.DisplayOrder > b.DisplayOrder ? 1 : -1));

    setOrderFlag(filteredOrderDetail);
  };

  const getUnAssociatedOrderFlag = (isOpen = false) => {
    unAssociatedOrderFlagList(order?.OrderId)
      .then((response) => {
        setUnAssociatedOrderFlag(response?.OrderFlags);
        if (isOpen) {
          setIsModalVisible(true);
        }
      })
      .catch(() => {
        notificationController.error({
          message: translate("editOrder.failedToLoadOrderFlagErrorMessage"),
        });
      });
  };

  //Do not remove below warning
  // prettier-ignore
  const onUpdateOrder = async (action: string) => {
    //Add error message for user required
    if (!orderData?.userId) {
      setEditOrderError((prevState) => ({
        ...prevState,
        userError: translate("editOrder.userRequiredErrorMessage"),
      }));
      return false;
    }
    //Add error message for order type required
    if (!orderData?.orderTypeCode) {
      setEditOrderError((prevState) => ({
        ...prevState,
        orderTypeError: translate("editOrder.orderTypeRequiredErrorMessage"),
      }));
      return false;
    }
    const result = await handleValidationOnSaveButton(order?.OmsOrderStateId);
    const filterOpenFlags = orderStatusSendEmail?.filter((item) => {
      if (item.OmsOrderStateId == order?.OmsOrderStateId) return item;
    });
    if (
      (result.length === 0) ||
      (result?.[0] == "TriggerFinalizedDate") ||
      (result?.[0] == "ValidationNotFound") ||
      (result?.[0] == "SetOrderLineItem") ||
      (result?.[0] == "SetOrderAndFinalized") ||
      (result?.[0] == "SetOrderCompletenessAndFinalized" && result?.[1].length === 0) ||
      (result?.[0] == "SetOrderAndCompleteness" && result?.[1].length === 0) ||
      (result?.[0] == "CompletenessAndFinalized" && result?.[1].length === 0)
    ) {
      const updateOrderPayload: IUpdateOrder = {
        OrderId: order?.OrderId,
        PortalId: orderData?.storeId,
        AssignTo: orderData?.userId,
        AccountId: orderData?.accountId != null ? orderData?.accountId : 0,
        ClassCode: ORDER_CLASS,
        OrderOrigin: ORDER_ORIGIN,
        OmsOrderStateId: order?.OmsOrderStateId,
        IsSendEmail: filterOpenFlags[0]?.IsSendEmail,
        OrderTypeCode: orderData?.orderTypeCode,
        IsOrderTypeChanged: orderData?.isOrderTypeChanged || false,
        IsAccountTypeChanged: orderData?.isAccountTypeChanged || false,
        IsAssignedUserChanged: orderData?.isAssignedUserChanged || false,
      };
      updateOrder(updateOrderPayload)
        .then((response) => {
          if (response?.data?.IsSuccess) {
            if (preserveOrderStatus != order?.OmsOrderStateId) {
              checkOrderValidation(result, order?.OmsOrderStateId);
            }
            else{
              getOrderDetails();
              showSuccessMessage();
            }
            if (action === "close") {
              navigate(`/${ROUTES_PATH.ORDERS}`);
              setTimeout(() => {
                showSuccessMessage();
              }, 1000);
              return;
            } else {
              setIsCalledByEditOrder(true);
            }
          }
        })
        .catch(() => {
          notificationController.error({
            message: translate("editOrder.failedToUpdateRecordErrorMessage"),
          });
        });
    } else {
      //Show validation messages
      showValidationMessages(result.length > 1 ? result?.[1] : result);
    }
  };

  const openOrderFlagModal = () => {
    if (unAssociatedOrderFlag?.length <= 0) {
      getUnAssociatedOrderFlag(true);
    } else {
      setIsModalVisible(true);
    }
  };

  const handleAddOrderFlag = async () => {
    const flagId: string = selectedRowKeys?.join(",");
    const addOrderFlagPayload: IAddUpdateOrderFlag = {
      OrderId: order?.OrderId,
      UserId: readUserId(),
      CPOrderFlagId: flagId,
      OrderTypeCode: order?.OrderType,
    };
    await addOrderFlag(addOrderFlagPayload)
      .then(() => {
        setIsModalVisible(false);
        getOrderDetailsWithFlag();
        setSearchInput("");
        notificationController.success({
          message: translate("editOrder.flagAddedSuccessMessage"),
        });
      })
      .catch(() => {
        setIsModalVisible(false);
        notificationController.error({
          message: translate("editOrder.failedToAddFlagErrorMessage"),
        });
      });
    getUnAssociatedOrderFlag(false);
    setSelectedRowKeys([]);
  };

  const calculateOrder = () => {
    calculate(orderId)
      .then((response) => {
        const data: ICalculate = response?.Calculate;
        setOrderCalculation(data);
      })
      .catch(() => {
        notificationController.error({
          message: translate("editOrder.failedToLoadOrderDetailsErrorMessage"),
        });
      });
  };

  const getOrderStatusButtons = (omsOrderStateId: number) => {
    getOrderStatusButtonList(omsOrderStateId)
      .then((response) => {
        const data: IActionButtonList[] = response?.ActionButtonList;
        setStatusButtonList(data);
      })
      .catch(() => {
        notificationController.error({
          message: translate("editOrder.failedToLoadButtonListMessage"),
        });
      });
  };

  const getOrderClassButtons = (omsOrderStateId: number) => {
    getOrderClassButtonList(omsOrderStateId)
      .then((response) => {
        const data: IActionButtonList[] = response?.ActionButtonList;
        setClassButtonList(data);
      })
      .catch(() => {
        notificationController.error({
          message: translate("editOrder.failedToLoadButtonListMessage"),
        });
      });
  };

  const handleValidationOnDynamicButton = async (buttonId: number, buttonType: string) => {
    getButtonDetailById(buttonId, buttonType)
      .then(async (response) => {
        const buttonDetail: IActionButton = response?.ActionButton;
        const result = await handleValidationOnSaveButton(buttonDetail?.OmsOrderStateId);
        checkOrderValidation(result, buttonDetail?.OmsOrderStateId);
      })
      .catch(() => {
        notificationController.error({
          message: translate("editOrder.failedToGetButtonDetailsMessage"),
        });
      });
  };

  const handleValidationOnSaveButton = async (omsOrderStateId: number) => {
    const response = await getOrderStatusById(omsOrderStateId);
    const statusDetail: IOrderStatus = response?.OrderStatusDetail;
    if (
      statusDetail?.IsCPRequireCompleteness &&
      statusDetail?.IsCPTriggerFulfilledData &&
      statusDetail?.IsOrderLineItemState
    ) {
      const validationDetails = await onValidateOrder();
      return ["SetOrderCompletenessAndFinalized", validationDetails];
    } else if (statusDetail?.IsCPRequireCompleteness && statusDetail?.IsCPTriggerFulfilledData) {
      const validationDetails = await onValidateOrder();
      return ["CompletenessAndFinalized", validationDetails];
    } else if (statusDetail?.IsCPRequireCompleteness && statusDetail?.IsOrderLineItemState) {
      const validationDetails = await onValidateOrder();
      return ["SetOrderAndCompleteness", validationDetails];
    } else if (statusDetail?.IsCPRequireCompleteness) {
      return onValidateOrder();
    } else if (statusDetail?.IsCPTriggerFulfilledData && statusDetail?.IsOrderLineItemState) {
      return ["SetOrderAndFinalized"];
    } else if (statusDetail?.IsCPTriggerFulfilledData) {
      return ["TriggerFinalizedDate"];
    } else if (statusDetail?.IsOrderLineItemState) {
      return ["SetOrderLineItem"];
    } else {
      return ["ValidationNotFound"];
    }
  };

  const onUpdateOrderStatus = (
    omsOrderStateId: number,
    isOrderFinalized: boolean,
    isSetOrderLineItem: boolean
  ) => {
    const filterOpenFlags = orderStatusSendEmail?.filter((item) => {
      if (item.OmsOrderStateId == order?.OmsOrderStateId) return item;
    });
    const updateOrderPayload: IUpdateOrder = {
      OrderId: order?.OrderId,
      UserId: Number(readUserId()),
      OmsOrderStateId: omsOrderStateId,
      IsOrderFinalized: isOrderFinalized,
      IsSetOrderLineItem: isSetOrderLineItem,
      IsSendEmail: filterOpenFlags[0]?.IsSendEmail,
    };
    updateOrderStatusByOrderId(updateOrderPayload)
      .then(() => {
        getOrderDetails();
        showSuccessMessage();
      })
      .catch(() => {
        notificationController.error({
          message: translate("editOrder.failedToUpdateOrderMessage"),
        });
      });
  };

  const getShippingDetails = () => {
    httpApi
      .get("/shipping/getshippingdetailsbyorderid" + "/" + orderId)
      .then((response) => {
        const data = JSON.parse(response?.data?.OrderShipment?.OrderDetail)[0].OrderShipment[0];
        if (data?.ShipDate) {
          setOrder((prevState) => ({
            ...prevState,
            ShipDate: data?.ShipDate,
          }));
        }
      })
      .catch(() => {
        notificationController.error({
          message: translate("editOrder.failedToLoadOrderDetailsErrorMessage"),
        });
      });
  };

  const showValidationMessages = (result: string[]) => {
    notificationController.error({
      message: (
        <Space direction="vertical" size={1}>
          {result.map((item: string, i: number) => {
            return (
              <div key={i} className="validation-msg">
                <InfoCircleOutlined
                  style={{ marginRight: "8px" }}
                  onClick={() => notification.destroy()}
                />
                {item}
              </div>
            );
          })}
        </Space>
      ),
      placement: "topRight",
      className: "top-120 notification-without-description error-notification",
      duration: 0,
    });
  };

  const onValidateOrder = () => {
    return validateOrder(orderId)
      .then(async (response) => {
        return response?.ValidationMessages;
      })
      .catch(() => {
        notificationController.error({
          message: translate("editOrder.failedToGetValidationDetailsMessage"),
        });
      });
  };

  const toPaymentJson = (orderCalculation: ICalculate) => {
    return {
      DiscountAmount:
        orderCalculation.Discount +
        orderCalculation.CSRDiscountAmount +
        orderCalculation.VoucherAmount,
      ShippingCost: orderCalculation.ShippingCost,
      ShippingDiscount: orderCalculation.ShippingDiscount,
      TaxCost: orderCalculation.TaxCost,
      SubTotal: orderCalculation.SubTotal,
      Total: orderCalculation.Total,
      ShippingHandlingCharges: orderCalculation.HandlingFee,
    };
  };

  const toProductJson = (productList: IProductList[]) => {
    return productList?.map((item) => {
      return {
        OrderProductId: item.OrderProductId,
        Price: item.Price,
      };
    });
  };

  const getOrderStatusDetailByStatusId = (OmsOrderStateId: number) => {
    return getOrderStatusById(OmsOrderStateId)
      .then((response) => {
        const statusDetail: IOrderStatus = response?.OrderStatusDetail;
        dispatch(
          getPermissions({
            allowEditing: statusDetail?.IsEdit || false,
          })
        );
      })
      .catch(() => {
        notificationController.error({
          message: translate("editOrder.failedToLoadOrderStatusErrorMessage"),
        });
      });
  };

  const onRequireCompleteness = (omsOrderStateId: number, restrictGetOrderDetailsCall = true) => {
    //Update order status, product price, and order total
    const finalizedData = orderStatusList?.find((el: OrderStatusListProps) => {
      return el?.OmsOrderStateId == omsOrderStateId.toString();
    });
    const completeOrderPayload: ICompleteOrder = {
      OrderId: order?.OrderId,
      PaymentData: JSON.stringify([toPaymentJson(orderCalculation)]),
      ProductDetail: JSON.stringify(toProductJson(productList)),
      OrderStateId: omsOrderStateId,
      IsFinalized: finalizedData==undefined ? false :finalizedData.IsCPRequireCompleteness,
    };
    //Complete Order
    completeOrder(completeOrderPayload)
      .then(() => {
        restrictGetOrderDetailsCall && getOrderDetails();
        notificationController.success({
          message: translate("editOrder.orderCompletedSuccessMessage"),
        });
      })
      .catch(() => {
        notificationController.error({
          message: translate("editOrder.failedToUpdateRecordErrorMessage"),
        });
      });
  };

  const handleBack = () => {
    navigate(`/${ROUTES_PATH.ORDERS}`);
  };

  const checkOrderValidation = (result: string | string[], omsOrderStateId: number) => {
    if (result?.[0] == "SetOrderCompletenessAndFinalized") {
      if (result?.[1].length === 0) {
        //If RequireCompleteness flag is true
        onRequireCompleteness(omsOrderStateId, false);

        //Update order level status, line item level status, and finalized date
        onUpdateOrderStatus(omsOrderStateId, true, true);

        //Bind product list if SetOrderItem flag is true
        setIsCalledByEditOrder(true);
      }
      //Show validation messages
      else {
        if (typeof result[1] == "object") {
          showValidationMessages(result[1]);
        }
      }
    } else if (result?.[0] == "SetOrderAndCompleteness") {
      if (result?.[1].length === 0) {
        //If RequireCompleteness flag is true
        onRequireCompleteness(omsOrderStateId, false);

        //Update both order level status and line item level status
        onUpdateOrderStatus(omsOrderStateId, false, true);

        //Bind product list if SetOrderItem flag is true
        setIsCalledByEditOrder(true);
      }
      //Show validation messages
      else {
        if (typeof result[1] == "object") {
          showValidationMessages(result[1]);
        }
      }
    } else if (result?.[0] == "CompletenessAndFinalized") {
      if (result?.[1].length === 0) {
        //If RequireCompleteness flag is true
        onRequireCompleteness(omsOrderStateId, false);

        //Update both status and finalized date
        onUpdateOrderStatus(omsOrderStateId, true, false);
      }
      //Show validation messages
      else {
        if (typeof result[1] == "object") {
          showValidationMessages(result[1]);
        }
      }
    } else if (result?.[0] == "TriggerFinalizedDate") {
      //Update both status and finalized date
      onUpdateOrderStatus(omsOrderStateId, true, false);
    } else if (result?.[0] == "ValidationNotFound") {
      //Update only status
      onUpdateOrderStatus(omsOrderStateId, false, false);
    } else if (result?.[0] == "SetOrderAndFinalized") {
      //Update order level status, line item level status, and finalized date
      onUpdateOrderStatus(omsOrderStateId, true, true);

      //Bind product list if SetOrderItem flag is true
      setIsCalledByEditOrder(true);
    } else if (result?.[0] == "SetOrderLineItem") {
      //Update both order and line item level status
      onUpdateOrderStatus(omsOrderStateId, false, true);

      //Bind product list if SetOrderItem flag is true
      setIsCalledByEditOrder(true);
    } else if (result.length === 0) {
      //If RequireCompleteness flag is true
      onRequireCompleteness(omsOrderStateId);
    } else {
      //Show validation messages
      if (typeof result == "object") {
        showValidationMessages(result);
      }
    }
  };

  const showSuccessMessage = () => {
    notificationController.success({
      message: translate("editOrder.recordUpdatedSuccessMessage"),
    });
  };

  const handleLineItemsValidationOnStatusChange = async (
    omsOrderStateId: number,
    orderId: string,
    orderProductId: string
  ) => {
    const response = await getOrderStatusById(omsOrderStateId);
    const statusDetail: IOrderStatus = response?.OrderStatusDetail;

    if (statusDetail?.IsCPRequireCompleteness && statusDetail?.IsOrderLineItemState) {
      const validationDetails = await onValidateOrderLineItems(orderId, orderProductId);
      return ["SetOrderAndCompleteness", validationDetails];
    } else if (statusDetail?.IsCPRequireCompleteness) {
      return await onValidateOrderLineItems(orderId, orderProductId);
    } else if (statusDetail?.IsOrderLineItemState) {
      return ["SetOrderLineItem"];
    } else {
      return ["ValidationNotFound"];
    }
  };

  const onValidateOrderLineItems = (orderId: string, orderProductId: string) => {
    return validateOrderLineItems(orderId, orderProductId)
      .then(async (response) => {
        return response?.ValidationMessages;
      })
      .catch(() => {
        notificationController.error({
          message: translate("editOrder.failedToGetValidationDetailsMessage"),
        });
      });
  };

  return (
    <>
      {showEditOrder && (
        <div
          className={
            priceNoteChangeInfo?.visible
              ? "order-details-container disabled-container"
              : "order-details-container"
          }
        >
          <EditOrderTitleHeader
            backClickHandler={handleBack}
            title={
              <Space direction="vertical" size={0} align="start">
                <div className="edit-order-header-title">{`Order - ${
                  orderData?.orderTypeName || ""
                }`}</div>
                <Space size={10} align="start">
                  <Title level={2} className="m-0 line-height-inherit">
                    {order?.ClassNumber}
                  </Title>
                  <div className="mt-5">
                    <StatusTag
                      text={order?.OrderStateName}
                      tagStyle={getStatusDropDownStyle(
                        orderStatusList,
                        order?.OrderStateName,
                        "OrderStateName"
                      )}
                      dataTestSelector="tagOrderStatus"
                    />
                  </div>
                </Space>
              </Space>
            }
            isBack={true}
            rhsContent={checkPermissionToShow(
              isEditPermission,
              <ActionButtons
                statusButtonList={statusButtonList}
                classButtonList={classButtonList}
                onClick={handleValidationOnDynamicButton}
                onUpdateOrder={onUpdateOrder}
                notesChildRef={notesChildRef?.current?.refetchTheNotesList()}
                getOrderDetails={getOrderDetails}
              />
            )}
          />
          <div className="mt-8">
            <AssignedTo
              order={order}
              setOrder={setOrder}
              groups={orderUserGroup || []}
              setOrderUserGroup={setOrderUserGroup}
              notesChildRef={notesChildRef?.current?.refetchTheNotesList()}
              getOrderDetails={getOrderDetails}
            />
          </div>
          <div className="collapse-container">
            <CollapseComponent
              size="small"
              title={
                <OrderSummaryHeader
                  orderDetails={order}
                  orderStatusList={orderStatusList}
                  setOrder={setOrder}
                  orderTotal={orderCalculation?.Total}
                  notesChildRef={notesChildRef?.current?.refetchTheNotesList()}
                />
              }
              defaultActiveKey={"1"}
              dataTestSelector="collapseOrderSummary"
            >
              <OrderSummaryContent
                orderDetails={order}
                setOrderData={setOrderData}
                orderData={orderData}
                editOrderError={editOrderError}
                setEditOrderError={setEditOrderError}
                orderCalculation={orderCalculation}
                getOrderDetailsWithFlag={getOrderDetailsWithFlag}
                initialOrderTypeCode={initialOrderTypeCode}
                initialAccountId={initialAccountId}
                initialAssignedUserId={initialAssignedUserId}
              />
            </CollapseComponent>
          </div>
          <div className="collapse-container">
            <CollapseComponent
              size="small"
              title={
                <OrderFlagsHeader openOrderFlagModal={openOrderFlagModal} orderFlags={orderFlag} />
              }
              dataTestSelector="collapseOrderFlags"
            >
              <OrderFlagsContent
                orderFlags={orderFlag}
                getUnAssociatedOrderFlag={getUnAssociatedOrderFlag}
                getOrderDetailsWithFlag={getOrderDetailsWithFlag}
                notesChildRef={notesChildRef?.current?.refetchTheNotesList()}
                getOrderDetails={getOrderDetails}
              />
            </CollapseComponent>
          </div>
          <div className="collapse-container">
            <TabComponent
              defaultActiveKey="1"
              onTabClick={(key: string) => {
                if (key == "4") {
                  /**
                   * key : 4 - NotesAndLog
                   * Fetch the notes and logs list every time
                   * on the Notes/Tab item clicked.
                   */
                  notesChildRef?.current?.refetchTheNotesList();
                }
              }}
              items={[
                {
                  key: "1",
                  label: translate("editOrder.productTabLabel"),
                  children: (
                    <ProductList
                      orderStatusList={orderStatusList}
                      productList={productList}
                      setProductList={setProductList}
                      calculateOrder={calculateOrder}
                      isCalledByEditOrder={isCalledByEditOrder}
                      setIsCalledByEditOrder={setIsCalledByEditOrder}
                      handleLineItemsValidationOnStatusChange={
                        handleLineItemsValidationOnStatusChange
                      }
                      showValidationMessages={showValidationMessages}
                      getOrderDetails={getOrderDetails}
                    />
                  ),
                },
                {
                  key: "2",
                  label: translate("editOrder.shippingTabLabel"),
                  children: (
                    <Shipping
                      order={order}
                      setOrder={setOrder}
                      orderData={orderData}
                      calculateOrder={calculateOrder}
                      productList={productList}
                      getOrderDetails={getOrderDetails} 
                      userId = {orderData?.userId}
                    />
                  ),
                },
                {
                  key: "3",
                  children: (
                    <Payment
                      order={order}
                      orderData={orderData}
                      calculateOrder={calculateOrder}
                      orderCalculation={orderCalculation}
                      getOrderDetails={getOrderDetails}
                    />
                  ),
                  label: translate("editOrder.paymentTabLabel"),
                },
                {
                  key: "4",
                  label: translate("editOrder.notesTabLabel"),
                  children: (
                    <NotesAndLog
                      OrderNotes={order}
                      ref={notesChildRef}
                      getOrderDetails={getOrderDetails}
                    />
                  ),
                },
              ]}
            />
          </div>
          <ModalComponent
            title={translate("editOrder.addOrderFlagsTitle")}
            visible={isModalVisible}
            onOK={() => {
              if (selectedRowKeys && selectedRowKeys.length) {
                handleAddOrderFlag();
                getOrderDetails();
              }
            }}
            onCancel={() => {
              setIsModalVisible(false);
              setSelectedRowKeys([]);
              setSearchInput("");
            }}
            okText={translate("editOrder.saveBtn")}
            cancelText={translate("editOrder.cancelBtn")}
            bodyStyle={{
              overflowY: "hidden",
              minHeight: "300px",
            }}
            dataTestSelector="popAddOrderFlags"
            modalWidth="450px"
            zIndex={10}
            isMaskClosable={false}
            className="standard-modal edit-order-flag-model"
          >
            <OrderFlagsList
              unAssociatedOrderFlag={unAssociatedOrderFlag}
              selectedRowKeys={selectedRowKeys}
              setSelectedRowKeys={setSelectedRowKeys}
              setSearchInput={setSearchInput}
              searchInput={searchInput}
            />
          </ModalComponent>
        </div>
      )}
    </>
  );
};
export default EditOrder;
