/* eslint-disable react-hooks/rules-of-hooks */
/* eslint-disable max-len */
/* eslint-disable indent */
import React, { Dispatch, SetStateAction } from "react";
import { CloseCircleOutlined, EditOutlined } from "@ant-design/icons";
import { Button, Input, Popover, Space, Typography } from "antd";
import { ILogsData } from "interfaces/APIInterface/IOrderNote";
import { translate } from "i18n";
import { getUserDetails } from "api/services/localStorage.service";
import { convertDate, convertDateTime, convertTime } from "utils";
const { TextArea } = Input;
const userData = getUserDetails() ? JSON.parse(getUserDetails() || "") : {};
const initials = userData?.FirstName + " " + userData?.LastName;
const { Text } = Typography;
export const columnsList = [
  {
    title: translate("editOrder.dateTitle"),
    dataIndex: "CreatedDate",
    key: "CreatedDate",
    render: (createdDate: string) => <span>{convertDate(createdDate)}</span>,
  },
  {
    title: translate("editOrder.timeTitle"),
    dataIndex: "CreatedDate",
    key: "CreatedDate",
    render: (createdDate: string) => <span>{convertTime(createdDate)}</span>,
  },
  {
    title: translate("editOrder.createdByTitle"),
    dataIndex: "CreatedByFullName",
    key: "CreatedByFullName",
  },
  {
    title: translate("editOrder.noteDetailsTitle"),
    dataIndex: "Note",
    key: "Note",
    width: "45%",
    render: (notes: string, record: ILogsData) => (
      <span>{(record?.PrefixNote || "") + record.Note}</span>
    ),
  },
];

// eslint-disable-next-line no-unused-vars
export const columns = (
  // eslint-disable-next-line no-unused-vars
  actionHandler: (data: ILogsData, actionType: string) => void,
  notes: string,
  setNotes: Dispatch<SetStateAction<string>>,
  openAddNotes: boolean,
  setOpenAddNotes: Dispatch<SetStateAction<boolean>>,
  editData: string,
  newViewValidation: string,
  setNewViewValidation: Dispatch<SetStateAction<string>>,
  isEditPermission: boolean
) => {
  const cols = [
    ...columnsList,
    {
      key: "action",
      title: translate("editOrder.tblActionsColumnLabel"),
      dataIndex: "Actions",
      sorter: false,
      hidden: false,

      render: (text: string, record: ILogsData) => {
        return (
          <>
            <Space size="middle">
              <Popover
                title=""
                content={
                  <Space className="m-0" size={16} direction="vertical">
                    <div>
                      {translate("editOrder.createdTitle")} :{" "}
                      <span>{convertDateTime(record.CreatedDate)}</span>,
                    </div>
                    <div>
                      {translate("editOrder.createdByTitle")} : {record.CreatedByFullName}
                    </div>
                    <TextArea
                      value={notes}
                      onChange={(e) => {
                        setNotes(e.target.value);
                        setNewViewValidation("");
                      }}
                      placeholder={translate("editOrder.addNotesPlaceholder")}
                      rows={3}
                      data-test-selector="txtNotes"
                      style={{ width: 280 }}
                    />
                    {newViewValidation == "" ? (
                      ""
                    ) : (
                      <Space>
                        {" "}
                        <Text type="danger">{newViewValidation}</Text>
                      </Space>
                    )}
                    <Space>
                      <Button
                        size="middle"
                        type="primary"
                        data-test-selector="btnAddNote"
                        onClick={() =>
                          notes == ""
                            ? setNewViewValidation(translate("editOrder.RequireOrderNote"))
                            : actionHandler(record, "save")
                        }
                      >
                        {translate("editOrder.saveNoteBtn")}
                      </Button>
                      <Button
                        size="middle"
                        type="default"
                        data-test-selector="btnAddNote"
                        onClick={() => actionHandler(record, "cancel")}
                      >
                        {translate("editOrder.cancelBtn")}
                      </Button>
                    </Space>
                  </Space>
                }
                trigger="click"
                open={openAddNotes && editData == record?.OrderNoteId}
                placement="bottomLeft"
                onOpenChange={(newOpen: boolean) => {
                  setOpenAddNotes(newOpen);
                }}
              >
                {!record?.IsSystemDefine && initials == record?.CreatedByFullName && (
                  <EditOutlined
                    style={{ color: "blue" }}
                    onClick={() => actionHandler(record, "edit")}
                  />
                )}
              </Popover>
              {!record?.IsSystemDefine && initials == record?.CreatedByFullName && (
                <CloseCircleOutlined
                  style={{ color: "blue" }}
                  onClick={() => actionHandler(record, "delete")}
                />
              )}
            </Space>
          </>
        );
      },
    },
  ];

  return isEditPermission
    ? cols
    : cols.filter((el) => {
        return el.dataIndex != "Actions";
      });
};
