/* eslint-disable max-len */
/* eslint-disable max-lines-per-function */
import React, { forwardRef, useEffect, useImperativeHandle, useState } from "react";
import { Space, Table } from "antd";
import { columns } from "./NotesAndLog.Constant";
import NotesListHeader from "./NotesListHeader";
import { ArrowLeftOutlined } from "@ant-design/icons";
import { notificationController } from "components/Common/Notification/Notification";
import {
  IExportParams,
  ILogsData,
  IOrderNoteFilters,
  IOrderNoteUpdateParams,
  IOrderNotesForEditOrder,
  IOrderNotesParams,
  filterTools,
} from "interfaces/APIInterface/IOrderNote";
import {
  createNote,
  deleteOrderNote,
  getExportOrderNote,
  getOrderNote,
  getOrderNoteFilters,
  updateOrderNote,
} from "api/services/orderNote.api";
import { translate } from "i18n";
import ModalComponent from "components/Common/Modal/Modal";
import { getUserDetails } from "api/services/localStorage.service";
import { ViewAll } from "config/constant";
import { useAppSelector } from "hooks/reduxHooks";

/**
 * @returns The `NotesAndLog` component is being returned.
 * This is a functional component that renders a notes list
 * using the antd table with data source.
 */
const NotesAndLog = forwardRef((props: IOrderNotesForEditOrder, ref) => {
  /**
   * added ref to refresh the notes and log list every time
   * on the Notes/Log TabItem clicked.
   */
  useImperativeHandle(ref, () => ({
    refetchTheNotesList: refetchTheNotesList,
  }));

  const { OrderNotes, getOrderDetails } = props;
  const isEditPermission = useAppSelector((state) => state.permission.isEditPermission);
  const [data, setData] = useState<ILogsData[]>([]);
  const [openAddNotes, setOpenAddNotes] = useState(false);
  const [notes, setNotes] = useState("");
  const [editData, setEditData] = useState("");
  const [selectedRowKeys, setSelectedRowKeys] = useState<React.Key[]>([]);
  const [orderNoteFilter, setOrderNoteFilter] = useState<IOrderNoteFilters>(
    {} as IOrderNoteFilters
  );
  const [isConfirmModalVisible, setIsConfirmModalVisible] = useState<boolean>(false);
  const [OrderNoteId, setOrderNoteId] = useState<string>("");
  const [selectdOrderNote, setSelectedOrderNote] = useState<string>(ViewAll || "");
  const userData = getUserDetails() ? JSON.parse(getUserDetails() || "") : {};
  const initials = userData?.FirstName + " " + userData?.LastName;
  const [newViewValidation, setNewViewValidation] = useState("");
  const [filteruse, setfilteruse] = useState(ViewAll);

  useEffect(() => {
    fetchLogsAndNotes("");
    // eslint-disable-next-line react-hooks/exhaustive-deps
  }, []);

  const refetchTheNotesList = () => {
    fetchLogsAndNotes("");
  };

  const rowSelection = {
    selectedRowKeys,
    onChange: (selectedRowKeys: React.Key[]) => {
      setSelectedRowKeys(selectedRowKeys);
    },
    getCheckboxProps: (record: ILogsData) => {
      return {
        disabled: record?.IsSystemDefine || initials != record?.CreatedByFullName, //enable first 2 rows only
      };
    },
  };
  const orderNoteFiltersEvent = (OrderNoteFilteritem: string) => {
    setSelectedOrderNote(OrderNoteFilteritem);
    const filtercode = OrderNoteFilteritem.split("(");
    const filterName = filtercode[0];
    setfilteruse(filterName);
    fetchLogsAndNotes(filterName);
  };
  const onDeleteItemPress = (data: string) => {
    if (selectedRowKeys?.length) {
      const deleteNotebody: IOrderNotesParams = {
        MappingId: OrderNotes.MappingId,
        TypeOfMapping: OrderNotes.TypeOfMapping,
        OrderNoteIds: data,
        IsDeleted: true,
        ClassId: OrderNotes.ClassId,
        UserId: OrderNotes.UserId,
        Note: "",
        Message: translate("editOrder.deleteNoteMessage") + OrderNotes.ClassNumber,
        ViewFilter: "",
        OrderId: OrderNotes.OrderId
      };
      deleteOrderNote(deleteNotebody)
        .then((response) => {
          if (response.IsSuccess) {
            fetchLogsAndNotes(deleteNotebody.ViewFilter);
            notificationController.success({
              message: translate("editOrder.orderNoteDeleteSuccessMessage"),
              placement: "top",
            });
            setIsConfirmModalVisible(false);
          }
        })
        .catch((err) => {
          notificationController.error({ message: err.message });
        });
    } else {
      notificationController.error({
        message: translate("editOrder.SelectAnyCheckBox"),
      });
    }
  };
  const onDeleteOrderNote = (data: string) => {
    const deleteNotebody: IOrderNotesParams = {
      MappingId: OrderNotes.MappingId,
      OrderId: OrderNotes.OrderId,
      TypeOfMapping: OrderNotes.TypeOfMapping,
      OrderNoteIds: data,
      IsDeleted: true,
      ClassId: OrderNotes.ClassId,
      UserId: OrderNotes.UserId,
      Note: "",
      Message: translate("editOrder.deleteNoteMessage") + OrderNotes.ClassNumber,
      ViewFilter: "",
    };
    deleteOrderNote(deleteNotebody)
      .then((response) => {
        if (response.IsSuccess) {
          fetchLogsAndNotes(deleteNotebody.ViewFilter);
          notificationController.success({
            message: translate("editOrder.orderNoteDeleteSuccessMessage"),
            placement: "top",
          });
          setIsConfirmModalVisible(false);
        }
      })
      .catch((err) => {
        notificationController.error({ message: err.message });
      });
  };
  const onExportOrderNote = (data: string) => {
    const exportBody: IExportParams = {
      OrderId: OrderNotes?.OrderId,
      FileType: data,
      ViewFilter: filteruse,
    };
    getExportOrderNote(exportBody);
  };

  const getFilterList = () => {
    const getFilterPayload = {
      OrderId: OrderNotes?.OrderId,
    };
    getOrderNoteFilters(getFilterPayload)
      .then((response) => {
        const data = response?.OrderLogFilters?.[0];
        setOrderNoteFilter({
          OrderNotes: data?.OrderNotes,
          OrderStatusChanges: data?.OrderStatusChanges,
          OwnerShipChanges: data?.OwnerShipChanges,
          FlagChanges: data?.FlagChanges,
          PriceChanges: data?.PriceChanges,
          AllChanges: data?.AllChanges,
          ViewAll: data?.ViewAll,
        });
      })
      .catch((err) => {
        notificationController.error({ message: err.message });
      });
  };
  const fetchLogsAndNotes = (data: string) => {
    const getNotePayload: IOrderNotesParams = {
      MappingId: OrderNotes?.MappingId,
      OrderId: OrderNotes?.OrderId,
      TypeOfMapping: OrderNotes?.TypeOfMapping,
      ClassId: 0,
      UserId: 0,
      Note: "",
      OrderNoteIds: "",
      IsDeleted: false,
      Message: "",
      ViewFilter: data,
    };
    getOrderNote(getNotePayload)
      .then((response) => {
        const data: ILogsData[] = response?.OrderLogs;
        setData(data);
        getFilterList();
      })
      .catch((err) => {
        notificationController.error({ message: err.message });
      });
  };

  const manageNotes = (payload: IOrderNotesParams, onCancelOrderNotes: () => void) => {
    const createNotePayload: IOrderNotesParams = {
      MappingId: payload.OrderId,
      OrderId: payload.OrderId,
      TypeOfMapping: "Orders",
      ClassId: payload.ClassId,
      UserId: payload.UserId,
      Note: payload.Note,
      OrderNoteIds: "",
      IsDeleted: false,
      Message: "",
      ViewFilter: "",
    };
    createNote(createNotePayload)
      .then((response) => {
        if (response.IsSuccess) {
          fetchLogsAndNotes(createNotePayload.ViewFilter);
          notificationController.success({
            message: translate("editOrder.orderNoteCreatedSuccessMessage"),
            placement: "top",
          });
          onCancelOrderNotes && onCancelOrderNotes();
        }
      })
      .catch((err) => {
        notificationController.error({ message: err.message });
      });
  };

  const mangeTools = (payload: filterTools) => {
    if (payload.ToolType == "delete") {
      const orderNoteId = selectedRowKeys.join(",");
      onDeleteItemPress(orderNoteId);
    } else if (payload.ToolType == "Export to CSV") {
      onExportOrderNote(payload.ToolType);
    } else if (payload.ToolType == "Export to Excel") {
      onExportOrderNote(payload.ToolType);
    }
  };
  const updateNotes = (noteId: string) => {
    const createNotePayload: IOrderNoteUpdateParams = {
      OrderId: OrderNotes?.OrderId,
      ClassId: OrderNotes?.ClassId,
      UserId: OrderNotes?.UserId,
      OrderNoteId: noteId,
      Note: notes,
    };
    updateOrderNote(createNotePayload)
      .then((response) => {
        if (response.IsSuccess) {
          const ViewFilter = "";
          fetchLogsAndNotes(ViewFilter);
          notificationController.success({
            message: translate("editOrder.orderNoteUpdateSuccessMessage"),
            placement: "top",
          });
        }
      })
      .catch((err) => {
        notificationController.error({ message: err.message });
      });
  };

  const actionHandler = (data: ILogsData, actionType: string) => {
    if (actionType == "edit") {
      setEditData(data.OrderNoteId);
      setNotes(data?.Note);
      setOpenAddNotes(true);
    } else if (actionType == "delete") {
      setOrderNoteId(data?.OrderNoteId);
      setIsConfirmModalVisible(true);
    } else if (actionType == "save") {
      if (data?.Note) {
        updateNotes(data.OrderNoteId);
        setOpenAddNotes(false);
        setNewViewValidation("");
      }
    } else if (actionType == "cancel") {
      setOpenAddNotes(false);
      setNewViewValidation("");
    }
  };

  const deleteHandler = () => {
    onDeleteOrderNote(OrderNoteId);
  };

  const cols = columns(
    actionHandler,
    notes,
    setNotes,
    openAddNotes,
    setOpenAddNotes,
    editData,
    newViewValidation,
    setNewViewValidation,
    isEditPermission
  );

  return (
    <div className="px-15 pt-8">
      <Table
        title={() => (
          <NotesListHeader
            OrderNotes={OrderNotes}
            manageNotes={manageNotes}
            mangeTools={mangeTools}
            orderNoteFilter={orderNoteFilter}
            orderNoteFiltersEvent={orderNoteFiltersEvent}
            selectdOrderNote={selectdOrderNote}
            newViewValidation={newViewValidation}
            setNewViewValidation={setNewViewValidation}
            getOrderDetails={getOrderDetails}
          />
        )}
        dataSource={data}
        columns={cols}
        rowKey={(record) => record.OrderNoteId}
        data-test-selector="tblProductList"
        pagination={{ position: ["bottomLeft"] }}
        scroll={{ y: 350 }}
        size={"small"}
        rowSelection={{
          type: "checkbox",
          ...rowSelection,
        }}
      />
      <ModalComponent
        title={translate("editOrder.confirmDeleteTitle")}
        visible={isConfirmModalVisible}
        onOK={() => {
          deleteHandler();
        }}
        onCancel={() => {
          setIsConfirmModalVisible(false);
        }}
        okText={translate("editOrder.tblOkColumnLabel")}
        cancelText={
          <Space className="d-flex justify-center align-center">
            <ArrowLeftOutlined />
            <span>{translate("editOrder.backBtn")}</span>
          </Space>
        }
        dataTestSelector="popConfirm"
        zIndex={10}
        isMaskClosable={true}
        className="standard-modal"
      >
        {translate("editOrder.deleteNoteConfirmation")}
      </ModalComponent>
    </div>
  );
});

export default NotesAndLog;
