/* eslint-disable max-lines */
/* eslint-disable max-len */
/* eslint-disable max-lines-per-function */
import React, { useEffect, useState } from "react";
import { Button, Dropdown, MenuProps, Popover, Row, Space, Typography, Input } from "antd";
import { PlusOutlined, CaretDownOutlined } from "@ant-design/icons";
import { checkPermissionToShow, isObjectEmpty } from "utils";
import { translate } from "i18n";
import { IOrderNotes } from "interfaces/ClientInterface/IOrderNote";
import { useAppSelector } from "hooks/reduxHooks";
const { Text } = Typography;
const { TextArea } = Input;

/**
 *
 * @returns This code exports a React functional component called
 * `NotesListHeader`. The component returns a JSX element that renders
 *  a header for a notes list table.
 */
export default function NotesListHeader({
  OrderNotes,
  manageNotes,
  mangeTools,
  orderNoteFilter,
  orderNoteFiltersEvent,
  // eslint-disable-next-line no-unused-vars
  selectdOrderNote,
  setNewViewValidation,
  newViewValidation,
  getOrderDetails,
}: IOrderNotes) {
  const isEditPermission = useAppSelector((state) => state.permission.isEditPermission);
  const [openAddNotes, setOpenAddNotes] = useState(false);
  const [notes, setNotes] = useState("");
  const [filters, setFilters] = useState<string[]>([]);

  useEffect(() => {
    if (!isObjectEmpty(orderNoteFilter)) {
      setFilters([
        `Order Notes (${orderNoteFilter?.OrderNotes})`,
        `Order Status Changes (${orderNoteFilter?.OrderStatusChanges})`,
        `Ownership Changes (${orderNoteFilter?.OwnerShipChanges})`,
        `Flag Change (${orderNoteFilter?.FlagChanges})`,
        `Price Changes (${orderNoteFilter?.PriceChanges})`,
        `All Changes (${orderNoteFilter?.AllChanges})`,
        `View All (${orderNoteFilter?.ViewAll})`,
      ]);
    }
  }, [orderNoteFilter]);

  const items: MenuProps["items"] = [
    {
      label: (
        <div
          onClick={() => {
            DeleteHandler("delete");
            getOrderDetails();
          }}
        >
          {translate("editOrder.deleteLabel")}
        </div>
      ),
      key: "delete",
      className: !isEditPermission ? "display-none" : "",
    },
    {
      label: (
        <div onClick={() => DeleteHandler("Export to CSV")}>
          {translate("editOrder.exportCsvLabel")}
        </div>
      ),
      key: "Export to CSV",
    },
    {
      label: (
        <div onClick={() => DeleteHandler("Export to Excel")}>
          {translate("editOrder.exportToExcelLabel")}
        </div>
      ),
      key: "Export to Excel",
    },
  ];
  const handleOpen = () => {
    setOpenAddNotes(true);
  };
  const handleOpenChange = (newOpen: boolean) => {
    setOpenAddNotes(newOpen);
    setNotes("");
  };

  const DeleteHandler = (action: string) => {
    const data = {
      ToolType: action,
    };
    mangeTools && mangeTools(data);
  };

  const onCancelOrderNotes = () => {
    setNotes("");
    setOpenAddNotes(false);
    setNewViewValidation("");
  };
  const handleOrderNote = (note: string) => {
    const data = {
      MappingId: OrderNotes.MappingId,
      OrderId: OrderNotes.OrderId,
      TypeOfMapping: OrderNotes.TypeOfMapping,
      ClassId: OrderNotes.ClassId,
      UserId: OrderNotes.UserId,
      Note: note,
      OrderNoteIds: "",
      IsDeleted: false,
      Message: "",
      ViewFilter: "",
      PrefixNote: "",
    };
    manageNotes && manageNotes(data, onCancelOrderNotes);
  };
  const onHandleFilters = (item: string) => {
    orderNoteFiltersEvent && orderNoteFiltersEvent(item);
  };
  const onAddNotesAndLogs = (value: string) => {
    if (value != "") {
      setNotes(value);
      setNewViewValidation("");
    }
  };

  return (
    <Row justify={"space-between"} align={"middle"} className="pb-8">
      <Space size={10}>
        {checkPermissionToShow(
          isEditPermission,
          <>
            <Popover
              title=""
              content={
                <Space className="m-0" size={16} direction="vertical">
                  <TextArea
                    value={notes}
                    onChange={(e) => onAddNotesAndLogs(e.target.value)}
                    placeholder={translate("editOrder.addNotesPlaceholder")}
                    rows={3}
                    data-test-selector="txtNotes"
                    style={{ width: 280 }}
                  />
                  {newViewValidation == "" ? (
                    ""
                  ) : (
                    <Space>
                      <Text type="danger">{newViewValidation}</Text>
                    </Space>
                  )}
                  <Space>
                    <Button
                      size="middle"
                      type="primary"
                      data-test-selector="btnAddNote"
                      onClick={() => {
                        notes == ""
                          ? setNewViewValidation(translate("editOrder.RequireOrderNote"))
                          : handleOrderNote(notes);
                        getOrderDetails();
                      }}
                    >
                      {translate("editOrder.addNoteBtn")}
                    </Button>
                    <Button size="middle" onClick={onCancelOrderNotes}>
                      {translate("editOrder.cancelBtn")}
                    </Button>
                  </Space>
                </Space>
              }
              trigger="click"
              open={openAddNotes}
              placement="bottomLeft"
              onOpenChange={handleOpenChange}
            >
              <Button
                size="small"
                type="primary"
                icon={<PlusOutlined />}
                data-test-selector="btnAddNote"
                onClick={handleOpen}
              >
                {translate("editOrder.addNoteBtn")}
              </Button>
            </Popover>
            <span>|</span>
          </>
        )}
        {filters &&
          filters.map((el: string, i: number) => {
            return (
              <div
                key={`chip${i}`}
                className={
                  el?.includes(selectdOrderNote)
                    ? "filter-chips-active cursor-pointer"
                    : "filter-chips-view cursor-pointer"
                }
                onClick={() => onHandleFilters(el)}
              >
                {el}
              </div>
            );
          })}
      </Space>
      <Space size={20}>
        <Dropdown
          menu={{ items }}
          trigger={["click"]}
          getPopupContainer={(triggerNode: HTMLElement) => triggerNode.parentNode as HTMLElement}
        >
          <Space className="title-name cursor-pointer">
            {translate("editOrder.toolsTitle")}
            <CaretDownOutlined />
          </Space>
        </Dropdown>
      </Space>
    </Row>
  );
}
