import React from "react";
import { Col, Row, Space, Button } from "antd";
import { Typography } from "antd";
import TagComponent from "components/Common/Tag/Tag";
import { PlusOutlined } from "@ant-design/icons";
import { IOrderFlagsHeaderProps, IOrderFlagCount } from "interfaces/ClientInterface/IOrderFlag";
import { translate } from "i18n";
import { checkPermissionToShow } from "utils";
import { useAppSelector } from "hooks/reduxHooks";
const { Text } = Typography;

/**
 * @returns This React functional component returns a JSX element that renders a
 * order flags and button to add flags
 */
export default function OrderFlagsHeader({
  openOrderFlagModal,
  orderFlags,
}: IOrderFlagsHeaderProps) {
  const isEditPermission = useAppSelector((state) => state.permission.isEditPermission);
  const orderFlagCount = [
    {
      type: "Open",
      count: orderFlags.filter((item) => !item.IsChecked && !item.IsActiveOverridden).length,
    },
    {
      type: "Overridden",
      count: orderFlags.filter((item) => item.IsActiveOverridden).length,
    },
    {
      type: "Completed",
      count: orderFlags.filter((item) => item.IsChecked).length,
    },
  ];
  return (
    <Row justify={"space-evenly"}>
      <Col>
        <Space split={"|"} size={20} align="center">
          <Text className="m-0 accordion-heading"> {translate("editOrder.orderFlagsTitle")}</Text>
          {checkPermissionToShow(
            isEditPermission,
            <Button
              size="small"
              type="primary"
              icon={<PlusOutlined />}
              data-test-selector="btnAddProduct"
              onClick={(e) => {
                openOrderFlagModal && openOrderFlagModal();
                e.stopPropagation();
                e.nativeEvent.stopImmediatePropagation();
              }}
            >
              {translate("editOrder.addFlagTitle")}
            </Button>
          )}

          <Space size={0} align="center">
            {orderFlagCount.map((item: IOrderFlagCount, i: number) => {
              return (
                <TagComponent
                  key={`chip${i}`}
                  text={`${item?.count} ${item?.type}`}
                  tagColor="#678EC2"
                  isRounded={true}
                  dataTestSelector="tagOrderFlag"
                />
              );
            })}
          </Space>
        </Space>
      </Col>
    </Row>
  );
}
