/* eslint-disable max-len */
import React from "react";
import { Input, Space, Table } from "antd";
import { columns } from "./OrderFlags.Constant";
import {
  IUnAssociatedOrderFlag,
  IUnAssociatedOrderFlagList,
} from "interfaces/ClientInterface/IOrderFlag";
import { SearchOutlined } from "@ant-design/icons";

/**
 * @returns This is a React functional component named `OrderFlagsList` which is rendering table.
 * Table is used to show order flags data.
 */

export const OrderFlagsList: React.FC<IUnAssociatedOrderFlag> = ({
  unAssociatedOrderFlag,
  selectedRowKeys,
  setSelectedRowKeys,
  setSearchInput,
  searchInput,
}: IUnAssociatedOrderFlag) => {
  /**
   * const rowSelection` is an object that defines the behavior of row
   * selection in the `Table` component.
   */
  const rowSelection = {
    selectedRowKeys,
    onChange: (selectedRowKeys: React.Key[]) => {
      setSelectedRowKeys(selectedRowKeys);
    },
  };

  const onRowClick = (record: IUnAssociatedOrderFlagList) => {
    // Check if the row is already selected, and toggle its selection status
    const selectedRowKeyIndex = selectedRowKeys.indexOf(record.CPOrderFlagId);
    let newSelectedRowKeys;
    if (selectedRowKeyIndex > -1) {
      newSelectedRowKeys = [...selectedRowKeys];
      newSelectedRowKeys.splice(selectedRowKeyIndex, 1);
    } else {
      newSelectedRowKeys = [...selectedRowKeys, record.CPOrderFlagId];
    }
    setSelectedRowKeys(newSelectedRowKeys);
  };

  const filterData = unAssociatedOrderFlag?.filter((item: IUnAssociatedOrderFlagList) => {
    return item?.NameUnchecked?.toLowerCase()?.includes(searchInput.toLowerCase());
  });
  

  return (
    <Space direction="vertical" size={"middle"} className="w-100">
      <div className="input-search-margin">
        <Input
          placeholder="Search Order Flag"
          suffix={<SearchOutlined />}
          onChange={(e) => setSearchInput(e.target.value)}
          value={searchInput}
          allowClear={true}
        />
      </div>
      <Table
        size="small"
        className="order-flags w-100"
        dataSource={(searchInput && searchInput?.trim() ? filterData : unAssociatedOrderFlag) || []}
        columns={columns}
        rowKey={(record) => record?.CPOrderFlagId}
        pagination={false}
        data-test-selector="tblAddOrderFlags"
        rowSelection={{
          type: "checkbox",
          ...rowSelection,
        }}
        style={{ overflowY: "auto", maxHeight: "200px" }}
        onRow={(record) => ({
          onClick: () => onRowClick(record),
        })}
      />
    </Space>
  );
};
