import React from "react";
import { Button, Col, Row, Select, Space, Typography } from "antd";
import { PlusOutlined } from "@ant-design/icons";
import { BillToProps } from "interfaces/ClientInterface/IPayment";
const { Text } = Typography;

/**
 * @param {billTo}  - `billTo`: selected value of Bill To DropDown
 * @param {setBillTo}  - `setBillTo`: Setter method to update the billTo dropdown value
 * @param {billingList}  - `billingList`: list of shipping address options to dropdown.
 * @param {onAddClick}
 * @returns A React functional component that renders a SelectInput component a "Add" button.
 */
export const BillTo: React.FC<BillToProps> = ({
  billTo,
  setBillTo,
  billingList,
  onAddClick,
  error,
  setError,
  isUserExists,
}: BillToProps) => {
  return (
    <Row align="middle">
      <Col span={8}>
        <Text className="key-title required">Bill To:</Text>
      </Col>
      <Col span={16}>
        <Space>
          <Select
            disabled={isUserExists}
            placeholder="Select"
            options={billingList || []}
            className="bill-inputs-width"
            showSearch={true}
            data-test-selector="drpBillTo"
            onChange={(bill) => {
              setBillTo(bill);
              setError((prevState) => ({
                ...prevState,
                BillToError: "",
              }));
            }}
            value={billTo || undefined}
            allowClear={true}
            fieldNames={{ label: "DisplayName", value: "AddressId" }}
          />
          <Button
            disabled={isUserExists}
            icon={<PlusOutlined className="add-icon" />}
            size="middle"
            data-test-selector="btnAddShipToAddress"
            onClick={onAddClick}
          />
        </Space>
        <div className="error">{error && error?.BillToError}</div>
      </Col>
    </Row>
  );
};

export default BillTo;
