/* eslint-disable no-console */
/* eslint-disable max-lines-per-function */
/* eslint-disable max-len */
/* eslint-disable max-lines */
/* eslint-disable no-unused-vars */
/* eslint-disable indent */
import React, { useContext, useEffect, useState } from "react";
import { Button, Col, Row, Space, Typography, Radio, Input } from "antd";
import { EditOutlined, CheckOutlined, CloseOutlined } from "@ant-design/icons";
import type { RadioChangeEvent } from "antd";
import { httpApi } from "api/http.api";
import { CheckBoxComponent } from "components/Common/Checkbox/Checkbox";
import { CheckboxChangeEvent } from "antd/es/checkbox";
import BillTo from "./BillTo";
import {
  ICouponData,
  ICsrDiscountData,
  IDiscountData,
  IDiscountItemValidate,
  IPayment,
  IPaymentError,
  IVoucherData,
} from "interfaces/APIInterface/IPayment";
import { useParams } from "react-router-dom";
import {
  CREATE_ORDER_PAYMENT,
  CREATE_PAYMENT_ADDRESS_API,
  GET_PAYMENT_ADDRESS_API,
  UPDATE_PAYMENT_ADDRESS_API,
  GET_PAYMENT_DETAILS_API,
  DEFAULT_EMPTY_GUID,
  VOUCHERNUMBER,
  COUPONCODE,
  VOUCHERVALUE,
} from "config/constant";
import { notificationController } from "components/Common/Notification/Notification";
import { readUserId } from "api/services/localStorage.service";
import AddAddressModal from "components/Common/AddAddress/AddAddress";
import "./Payment.scss";
import { IBillingProps } from "interfaces/ClientInterface/IPayment";
import { checkPermissionToShow, convertDateTime, isObjectEmpty } from "utils";
import { IAddressProps } from "interfaces/APIInterface/IAddAddress";
import Loader from "components/Common/Loader/Loader";
import { translate } from "i18n";
import { AbilityContext } from "ability/can";
import { calculate } from "api/services/calculateOrder.api";
import { useAppSelector } from "hooks/reduxHooks";
import { PERMISSION_CODE, PERMISSION_SUBJECT } from "ability/utils";
import { getGlobalSetting } from "api/services/localStorage.service";

const { Text } = Typography;

/**
 * @returns Payment function is a React component that renders a form
 * for entering payment and billing related information
 */
// eslint-disable-next-line max-lines-per-function
const Payment: React.FC<IBillingProps> = ({
  order,
  orderData,
  calculateOrder,
  orderCalculation,
  getOrderDetails,
}: IBillingProps) => {
  const accountId = useAppSelector((state) => state.editOrder.accountId);
  const isEditPermission = useAppSelector((state) => state.permission.isEditPermission);
  const ability = useContext(AbilityContext);
  const canChangeCSRDiscount = ability.can(
    PERMISSION_CODE.CHANGE_CSR_DISCOUNT,
    PERMISSION_SUBJECT.ORDERS
  );
  const [billTo, setBillTo] = useState("");
  const [billToList, setBillToList] = useState<IPayment[]>([]);
  const [voucherNumber, setVoucherNumber] = useState("");
  const [paymentOption, setPaymentOption] = useState(1);
  const [csrDiscount, setCsrDiscount] = useState("");
  const [couponCode, setCouponCode] = useState("");
  const [isTaxExemption, setIsTaxExemption] = useState(false);
  const [isAddressModalVisible, setIsAddressModalVisible] = useState(false);
  const [purchaseOrderNumber, setPurchaseOrderNumber] = useState("");
  const { orderId } = useParams<Record<string, string | undefined>>();
  const { orderAddressId } = useParams<Record<string, string | undefined>>();
  const [editBillingAddress, setBillingAddress] = useState(false);
  const [addressDetails, setAddressDetails] = useState({} as IPayment);
  const [paymentData, setPaymentData] = useState<IVoucherData[]>([]);
  const [couponCodeData, setCouponCodeData] = useState<ICouponData[]>([]);
  const [csrDiscountValue, setCsrDiscountValue] = useState<ICsrDiscountData[]>([]);
  const [isUserExists, setIsUserExists] = useState(false);
  const [loading, setLoading] = useState(false);
  const [callOnceCheck, setCallOnceCheck] = useState(false);

  const initialAddress = {
    AddressId: "",
    DisplayName: "",
    FirstName: "",
    LastName: "",
    CompanyName: "",
    Address1: "",
    Address2: "",
    CountryName: translate("addAddress.unitedStates"),
    StateName: "",
    City: "",
    PostalCode: "",
    PhoneNumber: "",
    IsDefaultBilling: false,
    IsDefaultShipping: false,
  };
  const [addressData, setAddressData] = useState<IAddressProps>(initialAddress);

  /**
   * useState for payError's
   */
  const [error, setError] = useState<IPaymentError>({
    BillToError: "",
    POError: "",
    VoucherNumber: "",
    CSRDiscount: "",
    CouponCode: "",
  });

  const [validate, setValidate] = useState<IDiscountItemValidate>({
    VoucherNumber: false,
    CSRDiscount: false,
    CouponCode: false,
  });

  const globalSettings = getGlobalSetting() ? JSON.parse(getGlobalSetting() || "") : {};
  const priceRoundOff = globalSettings?.PriceRoundOff;

  useEffect(() => {
    const data = billToList?.find((i: IPayment) => i.AddressId == billTo);
    setAddressDetails(data as IPayment);
    // eslint-disable-next-line react-hooks/exhaustive-deps
  }, [billTo]);

  useEffect(() => {
    if (orderData?.userId) {
      callOnceCheck && fetchBillTo();
      clearOrderPaymentDetails();
      setIsUserExists(false);
    } else {
      setBillToList([]);
      clearOrderPaymentDetails();
      setIsUserExists(true);
    }
    // eslint-disable-next-line react-hooks/exhaustive-deps
  }, [orderData.userId, orderCalculation.SubTotal]);

  useEffect(() => {
    fetchPaymentDetails();
    // eslint-disable-next-line react-hooks/exhaustive-deps
  }, [orderCalculation.SubTotal]);

  /**
   * Function is used to clear payment info fields.
   */
  const clearOrderPaymentDetails = () => {
    setBillTo("");
    setAddressDetails({} as IPayment);
    setPurchaseOrderNumber("");
    setVoucherNumber("");
    setCsrDiscount("");
    setCouponCode("");
    setIsTaxExemption(false);
    setPaymentData([]);
    setCouponCodeData([]);
    setCsrDiscountValue([]);
  };
  const onAddClickHandler = () => {
    setIsAddressModalVisible(true);
  };

  /**
   * Added the const to get payment details from the API and display.
   */
  const fetchPaymentDetails = () => {
    setLoading(true);
    httpApi
      .get(GET_PAYMENT_DETAILS_API + "/" + orderId)
      .then((response) => {
        const data = response?.data?.OrderPaymentModel;
        const paymentDetails = JSON.parse(data?.OrderDetail)?.[0].OrderPayment?.[0];
        const discountDetails = JSON.parse(data?.OrderDetail)?.[0].OrderDiscount;
        //Fetch List on mount.
        fetchBillTo(paymentDetails?.BillingAddress?.[0]?.AddressId || "");

        calculate(orderId).then((res) => {
          const calculateData = res;
          //Voucher Details

          const existingPaymentData: IVoucherData[] = [];

          calculateData?.Calculate?.VoucherDetails?.forEach((el: IVoucherData) => {
            if (calculateData?.Calculate?.VoucherDetails.length > 0) {
              const orderIdData = localStorage.getItem("orderIds");
              const orderIdParsedData =
                typeof orderIdData == "string" ? JSON?.parse(orderIdData) : [];
              if (!orderIdParsedData.includes(orderId)) {
                //saving data in local storage
                orderIdParsedData.push(orderId);
                localStorage.setItem("orderIds", JSON.stringify(orderIdParsedData));
                onValidateDiscountHandler(
                  translate("editOrder.voucherNumber"),
                  el.VoucherNumber,
                  "",
                  false,
                  false
                );
              }
            }

            if (
              el.VoucherMessage &&
              el.VoucherMessage.toLowerCase().includes(VOUCHERNUMBER.toLowerCase())
            ) {
              existingPaymentData.push({
                OrderDiscountId: discountDetails?.find((discountData: IDiscountData) => {
                  return discountData.DiscountCode == el.VoucherNumber;
                })?.OrderDiscountId,
                ExpirationDate: el.ExpirationDate,
                VoucherMessage: el.VoucherMessage,
                VoucherNumber: el.VoucherNumber,
                VoucherAmount: el.VoucherAmountApplied || "",
                IsVoucherValid: el.IsVoucherValid,
                VoucherName: el.VoucherName,
              });
              setValidate((prevState) => ({
                ...prevState,
                VoucherNumber: true,
              }));
            }
          });
          setPaymentData(existingPaymentData);

          //Coupon Details
          const existingCouponData: ICouponData[] = [];
          calculateData?.Calculate?.CouponDetails?.forEach((el: ICouponData) => {
            if (el.CouponMessage && el.CouponMessage.includes(COUPONCODE)) {
              existingCouponData.push({
                OrderDiscountId: discountDetails?.find((discountData: IDiscountData) => {
                  return discountData.DiscountCode == el.Coupon;
                })?.OrderDiscountId,
                Coupon: el.Coupon,
                CouponApplied: el.CouponApplied,
                CouponMessage: el.CouponMessage,
                CouponValid: el.CouponValid,
                PromotionName: el.PromotionName,
              });
              if (calculateData?.Calculate?.CouponDetails?.length > 0) {
                setValidate((prevState) => ({
                  ...prevState,
                  CouponCode: true,
                }));
              }
            }
          });
          setCouponCodeData(existingCouponData);

          //CsrDiscount Details
          const existingCsrDiscountData: ICsrDiscountData[] = [];

          existingCsrDiscountData.push({
            OrderDiscountId: discountDetails?.find((discountData: IDiscountData) => {
              return (
                discountData.DiscountCode == calculateData?.Calculate?.CSRDiscountAmount.toString()
              );
            })?.OrderDiscountId,
            CSRDiscountApplied: calculateData?.Calculate?.CSRDiscountApplied,
            CSRDiscountMessage: calculateData?.Calculate?.CSRDiscountMessage,
            CSRDiscountAmount: calculateData?.Calculate?.CSRDiscountAmount.toString(),
          });
          if (isCsrDiscountValid(existingCsrDiscountData)) {
            setCsrDiscountValue(existingCsrDiscountData);
          }

          setPaymentData(existingPaymentData);

          if (calculateData?.Calculate?.CSRDiscountAmount > 0) {
            setValidate((prevState) => ({
              ...prevState,
              CSRDiscount: true,
            }));
          }
        });

        const isCsrDiscountValid = (existingCsrDiscountData: ICsrDiscountData[]) => {
          if (
            existingCsrDiscountData[0].OrderDiscountId != undefined &&
            existingCsrDiscountData[0].CSRDiscountAmount != "0" &&
            existingCsrDiscountData[0].CSRDiscountMessage != ""
          ) {
            return true;
          } else {
            return false;
          }
        };

        if (paymentDetails?.TaxDetail?.[0]?.TaxClassName == translate("editOrder.taxExempt")) {
          setIsTaxExemption(true);
        } else {
          setIsTaxExemption(false);
        }
        setPurchaseOrderNumber(data?.PurchaseOrderNumber || "");
        setLoading(false);
        calculateOrder();
        setCallOnceCheck(true);
      })
      .catch((err) => {
        notificationController.error({ message: err.message, placement: "top" });
      });
  };

  /**
   * Added the const to get user address from the API and display.
   */
  const fetchBillTo = (addressId?: string | undefined) => {
    setLoading(true);
    httpApi
      .get(accountId ? "/account/addresslist" : "/customer/addresslist", {
        params: {
          expand: "ZnodeAddress",
          filter: accountId ? `AccountId~eq~${accountId}` : `UserId~eq~${orderData?.userId}`,
          sort: "",
          page: "",
          publishState: "",
        },
      })
      .then((response) => {
        const data = response?.data?.AddressList;
        const dataList = data ? (Array.isArray(data) ? data : [data]) : [];
        const defaultAddress = dataList?.find((item: IPayment) => item.IsDefaultBilling);
        setBillToList(dataList);
        setError((prevState) => ({
          ...prevState,
          BillToError: "",
        }));
        if (addressId) {
          const data = dataList?.find((item: IPayment) => item.AddressId == addressId);
          setAddressDetails(data as IPayment);
          if (data != undefined) {
            setBillTo(addressId);
          } else {
            setAddressDetails(defaultAddress as IPayment);
            setBillTo(defaultAddress?.AddressId);
          }
        } else {
          setAddressDetails(defaultAddress as IPayment);
          setBillTo(defaultAddress?.AddressId);
        }
        setLoading(false);
      })
      .catch((err) => {
        setLoading(false);
        notificationController.error({ message: err.message, placement: "top" });
      });
  };

  /**
   * Function to validate payment address.
   * @returns error status.
   */
  const validateBillTo = () => {
    if (!billTo) {
      setError((prevState) => ({
        ...prevState,
        BillToError: "Bill to address is required",
      }));
      return false;
    }
    return true;
  };

  /**
   * Function is used to save payment detail with validation.
   */
  const OnPaymentInfoSaveHandler = () => {
    const isValidBillTo = validateBillTo();
    let isDiscountItemRequired = true;

    if (voucherNumber && !validate?.VoucherNumber) {
      setError((prevState) => ({
        ...prevState,
        VoucherNumber: translate("editOrder.validateVoucherNumber"),
      }));
      isDiscountItemRequired = false;
    }

    if (csrDiscount && !validate?.CSRDiscount) {
      setError((prevState) => ({
        ...prevState,
        CSRDiscount: translate("editOrder.validateCSRDiscount"),
      }));
      isDiscountItemRequired = false;
    }

    if (couponCode && !validate?.CouponCode) {
      setError((prevState) => ({
        ...prevState,
        CouponCode: translate("editOrder.validateCouponCode"),
      }));
      isDiscountItemRequired = false;
    }

    if (!isDiscountItemRequired) {
      return isDiscountItemRequired;
    }

    if (!isValidBillTo) {
      return;
    }

    const body = {
      OrderId: order.OrderId || orderId,
      ClassId: order.ClassId || "",
      UserId: readUserId(),
      AddressId: billTo,
      OrderAddressId: orderAddressId,
      IsTaxExemption: isTaxExemption,
      PurchaseOrderNumber: purchaseOrderNumber,
    };
    httpApi
      .post(CREATE_ORDER_PAYMENT, body, {})
      .then((response) => {
        calculateOrder();
        getOrderDetails();
        notificationController.success({ message: "Payment Info saved successfully." });
      })
      .catch(() => {
        notificationController.error({ message: "Failed to save Payment Info" });
      });
  };

  // eslint-disable-next-line @typescript-eslint/no-explicit-any
  const onAddressSaveHandler = (addressData: IAddressProps, form: any) => {
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    const body: any = {
      displayName: addressData.DisplayName,
      firstName: addressData.FirstName,
      lastName: addressData.LastName,
      companyName: addressData.CompanyName,
      address1: addressData.Address1,
      address2: addressData.Address2,
      countryName: addressData.CountryName,
      stateName: addressData.StateName,
      cityName: addressData.City,
      postalCode: addressData.PostalCode,
      phoneNumber: addressData.PhoneNumber,
      isDefaultBilling: addressData.IsDefaultBilling,
      isDefaultShipping: addressData.IsDefaultShipping,
      userId: orderData?.userId.toString(),
    };

    /**
     * Check if the API request is for creating a new user address or updating an existing one.
     */
    if (editBillingAddress) {
      body.addressId = billTo;
      //Update user address
      httpApi
        .put(UPDATE_PAYMENT_ADDRESS_API, body, {})
        .then((response) => {
          const data = response?.data?.Address;
          fetchBillTo(data?.AddressId);
          setBillingAddress(false);
          setIsAddressModalVisible(false);
          form.resetFields();
          form.setFieldsValue(initialAddress);
        })
        .catch((ex) => {
          notificationController.error({ message: ex.message });
        });
    } else {
      //Create user address
      httpApi
        .post(CREATE_PAYMENT_ADDRESS_API, body, {})
        .then((response) => {
          const data = response?.data?.Address;
          fetchBillTo(data?.AddressId);
          setIsAddressModalVisible(false);
          form.resetFields();
          form.setFieldsValue(initialAddress);
        })
        .catch((ex) => {
          notificationController.error({ message: ex.message });
        });
    }
  };

  // eslint-disable-next-line @typescript-eslint/no-explicit-any
  const fetchBillingAddress = (billTo: any) => {
    httpApi
      .get(GET_PAYMENT_ADDRESS_API + "/" + billTo)
      .then((response) => {
        const data = response?.data?.CPAddressModel;
        setAddressData({
          AddressId: data?.AddressId || "",
          DisplayName: data?.DisplayName || "",
          FirstName: data?.FirstName || "",
          LastName: data?.LastName || "",
          CompanyName: data?.CompanyName || "",
          Address1: data?.Address1 || "",
          Address2: data?.Address2 || "",
          CountryName: data?.CountryName || "",
          StateName: data?.StateName || "",
          City: data?.CityName || "",
          PostalCode: data?.PostalCode || "",
          PhoneNumber: data?.PhoneNumber || "",
          IsDefaultBilling: data?.IsDefaultBilling || "",
          IsDefaultShipping: data?.IsDefaultShipping || "",
        });
        setIsAddressModalVisible(true);
        setBillingAddress(true);
      })
      .catch((err) => {
        notificationController.error({ message: err.message, placement: "top" });
      });
  };

  const showErrorMessageWithSubTotalCheck = (fieldLabel: string, fieldValue: string | number) => {
    switch (fieldLabel) {
      case "VoucherNumber":
        return translate("editOrder.noFurtherVoucherApplied");
        break;
      case "CSRDiscount":
        return translate("editOrder.totalDiscountExceedSubtotal");
        break;
      case "CouponCode":
        return fieldValue + " " + translate("editOrder.couponLimitReachedSubtotal");
        break;
      default:
        "";
    }
  };

  const showRemoveValidationMessage = (fieldLabel: string) => {
    switch (fieldLabel) {
      case "VoucherNumber":
        return translate("editOrder.voucherRemovedSuccessfully");
        break;
      case "CSRDiscount":
        return translate("editOrder.csrRemovedSuccessfully");
        break;
      case "CouponCode":
        return translate("editOrder.couponRemovedSuccessfully");
        break;
      default:
        "";
    }
  };

  /**
   * This function is used to validate Voucher, CsrDiscount and Coupon Discounts.
   * @param fieldLabel contains dynamic field label.
   * @param fieldValue contains dynamic field value.
   * @param updateDiscountIdLabel contains dynamic orderDiscountId for discount items.
   * @param isDeleted to check for remove validation.
   * @param isCsrDiscountId is used for csrDiscount update.
   * @returns validation filtered data.
   */
  const onValidateDiscountHandler = (
    fieldLabel: string,
    fieldValue: string | number,
    updateDiscountIdLabel: string,
    isDeleted: boolean,
    isMessageShow: boolean,
    isCsrDiscountId?: string
  ) => {
    setValidate((prevState) => ({
      ...prevState,
      [fieldLabel]: true,
    }));
    const orderIdData = localStorage.getItem("orderIds");
    const orderIdParsedData = typeof orderIdData == "string" ? JSON?.parse(orderIdData) : [];
    if (!orderIdParsedData.includes(orderId)) {
      //saving data in local storage
      orderIdParsedData.push(orderId);
      localStorage.setItem("orderIds", JSON.stringify(orderIdParsedData));
    }
    const checkDiscountForSubtotal = Number(orderCalculation?.SubTotal || 0);

    setError((prevState) => ({
      ...prevState,
      [fieldLabel]:
        checkDiscountForSubtotal <= 0
          ? showErrorMessageWithSubTotalCheck(fieldLabel, fieldValue)
          : "",
    }));

    if (checkDiscountForSubtotal <= 0) {
      return;
    }

    if (fieldValue && orderCalculation?.Total === 0) {
      notificationController.error({
        message: translate("editOrder.couponLimitReachedSubtotal"),
      });
      return;
    }

    const body = {
      OrderId: order.OrderId || orderId,
      ClassId: order.ClassId || "",
      DiscountData: [
        {
          OrderDiscountId: isCsrDiscountId
            ? isCsrDiscountId
            : isDeleted
            ? updateDiscountIdLabel
            : null,
          Code: fieldLabel?.toUpperCase() || "",
          Value: fieldValue || "",
          Amount: csrDiscount || "0",
          IsDeleted: isDeleted,
        },
      ],
      UserId: readUserId(),
      OrderAddressId: orderAddressId,
      IsTaxExemption: isTaxExemption,
    };

    httpApi
      .post("/payment/validatediscountitem", body, {})
      .then((response) => {
        const data = response?.data?.StatusModelList?.[0]?.Id;
        calculate(orderId).then((res) => {
          const calculateData = res;
          if (!isDeleted && fieldLabel == translate("editOrder.voucherNumber")) {
            const existingPaymentData: IVoucherData[] = [...paymentData];
            const item = calculateData?.Calculate?.VoucherDetails?.find((el: IVoucherData) => {
              return el.VoucherNumber == fieldValue;
            });
            existingPaymentData.push({
              OrderDiscountId: data,
              ExpirationDate: item?.ExpirationDate,
              VoucherMessage: item?.VoucherMessage,
              VoucherNumber: item?.IsVoucherValid ? item?.VoucherNumber : fieldValue?.toString(),
              VoucherAmount: item?.VoucherAmountApplied,
              IsVoucherValid: item?.IsVoucherValid,
              VoucherName: item?.VoucherName,
            });
            setPaymentData(existingPaymentData);
          } else {
            setPaymentData((prevState) => {
              const filterData = [...prevState]?.filter((item) => {
                return item.OrderDiscountId != updateDiscountIdLabel;
              });
              return filterData;
            });
          }

          if (!isDeleted && fieldLabel == translate("editOrder.couponCode")) {
            const existingCouponData: ICouponData[] = [...couponCodeData];
            const item = calculateData?.Calculate?.CouponDetails?.find((el: ICouponData) => {
              return el.Coupon == fieldValue;
            });

            existingCouponData.push({
              OrderDiscountId: data,
              Coupon: item?.Coupon ? item?.Coupon : fieldValue?.toString(),
              CouponValid: item?.CouponValid,
              CouponApplied: item?.CouponApplied,
              CouponMessage: item?.CouponMessage,
              PromotionName: item?.PromotionName,
            });

            setCouponCodeData(existingCouponData);
          } else {
            setCouponCodeData((prevState) => {
              const filterData = [...prevState]?.filter((item) => {
                return item.OrderDiscountId != updateDiscountIdLabel;
              });
              return filterData;
            });
          }

          if (!isDeleted && fieldLabel == translate("editOrder.csrDiscount")) {
            const existingCsrDiscountData: ICsrDiscountData[] = [];
            const item = calculateData?.Calculate;
            if (item.CSRDiscountAmount == fieldValue) {
              existingCsrDiscountData.push({
                OrderDiscountId: data,
                CSRDiscountApplied: item?.CSRDiscountApplied,
                CSRDiscountMessage: item?.CSRDiscountMessage,
                CSRDiscountAmount: item?.CSRDiscountAmount,
              });

              setCsrDiscountValue(existingCsrDiscountData);
            }
          } else {
            setCsrDiscountValue((prevState) => {
              const filterData = [...prevState]?.filter((item) => {
                return item.OrderDiscountId != updateDiscountIdLabel;
              });
              return filterData;
            });
          }

          if (data == null || data == undefined || data == DEFAULT_EMPTY_GUID || isDeleted) {
            setValidate((prevState) => ({
              ...prevState,
              [fieldLabel]: false,
            }));
            notificationController.success({
              message: showRemoveValidationMessage(fieldLabel),
            });
          } else {
            if (isMessageShow) {
              notificationController.success({
                message: translate("editOrder.validateSuccessfully"),
              });
            }
          }
          calculateOrder();
        });
      })
      .catch(() => {
        notificationController.error({ message: translate("editOrder.failedToValidate") });
      });
    return;
  };

  const onEditClickHandler = () => {
    fetchBillingAddress(billTo);
  };

  // eslint-disable-next-line @typescript-eslint/no-explicit-any
  const onModalCancelPress = (form: any) => {
    form.resetFields();
    form.setFieldsValue(initialAddress);
    setIsAddressModalVisible(false);
  };

  const changeTaxExemptText = isTaxExemption
    ? translate("editOrder.taxIsExempted")
    : translate("editOrder.makeTaxExempt");

  return (
    <Row
      wrap
      className={isEditPermission ? "payment-container" : "payment-container disabled-container"}
      gutter={[30, 0]}
    >
      <Loader loading={loading} />
      {checkPermissionToShow(
        isEditPermission,
        <Col span={24} className="mb-8 d-flex justify-end">
          <Button
            disabled={isUserExists}
            type="primary"
            data-test-selector={"btnSavePayment"}
            onClick={OnPaymentInfoSaveHandler}
            size="small"
          >
            {translate("editOrder.savePaymentDetailsBtn")}
          </Button>
        </Col>
      )}
      <Col span={8}>
        <Space direction="vertical" size={4} className="w-100">
          <BillTo
            billTo={billTo}
            setBillTo={setBillTo}
            billingList={billToList}
            onAddClick={onAddClickHandler}
            error={error}
            setError={setError}
            isUserExists={isUserExists}
          />
          {!isObjectEmpty(addressDetails || {}) && (
            <Row align="middle">
              <Col span={16} push={8}>
                <Space direction="vertical" size={1}>
                  <Space size={10}>
                    <Text className="txt-bold text-color-gray">
                      {`${addressDetails?.FirstName} ${addressDetails?.LastName}`}
                    </Text>
                    <div data-test-selector="btnAddShipToAddress" onClick={onEditClickHandler}>
                      <EditOutlined className="add-icon" />
                    </div>
                  </Space>
                  <Text className="text-color-gray">
                    {`${addressDetails?.Address1} , ${addressDetails?.CityName} ,
                    ${addressDetails?.StateName} , ${addressDetails?.PostalCode}`}
                    <br></br>
                    {`Ph: ${addressDetails?.PhoneNumber}`}
                  </Text>
                </Space>
              </Col>
            </Row>
          )}
        </Space>
      </Col>
      <Col span={8} className="d-flex justify-center">
        <Space direction="vertical" size={10}>
          <div className="txt-bold text-color-gray">
            {translate("editOrder.paymentMethodTitle")}:
          </div>
          <Row align="middle">
            <Col span={10}>
              <Text className="key-title">{translate("editOrder.voucherNumberTitle")}:</Text>
            </Col>
            <Col span={14}>
              <Space>
                <Input
                  disabled={isUserExists}
                  value={voucherNumber}
                  data-test-selector="txtVoucherNumber"
                  type="text"
                  placeholder={translate("editOrder.enterVoucherNumberMessage")}
                  onChange={(e) => setVoucherNumber(e?.target?.value)}
                />
                <Button
                  disabled={isEditPermission ? isUserExists || !voucherNumber : false}
                  icon={<CheckOutlined className="add-icon" />}
                  size="middle"
                  onClick={() => {
                    if (
                      paymentData.findIndex((el: IVoucherData) => {
                        return el.VoucherNumber == voucherNumber;
                      }) == -1
                    ) {
                      onValidateDiscountHandler(
                        translate("editOrder.voucherNumber"),
                        voucherNumber,
                        "",
                        false,
                        true
                      );
                    } else {
                      setError((prevState) => ({
                        ...prevState,
                        VoucherNumber: translate("editOrder.voucherAlreadyApplied"),
                      }));
                    }
                  }}
                  className={validate?.VoucherNumber ? "validated" : "un-validate"}
                />
              </Space>
            </Col>
            <Col span={14} offset={10}>
              <div className="error">{error && error?.VoucherNumber}</div>
              {paymentData &&
                paymentData.map((payment, index) => {
                  return (
                    <>
                      <Space
                        direction="horizontal"
                        align="start"
                        size={6}
                        key={index}
                        className="mt-8"
                      >
                        <CloseOutlined
                          className="discount-cross-icon"
                          onClick={() => {
                            setVoucherNumber("");
                            onValidateDiscountHandler(
                              translate("editOrder.voucherNumber"),
                              payment.VoucherNumber,
                              payment.OrderDiscountId?.toString(),
                              true,
                              true
                            );
                          }}
                        />
                        <Space key={index} className="discount-message" direction="vertical">
                          {payment.IsVoucherValid ? (
                            <Space size={2} direction="vertical">
                              <div>
                                {`$${parseFloat(payment?.VoucherAmount || "0.00")?.toFixed(
                                  priceRoundOff
                                )} `}{" "}
                                <span className="text-color-gray">{payment?.VoucherName}</span>
                              </div>
                              <div className="text-color-gray">Voucher Expires:</div>
                              <div className="text-color-gray">
                                {convertDateTime(payment?.ExpirationDate)}
                              </div>
                              <div className="txt-bold text-color-gray">
                                {payment?.VoucherNumber}
                              </div>
                            </Space>
                          ) : (
                            <Space size={2} direction="vertical">
                              <div className="txt-bold text-color-gray">
                                {payment?.VoucherNumber}
                              </div>
                              <div className="discount-cross-icon">{payment.VoucherMessage}</div>
                            </Space>
                          )}
                        </Space>
                      </Space>
                    </>
                  );
                })}
            </Col>
          </Row>
          <Row align="top">
            <Col span={10}>
              <Radio.Group
                onChange={(e: RadioChangeEvent) => {
                  setPaymentOption(e.target.value);
                }}
                value={paymentOption}
                data-test-selector="chkPaymentMethod"
                disabled={isUserExists}
              >
                <Space direction="vertical" size={16}>
                  <Radio value={1}>Purchase Order</Radio>
                </Space>
              </Radio.Group>
            </Col>
            <Col span={14}>
              <Input
                disabled={isUserExists}
                type="text"
                className="inputs-width"
                placeholder="PO-123456780"
                data-test-selector="txtPONumber"
                value={purchaseOrderNumber}
                onChange={(e) => {
                  setPurchaseOrderNumber(e?.target?.value);
                  setError((prevState) => ({
                    ...prevState,
                    POError: "",
                  }));
                }}
              />
              <div className="error">{error && error?.POError}</div>
            </Col>
          </Row>
        </Space>
      </Col>
      <Col span={8}>
        <Space direction="vertical" size={10} className="w-100">
          <div className="txt-bold text-color-gray">{translate("editOrder.discountTitle")}:</div>
          <Row align="middle">
            <Col span={10}>
              <Text className="key-title">{translate("editOrder.csrDiscountTitle")}:</Text>
            </Col>
            <Col span={14}>
              <Space>
                <Input
                  disabled={isUserExists || !canChangeCSRDiscount}
                  type="number"
                  placeholder="Enter Discount"
                  data-test-selector="txtCsrDiscount"
                  value={csrDiscount}
                  onChange={(e) => setCsrDiscount(e?.target?.value)}
                />
                <Button
                  disabled={
                    isEditPermission ? isUserExists || !csrDiscount || !canChangeCSRDiscount : false
                  }
                  icon={<CheckOutlined className="add-icon" />}
                  size="middle"
                  onClick={() => {
                    onValidateDiscountHandler(
                      translate("editOrder.csrDiscount"),
                      csrDiscount,
                      "",
                      false,
                      true,
                      csrDiscountValue[0] ? csrDiscountValue[0].OrderDiscountId?.toString() : ""
                    );
                  }}
                  className={validate?.CSRDiscount ? "validated" : "un-validate"}
                />
              </Space>
            </Col>
            <Col span={14} offset={10}>
              <div className="error">{error && error?.CSRDiscount}</div>
              {csrDiscountValue &&
                csrDiscountValue.map((csrValue, index) => {
                  return (
                    <Space direction="horizontal" align="start" size={6} key={index}>
                      <CloseOutlined
                        className="discount-cross-icon"
                        onClick={() => {
                          setCsrDiscount("");
                          onValidateDiscountHandler(
                            translate("editOrder.csrDiscount"),
                            "",
                            csrValue.OrderDiscountId?.toString(),
                            true,
                            true
                          );
                        }}
                      />
                      <Space key={index} className="discount-message" direction="vertical" size={0}>
                        <span key={index} className="discount-message">
                          {csrValue.CSRDiscountApplied ? (
                            <>
                              <div>
                                {csrValue?.CSRDiscountMessage.replace(
                                  /\$\S+/,
                                  `$${parseFloat(csrValue?.CSRDiscountAmount).toFixed(
                                    priceRoundOff
                                  )}`
                                )}
                              </div>
                            </>
                          ) : (
                            <>
                              <div className="discount-cross-icon">
                                {csrValue?.CSRDiscountMessage}
                              </div>
                            </>
                          )}
                        </span>
                      </Space>
                    </Space>
                  );
                })}
            </Col>
          </Row>
          <Row align="middle">
            <Col span={10}>
              <Text className="key-title">{translate("editOrder.couponCodeTitle")}:</Text>
            </Col>
            <Col span={14}>
              <Space>
                <Input
                  disabled={isUserExists}
                  type="text"
                  placeholder={translate("editOrder.enterCouponCodeMessage")}
                  data-test-selector="txtCouponCode"
                  value={couponCode}
                  onChange={(e) => setCouponCode(e?.target?.value)}
                />
                <Button
                  disabled={isEditPermission ? isUserExists || !couponCode : false}
                  icon={<CheckOutlined className="add-icon" />}
                  size="middle"
                  onClick={() => {
                    if (
                      couponCodeData?.findIndex((el: ICouponData) => {
                        return el.Coupon == couponCode;
                      }) == -1
                    ) {
                      onValidateDiscountHandler(
                        translate("editOrder.couponCode"),
                        couponCode,
                        "",
                        false,
                        true
                      );
                    } else {
                      const data = couponCodeData?.filter((el: ICouponData) => {
                        return el.Coupon == couponCode;
                      });

                      data?.find((el: ICouponData) => {
                        if (el.CouponValid == true) {
                          setError((prevState) => ({
                            ...prevState,
                            CouponCode: translate("editOrder.couponAlreadyApplied"),
                          }));
                        } else {
                          setError((prevState) => ({
                            ...prevState,
                            CouponCode: "",
                          }));
                        }
                      });
                    }
                  }}
                  className={validate?.CouponCode ? "validated" : "un-validate"}
                />
              </Space>
            </Col>
            <Col span={14} offset={10}>
              <div className="error">{error && error?.CouponCode}</div>
              {couponCodeData &&
                couponCodeData.map((coupon, index) => {
                  return (
                    <>
                      <Space
                        direction="horizontal"
                        align="start"
                        size={6}
                        key={index}
                        className="mt-8"
                      >
                        <CloseOutlined
                          className="discount-cross-icon"
                          onClick={() => {
                            setCouponCode("");
                            onValidateDiscountHandler(
                              translate("editOrder.couponCode"),
                              "",
                              coupon.OrderDiscountId.toString(),
                              true,
                              true
                            );
                          }}
                        />
                        <Space
                          key={index}
                          className="discount-message"
                          direction="vertical"
                          size={0}
                        >
                          {coupon.CouponValid ? (
                            <>
                              <div>
                                <span className="txt-bold">{coupon?.Coupon}</span>
                              </div>
                              <div>{`${coupon?.CouponMessage}`}</div>
                            </>
                          ) : (
                            <>
                              <div>
                                <span className="txt-bold discount-cross-icon">
                                  {coupon?.Coupon}
                                </span>
                              </div>
                              <div className="discount-cross-icon">{coupon.CouponMessage}</div>
                            </>
                          )}
                        </Space>
                      </Space>
                    </>
                  );
                })}
            </Col>
          </Row>
          <Row align="middle">
            <Col span={10}>
              <Text className="key-title">Tax Exemption:</Text>
            </Col>
            <Col span={14}>
              <CheckBoxComponent
                disabled={isUserExists}
                name={changeTaxExemptText}
                checked={isTaxExemption}
                closable={false}
                dataTestSelector={"chkTaxExempt"}
                onChangeHandle={(e: CheckboxChangeEvent) => setIsTaxExemption(e.target.checked)}
              />
            </Col>
          </Row>
        </Space>
      </Col>
      <AddAddressModal
        title="CUSTOMER ADDRESS"
        isAddressModalVisible={isAddressModalVisible}
        setIsAddressModalVisible={setIsAddressModalVisible}
        onAddressSave={onAddressSaveHandler}
        addressDetails={addressData}
        setAddressDetails={setAddressData}
        onModalCancelPress={onModalCancelPress}
      />
    </Row>
  );
};
export default Payment;
