/* eslint-disable no-console */
/* eslint-disable max-lines-per-function */
/* eslint-disable max-lines */
/* eslint-disable max-len */
import React, { useContext, useEffect, useState } from "react";
import { DELETE_TYPES, columns } from "./EditOrder.Constant";
import { Button, Space, Table, Typography } from "antd";
import {
  IProductList,
  IProductListProps,
  IProductSetLineItems,
  ISkuStatusList,
} from "interfaces/ClientInterface/IEditOrder";
import { PlusOutlined, ArrowLeftOutlined } from "@ant-design/icons";
import { useNavigate, useParams } from "react-router-dom";
import { DELETE_LINEITEM_API, GET_PRODUCTLISTBYORDERID_API } from "config/constant";
import { httpApi } from "api/http.api";
import { ProductListHeader } from "./ProductsListHeader";
import { notificationController } from "components/Common/Notification/Notification";
import DuplicateModalComponent from "components/Common/DuplicateModal/DuplicateModal";
import { ROUTES_PATH } from "routes/Routes.Constant";
import { IDuplicateLineItemPayload } from "interfaces/APIInterface/IOrderList";
import { duplicateLineItem } from "api/services/manageOrder.api";
import { IDuplicateLineItem } from "interfaces/ClientInterface/IOrderList";
import QuickAddModal from "components/Common/QuickAddModal/QuickAddModal";
import ModalComponent from "components/Common/Modal/Modal";
import { translate } from "i18n";
import { PureAbility } from "@casl/ability";
import {
  resetLineItemPrice,
  updateLineItemPrice,
  updateLineItemQuantity,
  updateLineItemStatus,
} from "api/services/editOrder.api";
import { SendCartLineItems } from "api/services/addProduct.api";
import { useAppDispatch, useAppSelector } from "hooks/reduxHooks";
import { AbilityContext } from "ability/can";
import { setPriceOrderNotesDetails } from "store/slices/editOrder.slice";
const { Text, Title } = Typography;
import { getGlobalSetting } from "api/services/localStorage.service";
// import { createNote } from "api/services/orderNote.api";
import { OrderStatusListProps } from "interfaces/ClientInterface/IEditOrder";
import { IIsPriceResetProductList } from "interfaces/ClientInterface/IEditOrder";

/**
 * @returns This is a React functional component named `ProductList` which is rendering table.
 * Table is used to show products data.
 * It also defines a function `onChangeHandler` that updates a specific field in a
 * table row based on the provided text input and index.
 */
export const ProductList: React.FC<IProductListProps> = ({
  orderStatusList,
  productList,
  setProductList,
  calculateOrder,
  isCalledByEditOrder,
  setIsCalledByEditOrder,
  handleLineItemsValidationOnStatusChange,
  showValidationMessages,
  getOrderDetails,
}: IProductListProps) => {
  const ability: PureAbility<[string, string]> = useContext(AbilityContext);
  const isEditPermission = useAppSelector((state) => state.permission.isEditPermission);
  const priceNoteChangeInfo = useAppSelector((state) => state.editOrder.priceNoteChange);
  // const orderData = useAppSelector((state) => state.editOrder.orderDetails);
  const navigate = useNavigate();
  const dispatch = useAppDispatch();
  //const [data, setData] = useState<Array<IProductList>>([]);
  const [selectedRowKeys, setSelectedRowKeys] = useState<React.Key[]>([]);
  const [isExpandable, setIsExpandable] = useState<boolean>(true);
  const [isDuplicateOrder, setIsDuplicateOrder] = useState<IDuplicateLineItem>({
    visible: false,
    OrderProductId: "",
  });
  const [loading, setLoading] = useState<boolean>(false);
  const { orderId } = useParams<Record<string, string | undefined>>();
  const [isQuickAddModalVisible, setIsQuickAddModalVisible] = useState<boolean>(false);
  const [isConfirmModalVisible, setIsConfirmModalVisible] = useState<boolean>(false);
  const [deleteAction, setDeleteAction] = useState<string>("");
  const [deleteOrderId, setDeleteOrderId] = useState<string>("");
  const [recordRowClassName, setRecordRowClassName] = useState<OrderStatusListProps[]>();
  const globalSettings = getGlobalSetting() ? JSON.parse(getGlobalSetting() || "") : {};
  const priceRoundOff = globalSettings?.PriceRoundOff;

  /**
   * `useEffect is a React hook that is used to update the state
   * of the component after the initial render. In this case, it sets the `data` state to the
   * `productData` array when the component mounts.
   */
  useEffect(() => {
    fetchProductList(orderId);
    // eslint-disable-next-line react-hooks/exhaustive-deps
  }, [orderId]);

  useEffect(() => {
    if (isCalledByEditOrder) fetchProductList(orderId);
    // eslint-disable-next-line react-hooks/exhaustive-deps
  }, [isCalledByEditOrder]);

  // eslint-disable-next-line @typescript-eslint/no-explicit-any
  const onChangeHandler = async (text: any, field: string, index: number) => {
    const tableData: IProductList[] = [...productList];
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    const row: any = tableData[index];
    if (field == "Status") {
      const result = await handleLineItemsValidationOnStatusChange(
        text,
        row["OrderId"],
        row["OrderProductId"]
      );
      if (
        result.length === 0 ||
        result?.[0] == "TriggerFinalizedDate" ||
        result?.[0] == "ValidationNotFound" ||
        result?.[0] == "SetOrderLineItem" ||
        result?.[0] == "SetOrderAndFinalized" ||
        (result?.[0] == "SetOrderCompletenessAndFinalized" && result?.[1].length === 0) ||
        (result?.[0] == "SetOrderAndCompleteness" && result?.[1].length === 0) ||
        (result?.[0] == "CompletenessAndFinalized" && result?.[1].length === 0)
      ) {
        row[field as keyof IProductList] = text;
        row["OmsOrderStateId"] = text;
        row["IsPriceUpdated"] = false;
        updateLineItemStatusHandler(row);
      } else {
        showValidationMessages(result.length > 1 ? result?.[1] : result);
      }
    }
    tableData[index] = row;
    setProductList(tableData);
  };

  const onChangeHandlerForTotalUpdate = (
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    text: any,
    field: string,
    index: number,
    eventName: string
  ) => {
    const tableData: IProductList[] = [...productList];
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    const row: any = tableData[index];
    row[field as keyof IProductList] = text;
    const isPriceValueChanged = !(row.Price == row.onChangePrice);
    const isQuantityValueChanged =
    row.Quantity !== row.onChangeQuantity || (row.Quantity === 0 && row.onChangeQuantity === "");
    if (eventName == "onChange") {
      if (field == "onChangeQuantity" || field == "onChangePrice") {
        const total =
          parseFloat(row.onChangeQuantity || 0.0) * parseFloat(row.onChangePrice || 0.0);
        row.Total = total.toFixed(priceRoundOff);
        tableData[index] = row;
        setProductList(tableData);
      }
    }
    if (eventName == "onBlur") {
      if (field == "onChangePrice" && isPriceValueChanged) {
        /**
         * if price is not entered and the input event shift to blur then
         * set the first original price as it is to the input.
         */
        if (row.onChangePrice?.trim() == "") {
          row["onChangePrice"] = row?.Price;
          tableData[index] = row;
          setProductList(tableData);
          return;
        }

        dispatch(
          setPriceOrderNotesDetails({
            OrderProductId: row?.OrderProductId || "",
            visible: true,
            index: index,
          })
        );
      }
      if (field == "onChangeQuantity" && isQuantityValueChanged) {
        row["Quantity"] = row?.onChangeQuantity;
        updateLineItemQuantityHandler(row, index);
        getOrderDetails();
      }
    }
    if (eventName == "onClick") {
      const SkuQuantityDetails = [];
      let payload = {};
      const filterSameSKUData: IProductList[] = productList.filter((item) => {
        return item.SKU === row.SKU;
      });
      if (filterSameSKUData.length > 1) {
        // eslint-disable-next-line
        //@ts-ignore
        const sameSKUQtySummation = filterSameSKUData.reduce((a, b) => {
          // eslint-disable-next-line
          //@ts-ignore
          return a?.Quantity + b?.Quantity;
        });
        SkuQuantityDetails.push({
          SKU: filterSameSKUData[0].SKU,
          Quantity: sameSKUQtySummation,
        });

        payload = {
          SKU: row.SKU,
          Price: row.Price,
          Quantity: row.Quantity,
          OrderId: row.OrderId,
          OrderProductId: row.OrderProductId,
          SkuQuantityDetails: JSON.stringify(SkuQuantityDetails),
        };
      } else {
        SkuQuantityDetails.push({
          SKU: filterSameSKUData[0].SKU,
          Quantity: filterSameSKUData[0].Quantity,
        });
        payload = {
          SKU: row.SKU,
          Price: row.Price,
          Quantity: row.Quantity,
          OrderId: row.OrderId,
          OrderProductId: row.OrderProductId,
          SkuQuantityDetails: JSON.stringify(SkuQuantityDetails),
        };
      }
      row["IsPriceUpdated"] = true;
      const updateConditions = {
        index: index,
        refreshList: false,
      };
      resetLineItemPriceHandler(payload, updateConditions);
      row["IsPriceUpdated"] = false;
    }
    tableData[index] = row;
    setProductList(tableData);
  };

  const handlePriceChangeNote = (action: string) => {
    if (action === "add") {
      updateLineItemPriceHandler();
    } else {
      //on cancel button click of note, set the initial price as it is
      const tableData: IProductList[] = [...productList];
      const row: IProductList = tableData[priceNoteChangeInfo.index];
      row["onChangePrice"] = row?.Price;
      tableData[priceNoteChangeInfo.index] = row;
      setProductList(tableData);
    }
  };

  const updatedData = (data: IProductList[]) => {
    const filterData: IProductList[] = data.filter((item) => {
      return selectedRowKeys.includes(item.OrderProductId!);
    });
    const arr: OrderStatusListProps[] = [];
    filterData.forEach((item) => {
      const data: IProductList[] = orderStatusList.filter((data) => {
        return data.OmsOrderStateId == item.OmsOrderStateId;
      });
      const addOrderProductId = data.map((product) => {
        return {
          ...product,
          OrderProductId: item.OrderProductId,
          SKU: item.SKU,
          IsPriceUpdated: item.IsPriceUpdated,
        };
      });
      //eslint-disable-next-line
      // @ts-ignore
      arr.push(addOrderProductId);
    });
    return arr.flat(2);
  };

  const updateLineItemPriceHandler = () => {
    setLoading(true);
    const tableData: IProductList[] = [...productList];
    const row: IProductList = tableData[priceNoteChangeInfo.index];
    const OldPrice = row["Price"];
    row["Price"] = row?.onChangePrice;
    row["IsPriceUpdated"] = true;
    tableData[priceNoteChangeInfo.index] = row;
    setProductList(tableData);

    const updateRecordRow = updatedData(tableData);
    setRecordRowClassName(updateRecordRow);

    //API calling
    const payload = {
      OrderId: row?.OrderId,
      OrderProductId: row?.OrderProductId,
      Price: row?.Price,
      OldPrice: OldPrice,
      ProductNote: priceNoteChangeInfo.notes || "",
    };

    if (row?.Price != "") {
      updateLineItemPrice(payload)
        .then((response) => {
          if (!response?.HasError) {
            calculateOrder();
            notificationController.success({
              message: translate("editOrder.recordUpdatedSuccessMessage"),
              placement: "top",
            });
            setLoading(false);
          }
        })
        .catch((error) => {
          notificationController.error({
            message: translate(error.message),
          });
          setLoading(false);
        });
    } else {
      setLoading(false);
      notificationController.error({
        message: translate("editOrder.priceRequiredErrorMessage"),
        placement: "top",
      });
    }
  };

  const updateLineItemQuantityHandler = (rowItem: IProductList, index: number) => {
    setLoading(true);
    const payload = {
      OrderId: rowItem?.OrderId,
      OrderProductId: rowItem?.OrderProductId,
      Quantity: rowItem?.Quantity,
    };
    if (rowItem?.Quantity) {
      updateLineItemQuantity(payload)
        .then((response) => {
          if (response?.length) {
            //update price from response
            const tableData: IProductList[] = [...productList];
            const row = tableData[index];
            row["Price"] = response?.[0]?.Price;
            row["onChangePrice"] = response?.[0]?.Price;
            tableData[index] = row;
            setProductList(tableData);
          }
          fetchProductList(orderId);
          calculateOrder();
          notificationController.success({
            message: translate("editOrder.recordUpdatedSuccessMessage"),
            placement: "top",
          });
          setLoading(false);
        })
        .catch((error) => {
          setLoading(false);
          notificationController.error({
            message: translate(error.message),
          });
        });
    } else {
      setLoading(false);
      notificationController.error({
        message: translate("editOrder.quantityRequiredErrorMessage"),
        placement: "top",
      });
    }
  };

  const updateLineItemStatusHandler = (rowItem: IProductList) => {
    setLoading(true);
    const payload = {
      OrderId: rowItem?.OrderId,
      OrderProductId: rowItem?.OrderProductId,
      OmsOrderStateId: rowItem?.OmsOrderStateId,
      SKU: rowItem?.SKU,
    };
    updateLineItemStatus(payload)
      .then((response) => {
        if (!response?.HasError) {
          notificationController.success({
            message: translate("editOrder.recordUpdatedSuccessMessage"),
            placement: "top",
          });
        }
        setLoading(false);
      })
      .catch((error) => {
        setLoading(false);
        notificationController.error({
          message: translate(error.message),
        });
      });
  };

  const resetLineItemPriceHandler = (
    payload: IIsPriceResetProductList,
    updateConditions?: { index: number | undefined; refreshList: boolean },
    notAllowLineItemSKUs?: string
  ) => {
    setLoading(true);
    resetLineItemPrice(payload)
      .then((response) => {
        if (updateConditions?.index != undefined) {
          const tableData: IIsPriceResetProductList[] = [...productList];
          const row = tableData[updateConditions?.index];
          row["Price"] = response?.[0]?.Price;
          // eslint-disable-next-line
          //@ts-ignore
          row["onChangePrice"] = response?.[0]?.Price;
          tableData[updateConditions?.index] = row;
          setProductList(tableData);
          calculateOrder();
        }
        //refresh all product list on multiple prices update
        if (updateConditions?.refreshList) {
          fetchProductList(orderId);
          calculateOrder();
        }
        if (!notAllowLineItemSKUs) {
          notificationController.success({
            message: translate("editOrder.recordUpdatedSuccessMessage"),
            placement: "top",
          });
          getOrderDetails();
        } else {
          notificationController.error({
            message: translate("editOrder.nonEditableRecordUpdatedSuccessMessageSKU"),
            placement: "top",
          });
        }
        setLoading(false);
      })
      .catch((error) => {
        setLoading(false);
        notificationController.error({
          message: translate(error.message),
        });
      });
  };

  const fetchProductList = (orderId: string | undefined) => {
    setLoading(true);
    setIsCalledByEditOrder(false);
    httpApi
      .get(GET_PRODUCTLISTBYORDERID_API + "/" + orderId)
      .then((response) => {
        const responseData = JSON.parse(response?.data?.Order.OrderDetail);
        const productList: IProductList[] = responseData[0].OrderProduct;
        const skuStatusList: ISkuStatusList[] = response?.data?.Order?.SkuStatusList || [];
        productList?.map((item: IProductList) => {
          item.onChangePrice =
            item?.Price != null && item?.Price !== undefined
              ? parseFloat(item.Price).toFixed(priceRoundOff)
              : item.Price;
          item.onChangeQuantity = item.Quantity;
          const skuStatus = skuStatusList.find((statusItem) => statusItem.Sku === item.SKU)?.Status;
          if (skuStatus !== undefined) {
            item.SkuStatus = skuStatus;
          }
          return item;
        });
        setProductList(productList);
        setLoading(false);
      })
      .catch((error) => {
        setLoading(false);
        throw error;
      });
  };

  const ProductToolshandler = (type: string) => {
    if (type == "resetPrice") {
      resetPrice();
      setSelectedRowKeys([]);
    } else if (type == "SendCartLine") {
      SendCartLine();
    } else if (type == DELETE_TYPES.DELETE_MULTIPLE || type == DELETE_TYPES.CLEAR_ALL) {
      deleteLineItemHandler(type);
    }
  };

  const SendCartLine = () => {
    if (selectedRowKeys?.length > 0) {
      const lineItemIds = selectedRowKeys.join(",");
      const lineItemDetails: IProductSetLineItems = {
        orderId: orderId || "",
        lineItemIds: lineItemIds,
      };
      SendCartLineItems(lineItemDetails)
        .then((response) => {
          // eslint-disable-next-line @typescript-eslint/no-unused-vars, no-unused-vars
          const res = response?.data?.SavedView;
          if (response?.data?.IsSuccess) {
            notificationController.success({
              message: translate("products.SendCartLineItems"),
              placement: "top",
            });
            getOrderDetails();
          } else {
            notificationController.error({
              message: translate("products.ErrorSendCartLineItems"),
              placement: "top",
            });
          }
        })
        .catch((err) => {
          setLoading(false);
          notificationController.error({ message: err.message });
        });
    } else {
      notificationController.error({
        message: translate("products.isRecordsSelectedCheckMsg"),
        placement: "top",
      });
    }
  };
  /**
   *
   * @returns
   */
  const resetPrice = () => {
    if (selectedRowKeys?.length == 0) {
      recordEmptyMessage();
      return;
    }
    const allowResetPriceId = [];
    const notAllowResetPriceSKU = [];
    const SkuQuantityDetails: IIsPriceResetProductList[] = [];
    if (recordRowClassName) {
      for (let i = 0; i < recordRowClassName.length; i++) {
        if (recordRowClassName[i].IsPriceUpdated) {
          if (recordRowClassName[i].IsEdit) {
            allowResetPriceId.push(recordRowClassName[i].OrderProductId);
          } else {
            notAllowResetPriceSKU.push(recordRowClassName[i].SKU);
          }
          recordRowClassName[i].IsPriceUpdated = false;
        }
      }
      const filterSameSKUData: IProductList[] = productList.filter((item) =>
        recordRowClassName.some((otherItem) => otherItem.SKU === item.SKU)
      );
      if (filterSameSKUData.length > 1) {
        const sameSKUQtySummation = filterSameSKUData.reduce((accumulator, order) => {
          // eslint-disable-next-line
          // @ts-ignore
          const existingOrder = accumulator.find((item) => item.SKU === order.SKU);

          if (existingOrder) {
            // eslint-disable-next-line
            //@ts-ignore
            existingOrder.Quantity += order.Quantity;
          } else {
            // eslint-disable-next-line
            //@ts-ignore
            accumulator.push({
              SKU: order.SKU,
              Quantity: order.Quantity,
            });
          }

          return accumulator;
        }, []);
        // eslint-disable-next-line
        //@ts-ignore
        SkuQuantityDetails.push(sameSKUQtySummation);
      }
    }
    const allowLineItemIds = allowResetPriceId.join(",");
    const notAllowLineItemSKUs = notAllowResetPriceSKU.join(",");
    if (allowLineItemIds != "") {
      const lineItemDetails = {
        OrderProductId: allowLineItemIds,
        OrderId: orderId || "",
        SkuQuantityDetails: JSON.stringify(SkuQuantityDetails.flat(2)),
      };
      const updateConditions = {
        index: undefined,
        refreshList: true,
      };
      resetLineItemPriceHandler(
        // eslint-disable-next-line
        //@ts-ignore
        lineItemDetails,
        updateConditions,
        notAllowLineItemSKUs ? notAllowLineItemSKUs : ""
      );
    }
  };
  /**
   * This handler is use for delete the line items which added on product level
   * This same handler is use for clear all the line items from the list
   */
  const deleteLineItemHandler = (action: string) => {
    if (action == DELETE_TYPES.DELETE_MULTIPLE) {
      if (selectedRowKeys?.length == 0) {
        recordEmptyMessage();
        return;
      }
    }
    setDeleteAction(action);
    setIsConfirmModalVisible(true);
  };

  const clearAllHandler = () => {
    const allowDeleteId = [];
    const notAllowDeleteSKU = [];
    const orderIdList: OrderStatusListProps[] = [];
    const allIdList: string[] = [];
    productList.forEach((item) => {
      const data: OrderStatusListProps[] = orderStatusList.filter((data) => {
        return data.OmsOrderStateId == item.OmsOrderStateId;
      });
      for (let i = 0; i < data.length; i++) {
        if (data[i].OmsOrderStateId == item.OmsOrderStateId && data[i].IsEdit) {
          orderIdList.push({
            ...data[i],
            OrderProductId: item.OrderProductId,
          });
        }
      }
      for (let j = 0; j < orderIdList.length; j++) {
        allIdList.push(orderIdList[j].OrderProductId!);
      }
    });
    if (recordRowClassName) {
      for (let i = 0; i < recordRowClassName.length; i++) {
        if (recordRowClassName[i].IsEdit) {
          allowDeleteId.push(recordRowClassName[i].OrderProductId);
        } else {
          notAllowDeleteSKU.push(recordRowClassName[i].SKU);
        }
      }
    }
    const allowDeleteLineItemIds = allowDeleteId.join(",");
    const notAllowDeleteLineItemSKUs = notAllowDeleteSKU.join(",");
    const allLineItemIds = allIdList.join(",");
    switch (deleteAction) {
      case DELETE_TYPES.DELETE:
        deleteLineItems(
          deleteOrderId,
          false,
          notAllowDeleteLineItemSKUs ? notAllowDeleteLineItemSKUs : ""
        );
        break;
      case DELETE_TYPES.DELETE_MULTIPLE:
        deleteLineItems(
          allowDeleteLineItemIds,
          false,
          notAllowDeleteLineItemSKUs ? notAllowDeleteLineItemSKUs : ""
        );
        break;
      case DELETE_TYPES.CLEAR_ALL:
        deleteLineItems(
          allLineItemIds,
          false,
          notAllowDeleteLineItemSKUs ? notAllowDeleteLineItemSKUs : ""
        );
        break;
      default:
        deleteLineItems(
          allowDeleteLineItemIds,
          false,
          notAllowDeleteLineItemSKUs ? notAllowDeleteLineItemSKUs : ""
        );
    }
  };

  /**
   * const rowSelection` is an object that defines the behavior of row
   * selection in the `Table` component.
   */
  const rowSelection = {
    selectedRowKeys,
    onChange: (selectedRowKeys: React.Key[]) => {
      const filterData: IProductList[] = productList.filter((item) => {
        return selectedRowKeys.includes(item.OrderProductId!);
      });
      const arr: OrderStatusListProps[] = [];
      filterData.forEach((item) => {
        const data: IProductList[] = orderStatusList.filter((data) => {
          return data.OmsOrderStateId == item.OmsOrderStateId;
        });
        const addOrderProductId = data.map((product) => {
          return {
            ...product,
            OrderProductId: item.OrderProductId,
            SKU: item.SKU,
            IsPriceUpdated: item.IsPriceUpdated,
          };
        });
        //eslint-disable-next-line
        // @ts-ignore
        arr.push(addOrderProductId);
      });
      setRecordRowClassName(arr.flat(2));
      setSelectedRowKeys(selectedRowKeys);
    },
    getCheckboxProps: () => {
      return {
        disabled: false,
        style: {
          cursor: "pointer",
          pointerEvents: "auto" as React.CSSProperties["pointerEvents"],
        },
      };
    },
  };

  const recordEmptyMessage = () => {
    notificationController.error({
      message: translate("editOrder.pleaseSelectRecordMessage"),
      placement: "top",
    });
  };

  const onEditItemPress = (lineItemProductId: string, childSKU: string) => {
    navigate(`/${ROUTES_PATH.EDIT_PRODUCT}/${lineItemProductId}/${childSKU}`);
  };

  const onDeleteItemPress = (lineItemProductId: string, deleteTypeFlag: string) => {
    setDeleteAction(deleteTypeFlag);
    setIsConfirmModalVisible(true);
    setDeleteOrderId(lineItemProductId);
  };

  const deleteLineItems = (
    lineItemProductId: string,
    isDeleteAll: boolean,
    notAllowLineItemSKUs: string
  ) => {
    setLoading(true);
    const lineItemDetails: IProductList = {
      IsDeleteAll: isDeleteAll,
      OrderProductId: lineItemProductId,
      OrderId: orderId || "",
    };
    return httpApi
      .post(DELETE_LINEITEM_API, lineItemDetails, {})
      .then((response) => {
        fetchProductList(orderId);
        calculateOrder();
        if (response?.data?.IsSuccess && !notAllowLineItemSKUs) {
          notificationController.success({
            message: translate("editOrder.recordDeletedSuccessMessage"),
            placement: "top",
          });
        } else {
          notificationController.error({
            message: translate("editOrder.nonEditableRecordDeleteSuccessMessageSKU"),
            placement: "top",
          });
        }
        setIsConfirmModalVisible(false);
        setDeleteAction("");
        setDeleteOrderId("");
      })
      .catch((error) => {
        notificationController.error({ message: error.message, placement: "top" });
        setIsConfirmModalVisible(false);
        setLoading(false);
        throw error;
      });
  };

  const productDeactivateMessage = () => {
    notificationController.error({
      message: translate("editOrder.productDeactivate"),
      placement: "top",
    });
  };

  const cols = columns(
    onChangeHandler,
    onChangeHandlerForTotalUpdate,
    orderStatusList,
    isExpandable,
    onEditItemPress,
    setIsDuplicateOrder,
    onDeleteItemPress,
    ability,
    productList,
    isEditPermission,
    handlePriceChangeNote,
    getOrderDetails,
    productDeactivateMessage
  );

  const refreshListOnBulkAdd = () => {
    fetchProductList(orderId);
  };

  const duplicate = () => {
    const requestBody: IDuplicateLineItemPayload = {
      OrderId: orderId || "",
      OrderProductId: isDuplicateOrder?.OrderProductId,
    };
    duplicateLineItem(requestBody)
      .then((response) => {
        const data = response?.data;
        if (data?.IsSuccess) {
          notificationController.success({
            message: translate("editOrder.recordDuplicatedSuccessMessage"),
          });
          fetchProductList(orderId);
          calculateOrder();
          handleBack();
          getOrderDetails();
        }
      })
      .catch((err) => {
        notificationController.error({ message: err.message });
      });
  };

  const handleBack = () => {
    setIsDuplicateOrder({
      visible: false,
      OrderProductId: "",
    });
  };

  /**
   * This function is used to navigate to the add products to the order page.
   */
  const addProductToOrder = () => {
    navigate(`/${ROUTES_PATH.ADD_PRODUCTS}/${orderId}`);
  };

  const checkIsAllowEditAtLineItemLevel = (record: IProductList) => {
    const statusObj = orderStatusList?.find((el) => {
      return el?.OmsOrderStateId == record?.OmsOrderStateId;
    });
    return statusObj == null ? false : !statusObj?.IsEdit;
  };

  return (
    <div className="px-15 pt-8">
      <Table
        title={() => (
          <ProductListHeader
            IsExpandable={isExpandable}
            setIsExpandable={setIsExpandable}
            ProductToolshandler={ProductToolshandler}
            setIsQuickAddModalVisible={setIsQuickAddModalVisible}
            productList={productList}
          />
        )}
        dataSource={[...productList]}
        columns={cols}
        loading={loading}
        pagination={false}
        style={{ width: "100%", height: "100%" }}
        scroll={{ x: "max-content", y: 400 }}
        data-test-selector="tblProductList"
        rowKey={(record) => record.OrderProductId || ""}
        rowClassName={(record) => (checkIsAllowEditAtLineItemLevel(record) ? "disabled-row" : "")}
        rowSelection={{
          type: "checkbox",
          ...rowSelection,
        }}
        locale={{
          emptyText: (
            <Space direction="vertical" size={1} className="empty-table-container">
              <Button
                type="primary"
                shape="circle"
                icon={<PlusOutlined />}
                size={"large"}
                data-test-selector="btnAddProduct"
                onClick={addProductToOrder}
                disabled={!isEditPermission}
              />
              <Title level={4}>{translate("editOrder.addProductBtn")}</Title>
              <Text className="m-0">{translate("editOrder.pleaseAddProductMessage")}</Text>
            </Space>
          ),
        }}
        size={"small"}
        className={productList.length ? "" : "no-product-data"}
      />
      <DuplicateModalComponent
        title={translate("editOrder.confirmDuplicateTitle")}
        visible={isDuplicateOrder?.visible}
        onCancel={handleBack}
        dataTestSelector="popConfirm"
        zIndex={10}
        isMaskClosable={true}
        footer={null}
        className="duplicate-modal-popup"
      >
        Do you want to duplicate the selected record?
        <div className="popup-action mt-24">
          <Space>
            <Button icon={<ArrowLeftOutlined />} onClick={handleBack} size={"middle"}>
              {translate("editOrder.backBtn")}
            </Button>
            <Button type="primary" onClick={duplicate} size={"middle"}>
              {translate("editOrder.duplicateBtn")}
            </Button>
          </Space>
        </div>
      </DuplicateModalComponent>
      <QuickAddModal
        open={isQuickAddModalVisible}
        setOpen={setIsQuickAddModalVisible}
        refreshListOnBulkAdd={refreshListOnBulkAdd}
        calculateOrder={calculateOrder}
        getOrderDetailsSKU={getOrderDetails}
      />
      <ModalComponent
        title={translate("editOrder.confirmDeleteTitle")}
        visible={isConfirmModalVisible}
        onOK={() => {
          clearAllHandler();
          getOrderDetails();
        }}
        onCancel={() => {
          setIsConfirmModalVisible(false);
        }}
        okText={translate("editOrder.tblOkColumnLabel")}
        cancelText={
          <Space className="d-flex justify-center align-center">
            <ArrowLeftOutlined />
            <span>{translate("editOrder.backBtn")}</span>
          </Space>
        }
        dataTestSelector="popConfirm"
        zIndex={10}
        isMaskClosable={true}
        className="standard-modal"
      >
        {translate("editOrder.permanentlyDeleteItemMessage")}
      </ModalComponent>
    </div>
  );
};
