import React from "react";
import { Button, Col, Row, Select, Space, Typography } from "antd";
import { PlusOutlined } from "@ant-design/icons";
import { ShipToProps } from "interfaces/ClientInterface/IShipping";
import { translate } from "i18n";
const { Text } = Typography;

/**
 * @param {shipTo}  - `ShipTo`: selected value of Ship To DropDown
 * @param {setShipTo}  - `setShipTo`: Setter method to update the shipTo dropdown value
 * @param {shippingList}  - `shippingList`: list of shipping address options to dropdown.
 * @param {onAddClick}  - `onAddClick`: onClick callback of plus icon button
 * @returns A React functional component that renders a SelectInput component a "Add" button.
 */
export const ShipTo: React.FC<ShipToProps> = ({
  shipTo,
  setShipTo,
  shippingList,
  onAddClick,
  error,
  setError,
  onShipToSelection,
  isUserExists,
}: ShipToProps) => {
  return (
    <Row align="middle">
      <Col span={8}>
        <Text className="key-title required">{translate("editOrder.shipToTitle")}:</Text>
      </Col>
      <Col span={16}>
        <Space>
          <Select
            disabled={isUserExists}
            placeholder="Select"
            options={shippingList || []}
            className="ship-inputs-width"
            showSearch={true}
            data-test-selector="drpShipTo"
            onChange={(ship) => {
              setShipTo(ship);
              setError((prevState) => ({
                ...prevState,
                ShipToError: "",
              }));
              onShipToSelection && onShipToSelection(ship);
            }}
            value={shipTo || undefined}
            allowClear={true}
            fieldNames={{ label: "DisplayName", value: "AddressId" }}
          />
          <Button
            disabled={isUserExists}
            icon={<PlusOutlined className="add-icon" />}
            size="middle"
            data-test-selector="btnAddShipToAddress"
            onClick={onAddClick}
          />
        </Space>
        <div className="error">{error && error?.ShipToError}</div>
      </Col>
    </Row>
  );
};

export default ShipTo;
