/* eslint-disable max-lines-per-function */
/* eslint-disable max-lines */
/* eslint-disable @typescript-eslint/no-unused-vars */
/* eslint-disable max-len */
/* eslint no-unused-vars : "off" */
import React, { useEffect, useState } from "react";

import {
  Col,
  Row,
  Button,
  Space,
  Typography,
  Radio,
  Input,
  DatePickerProps,
  DatePicker,
  Spin,
} from "antd";
import { EditOutlined } from "@ant-design/icons";
import type { RadioChangeEvent } from "antd";
import type { Dayjs } from "dayjs";
import "./Shipping.scss";
import ShipTo from "./ShipTo";
import { IError, IShippingMethod, IShippingTo, IShoppingCartModel } from "interfaces/APIInterface/IShipping";
import {
  CREATE_SHIPPING_ADDRESS_API,
  UPDATE_SHIPPING_ADDRESS_API,
  GET_SHIPPING_ADDRESS_API,
  CREATE_ORDER_SHIPPING_API,
  GET_SHIPPING_DETAILS_API,
  DATE_FORMATE,
} from "config/constant";
import { notificationController } from "components/Common/Notification/Notification";
import AddAddressModal from "components/Common/AddAddress/AddAddress";
import { httpApi } from "api/http.api";
import { readUserId } from "api/services/localStorage.service";
import { useParams } from "react-router-dom";
import dayjs from "dayjs";
import customParseFormat from "dayjs/plugin/customParseFormat";
import { checkPermissionToShow, isObjectEmpty } from "utils";
import { IShippingProps } from "interfaces/ClientInterface/IShipping";
import { IAddressProps } from "interfaces/APIInterface/IAddAddress";
import Loader from "components/Common/Loader/Loader";
import { translate } from "i18n";
import { useAppSelector } from "hooks/reduxHooks";
import { isValidPhoneNumber } from "utils/validation";
import type { RangePickerProps } from "antd/es/date-picker";
import { getShippingMethod } from "api/services/shipping.api";
import { getGlobalSetting } from "api/services/localStorage.service";

dayjs.extend(customParseFormat);

const { Text } = Typography;
const { TextArea } = Input;

/**
 * @returns Shipping function is a React component that renders a form
 * for entering shipping information
 */
// eslint-disable-next-line max-lines-per-function

const Shipping: React.FC<IShippingProps> = ({
  order,
  setOrder,
  orderData,
  calculateOrder,
  productList,
  getOrderDetails,
  userId
}: IShippingProps) => {
  const accountId = useAppSelector((state) => state.editOrder.accountId);
  const isEditPermission = useAppSelector((state) => state.permission.isEditPermission);
  const [shipTo, setShipTo] = useState("");
  const [shipToList, setShipToList] = useState<IShippingTo[]>([]);
  const [showAddress, setShowAddress] = useState({} as IShippingTo);
  const [shipMethod, setShipMethod] = useState<IShippingMethod[]>([]);
  const [phone, setPhone] = useState("");
  const [shippingMethod, setShippingMethod] = useState(0);
  const [trackingNumber, setTrackingNumber] = useState("");
  const [shippingOption, setShippingOption] = useState("Ship Complete");
  const [shippingNotes, setShippingNotes] = useState("");
  const [isAddressModalVisible, setIsAddressModalVisible] = useState(false);
  const [isEditAddress, setIsEditAddress] = useState(false);
  const [inHandsDate, setInHandsDate] = useState<string | null>(null);
  const { orderId } = useParams<Record<string, string | undefined>>();
  const initialAddress = {
    AddressId: "",
    DisplayName: "",
    FirstName: "",
    LastName: "",
    CompanyName: "",
    Address1: "",
    Address2: "",
    CountryName: translate("addAddress.unitedStates"),
    StateName: "",
    City: "",
    PostalCode: "",
    PhoneNumber: "",
    IsDefaultBilling: false,
    IsDefaultShipping: false,
  };
  const [addressData, setAddressData] = useState<IAddressProps>(initialAddress);
  const [shipmentData, setShippingData] = useState("");
  const [alternateNumber, setAlternateNumber] = useState("");
  const [isUserExists, setIsUserExists] = useState(false);
  const currentDate = dayjs(); // Get the current date
  const futureDate = currentDate.add(1, "month"); // Add 1 month to the current date
  const [loading, setLoading] = useState(false);
  const globalSettings = getGlobalSetting() ? JSON.parse(getGlobalSetting() || "") : {};
  const priceRoundOff = globalSettings?.PriceRoundOff;
  const [callOnceCheck, setCallOnceCheck] = useState(false);
  const [shippingLoading, setShippingLoading] = useState(false);

  /**
   * Use State to declare empty property.
   */
  const [error, setError] = useState<IError>({
    ShipToError: "",
    PhoneError: "",
    ShippingMethodError: "",
    TrackingNumberError: "",
    ShipDateError: "",
    ShippingOptionsError: "",
  });

  /**
   * useEffect is used to get the shipTo address list according to order userId.
   */
  useEffect(() => {
    if (userId) {
      clearOrderShippingDetails();
      callOnceCheck && fetchShipTo();
      setIsUserExists(false);
    } else {
      setShipToList([]);
      clearOrderShippingDetails();
      setIsUserExists(true);
    }
    setInHandsDate(futureDate.format(DATE_FORMATE));
    // eslint-disable-next-line react-hooks/exhaustive-deps
  }, [userId]);

  useEffect(() => {
    if (productList?.length == 0) {
      isProductEmptyCheck();
    }
    // eslint-disable-next-line react-hooks/exhaustive-deps
  }, [productList]);

  useEffect(() => {
    fetchShippingDetails();
    // eslint-disable-next-line react-hooks/exhaustive-deps
  }, []);

  /**
   * This function sets the selected date from a date picker component to a state variable.
   * @param date - The selected date in the DatePicker component. It is of type `dayjs` which
   * is a JavaScript date library for parsing, validating, manipulating, and formatting dates.
   * @param dateString - The dateString parameter in the onDateChange function is a string
   * representation of the selected date in the DatePicker component.
   * It is formatted according to the format specified in the DatePicker's props.
   * In this case, it is being used to update the state
   * variable inHandsDate with the selected date.
   */
  const onDateChange: DatePickerProps["onChange"] = (date, dateString) => {
    setInHandsDate(dateString);
    setError((prevState) => ({
      ...prevState,
      ShipDateError: "",
    }));
  };

  /**
   * Function is used to clear shipping info fields.
   */
  const clearOrderShippingDetails = () => {
    setShipTo("");
    setShowAddress({} as IShippingTo);
    setPhone("");
    setShipMethod([]);
    setTrackingNumber("");
    setInHandsDate("");
    setShippingOption("Ship Complete");
    setShippingNotes("");
    setShippingMethod(0);
  };

  /**
   * function to get order shipping details from API.
   */
  const fetchShippingDetails = () => {
    httpApi
      .get(GET_SHIPPING_DETAILS_API + "/" + orderId)
      .then((response) => {
        const data = JSON.parse(response?.data?.OrderShipment?.OrderDetail)[0].OrderShipment[0];
        //Fetch List on mount.
        fetchShipTo(data?.ShippingAddress[0]?.AddressId || "");
        setAlternateNumber(data?.ShippingAddress[0]?.AlternateMobileNumber);
        setPhone(data?.ShippingAddress[0]?.AlternateMobileNumber);
        setShippingMethod(data?.ShippingId);
        setTrackingNumber(data?.TrackingNumber);
        if (data?.ShipDate) {
          setInHandsDate(data?.ShipDate);
        }
        setShippingOption(data?.ShippingConstraintCode || shippingOption);
        setShippingNotes(data?.ShippingNote[0]?.Note);
        setShippingData(data?.OrderShipmentId || "");
        calculateOrder();
        setCallOnceCheck(true);
      })
      .catch((err) => {
        notificationController.error({ message: err.message, placement: "top" });
      });
  };

  /**
   * Added the const to get user address from the API and display.
   */
  const fetchShipTo = (addressId?: string | undefined) => {
    setLoading(true);
    httpApi
      .get(accountId ? "/account/addresslist" : "/customer/addresslist", {
        params: {
          expand: "ZnodeAddress",
          filter: accountId ? `AccountId~eq~${accountId}` : `UserId~eq~${orderData?.userId}`,
          sort: "",
          page: "",
          publishState: "",
        },
      })
      .then((response) => {
        const data = response?.data?.AddressList;
        const listData = data ? (Array.isArray(data) ? data : [data]) : [];
        const defaultAddress = listData?.find((item: IShippingTo) => item.IsDefaultShipping);
        setShipToList(listData);
        if (addressId) {
          const data = listData?.find((item: IShippingTo) => item.AddressId == addressId);
          const postalCode = data?.PostalCode;
          setShowAddress((data as IShippingTo) || {});
          if (data != undefined) {
            setShipTo(addressId);
            fetchShipMethod(postalCode);
          } else {
            const defaultPostalCode = defaultAddress?.PostalCode;
            setShowAddress((defaultAddress as IShippingTo) || {});
            setShipTo(defaultAddress?.AddressId);
            fetchShipMethod(defaultPostalCode);
            setShippingMethod(0);
          }
        } else {
          const postalCode = defaultAddress?.PostalCode;
          setShowAddress((defaultAddress as IShippingTo) || {});
          setShipTo(defaultAddress?.AddressId);
          fetchShipMethod(postalCode);
        }
        setLoading(false);
      })
      .catch((err) => {
        setLoading(false);
        notificationController.error({ message: err.message, placement: "top" });
      });
  };

  /**
   * Added the const to get shipping methods associated with users.
   */
  const fetchShipMethod = (postalCode: string) => {
    const shippingData: IShippingTo = shipToList.filter((item: IShippingTo) => {
      return item.AddressId == shipTo;
    })[0];
    let PublishedCatalogId=0;    
    const shoppingCartModels: IShoppingCartModel[] = [];
    if (productList.length > 0) {
      productList.forEach((product) => {
        PublishedCatalogId=product.ZnodeCatalogId??0;
        const shoppingCartModeld: IShoppingCartModel = {
          Quantity: Number(product.Quantity),
          SKU: product.SKU ?? "",
          ConfigurableProductSKUs: product.SKU ?? "",
        };
        shoppingCartModels.push(shoppingCartModeld);
      });
    }
    const shippingMethodPayload: IShippingMethod = {
      PortalId: order.PortalId,
      UserId: orderData?.userId.toString(),
      ShippingAddressModel: shippingData,
      ShippingId: "",
      ShippingName: "",
      ShippingRate: "",
      ShippingCost: "",
      Description: "",
      LocaleId: order.LocaleId,
      PublishedCatalogId: PublishedCatalogId,
      ShoppingCartItems: shoppingCartModels,
    };

    /**
     * Function to get shipping methods payload and set it into state.
     */
    setShippingLoading(true);
    if (postalCode) {
      if (productList.length > 0) {
        getShippingMethod(postalCode, shippingMethodPayload)
          .then((res) => {
            const data = res?.data?.ShippingList;
            const formattedShipMethod =
              data &&
              data?.map((item: IShippingMethod) => ({
                ...item,
                ShippingRate: parseFloat(item?.ShippingRate || "0.00")?.toFixed(priceRoundOff),
              }));
            setShipMethod(formattedShipMethod);
            setShippingLoading(false);
          })
          .catch(() => {
            setShippingLoading(false);
          });
      } else {
        isProductEmptyCheck();
      }
    }
    setLoading(false);
  };

  const isProductEmptyCheck = () => {
    setShipMethod([]);
    setError((prevState) => ({
      ...prevState,
      ShippingMethodError: translate("editOrder.pleaseSelectOneProductErrorMessage"),
    }));
  };

  /**
   * Event to view address popup model.
   */
  const onAddClickHandler = () => {
    setAddressData(initialAddress);
    setIsAddressModalVisible(true);
  };

  /**
   * Address Body to Add or update user address.
   */
  // eslint-disable-next-line @typescript-eslint/no-explicit-any
  const onAddressSaveHandler = (addressData: IAddressProps, form: any) => {
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    const body: any = {
      displayName: addressData.DisplayName,
      firstName: addressData.FirstName,
      lastName: addressData.LastName,
      companyName: addressData.CompanyName,
      address1: addressData.Address1,
      address2: addressData.Address2,
      countryName: addressData.CountryName,
      stateName: addressData.StateName,
      cityName: addressData.City,
      postalCode: addressData.PostalCode,
      phoneNumber: addressData.PhoneNumber,
      isDefaultBilling: addressData.IsDefaultBilling,
      isDefaultShipping: addressData.IsDefaultShipping,
      UserId: orderData?.userId.toString(),
    };

    /**
     * Check if the API request is for creating a new user address or updating an existing one.
     */
    if (isEditAddress) {
      body.addressId = shipTo;
      //Update user address
      httpApi
        .put(UPDATE_SHIPPING_ADDRESS_API, body, {})
        .then((response) => {
          const data = response?.data?.Address;
          fetchShipTo(data?.AddressId);
          setIsEditAddress(false);
          setIsAddressModalVisible(false);
          form.resetFields();
          form.setFieldsValue(initialAddress);
        })
        .catch((ex) => {
          notificationController.error({ message: ex.message });
        });
    } else {
      //Create user address
      httpApi
        .post(CREATE_SHIPPING_ADDRESS_API, body, {})
        .then((response) => {
          const data = response?.data?.Address;
          fetchShipTo(data?.AddressId);
          setShowAddress((data as IShippingTo) || {});
          fetchShipMethod(body.postalCode);
          setIsAddressModalVisible(false);
          form.resetFields();
          form.setFieldsValue(initialAddress);
        })
        .catch((ex) => {
          notificationController.error({ message: ex.message });
        });
    }
  };

  /**
   * Event to view edit address popup model and call api function to get address.
   */
  const onEditClickHandler = () => {
    fetchShippingAddress(shipTo);
  };

  /**
   * @param shipTo is used to get addressId.
   * API calls to Get selected shipping address and set the response to the model.
   */
  // eslint-disable-next-line @typescript-eslint/no-explicit-any
  const fetchShippingAddress = (shipTo: any) => {
    httpApi
      .get(GET_SHIPPING_ADDRESS_API + "/" + shipTo)
      .then((response) => {
        const data = response?.data?.CPAddressModel;
        setAddressData({
          AddressId: data?.AddressId || "",
          DisplayName: data?.DisplayName || "",
          FirstName: data?.FirstName || "",
          LastName: data?.LastName || "",
          CompanyName: data?.CompanyName || "",
          Address1: data?.Address1 || "",
          Address2: data?.Address2 || "",
          CountryName: data?.CountryName || "",
          StateName: data?.StateName || "",
          City: data?.CityName || "",
          PostalCode: data?.PostalCode || "",
          PhoneNumber: data?.PhoneNumber || "",
          IsDefaultBilling: data?.IsDefaultBilling || "",
          IsDefaultShipping: data?.IsDefaultShipping || "",
        });
        setIsAddressModalVisible(true);
        setIsEditAddress(true);
      })
      .catch((err) => {
        notificationController.error({ message: err.message, placement: "top" });
      });
  };

  /**
   * Function to pass body to save Shipping-Info into Database with API call.
   */
  const onOrderShippingSaveHandler = () => {
    /**
     * Function to validate shipping address.
     * @returns error status.
     */
    const validateShipTo = () => {
      if (!shipTo) {
        setError((prevState) => ({
          ...prevState,
          ShipToError: translate("editOrder.shipToErrorMessage"),
        }));
        return false;
      }
      return true;
    };

    /**
     * Function to validate shipping method.
     * @returns error status.
     */
    const validateShippingMethod = () => {
      if (productList.length > 0) {
        if (!shippingMethod) {
          setError((prevState) => ({
            ...prevState,
            ShippingMethodError: translate("editOrder.shippingMethodReqMessage"),
          }));
          return false;
        }
        return true;
      } else {
        setError((prevState) => ({
          ...prevState,
          ShippingMethodError: translate("editOrder.pleaseSelectOneProductErrorMessage"),
        }));
      }
    };

    /**
     * Function to validate In-Hands date.
     * @returns error status.
     */
    const validateInHandDate = () => {
      if (!inHandsDate) {
        setError((prevState) => ({
          ...prevState,
          ShipDateError: translate("editOrder.inHandDateReqMessage"),
        }));
        return false;
      }
      return true;
    };

    /**
     * Variables to store error status.
     */
    const isValidShipTo = validateShipTo();
    const isValidShippingMethod = validateShippingMethod();
    const isValidInHandDate = validateInHandDate();

    /**
     * Condition to check field validation error status.
     */
    if (!isValidShipTo || !isValidShippingMethod || !isValidInHandDate) {
      return;
    }

    /**
     * API call to create Shipping-Info Details with body.
     */
    const body = {
      OrderId: order.OrderId || orderId,
      OrderAddressId: "",
      Phone: phone,
      ClassId: order.ClassId || 5,
      ShippingId: shippingMethod,
      TrackingNumber: trackingNumber || "",
      ShipDate: inHandsDate || "",
      ShippingConstraintCode: shippingOption,
      IsShipCompletely: true,
      UserId: readUserId(),
      ShippingNotes: shippingNotes || "",
      IsDeleted: false,
      AddressId: shipTo,
      PhoneNumber: phone || "",
      OrderShipmentId: shipmentData !== "" ? shipmentData : "00000000-0000-0000-0000-000000000000",
    };

    //API to insert shipping-info details.
    // eslint-disable-next-line @typescript-eslint/no-empty-function
    httpApi
      .post(CREATE_ORDER_SHIPPING_API, body, {})
      .then((response) => {
        const data =
          response?.data?.OrderShipment?.OrderShipmentListModel?.OrderShipmentModels?.[0]
            ?.OrderShipmentId;
        setShippingData(data || "");
        setOrder((prevState) => ({
          ...prevState,
          ShipDate: inHandsDate?.toString(),
        }));
        calculateOrder();
        getOrderDetails();
        notificationController.success({
          message: translate("editOrder.shippingInfoSuccessMessage"),
        });
      })
      .catch(() => {
        notificationController.error({ message: translate("editOrder.failedToSaveInfo") });
      });
  };

  // eslint-disable-next-line @typescript-eslint/no-explicit-any
  const onModalCancelPress = (form: any) => {
    form.resetFields();
    form.setFieldsValue(initialAddress);
    setIsAddressModalVisible(false);
  };

  /**
   * function is ued to get selected address bu call back function.
   * @param selectedShipTo is used to take selected address.
   */
  const onShipToSelection = (selectedShipTo: string) => {
    const data = shipToList?.find((i: IShippingTo) => i.AddressId == selectedShipTo);
    setPhone(alternateNumber || "");
    setShowAddress(data as IShippingTo);
    fetchShipMethod(data?.PostalCode || "");
  };

  // eslint-disable-next-line arrow-body-style
  const disabledDate: RangePickerProps["disabledDate"] = (current) => {
    // Can not select date before today.
    return current && current < dayjs().startOf("day");
  };

  return (
    <Row
      className={isEditPermission ? "shipping-container" : "shipping-container disabled-container"}
      gutter={[30, 0]}
    >
      <Loader loading={loading} />
      {checkPermissionToShow(
        isEditPermission,
        <Col span={24} className="mb-8 d-flex justify-end">
          <Button
            disabled={isUserExists}
            type="primary"
            data-test-selector={"btnSaveShipping"}
            onClick={onOrderShippingSaveHandler}
            size="small"
          >
            {translate("editOrder.saveShippingDetailsBtn")}
          </Button>
        </Col>
      )}
      <Col span={8} className="d-flex ">
        <Space direction="vertical" size={4} className="w-100">
          <ShipTo
            shipTo={shipTo}
            setShipTo={setShipTo}
            shippingList={shipToList}
            onAddClick={onAddClickHandler}
            error={error}
            setError={setError}
            onShipToSelection={onShipToSelection}
            isUserExists={isUserExists}
          />
          {!isObjectEmpty(showAddress || {}) && (
            <Row align="middle">
              <Col span={16} push={8}>
                <Space direction="vertical" size={1}>
                  <Space size={10}>
                    <Text className="txt-bold text-color-gray">
                      {`${showAddress?.FirstName} ${showAddress?.LastName}`}
                    </Text>
                    <div data-test-selector="btnAddShipToAddress" onClick={onEditClickHandler}>
                      <EditOutlined className="add-icon" />
                    </div>
                  </Space>
                  <Text className="text-color-gray">
                    {`${showAddress?.Address1} , ${showAddress?.CityName} ,
                    ${showAddress?.StateName} , ${showAddress?.PostalCode}`}
                    <br></br>
                    {`Ph: ${showAddress?.PhoneNumber}`}
                  </Text>
                </Space>
              </Col>
            </Row>
          )}
          <Row align="middle" className="mt-5">
            <Col span={8}>
              <Text className="key-title">{translate("editOrder.shipToPhoneTitle")}:</Text>
            </Col>
            <Col span={16}>
              <Input
                disabled={isUserExists}
                className="ship-inputs-width"
                placeholder={translate("editOrder.enterPhoneNumber")}
                data-test-selector="txtPhoneNumber"
                value={phone}
                onChange={(e) => {
                  if (e.target.value.length <= 20) {
                    setPhone(e.target.value);
                  }
                }}
                onKeyUp={() => {
                  if (!phone) {
                    setError((prevError) => ({
                      ...prevError,
                      PhoneError: translate("editOrder.shipToPhoneReqErrorMessage"),
                    }));
                  } else if (phone && !isValidPhoneNumber.test(phone)) {
                    setError((prevError) => ({
                      ...prevError,
                      PhoneError: translate("editOrder.shipToPhoneValidationErrorMessage"),
                    }));
                  } else {
                    setError((prevError) => {
                      return {
                        ...prevError,
                        PhoneError: "",
                      };
                    });
                  }
                }}
                maxLength={20}
              />
              <div className="error">{error && error?.PhoneError}</div>
            </Col>
          </Row>
        </Space>
      </Col>
      <Col span={8} className="d-flex justify-center">
        <Space direction="vertical" size={0}>
          <div className="txt-bold text-color-gray mb-4 required">
            {translate("editOrder.shippingMethodTitle")}
          </div>
          <Space className="d-flex justify-center align-center">
            {
              shippingLoading && <Spin />
            }
          </Space>
          {shipTo ? (
            <Space direction="vertical" size={0}>
              {shipMethod?.length > 0 ? (
                <Radio.Group
                  onChange={(e: RadioChangeEvent) => {
                    setShippingMethod(e.target.value);
                    setError((prevState) => ({
                      ...prevState,
                      ShippingMethodError: "",
                    }));
                  }}
                  value={shippingMethod}
                  data-test-selector="chkShippingMethod"
                  disabled={isUserExists}
                >
                  <Space direction="vertical" size={4}>
                    {shipMethod.map((item: IShippingMethod) => {
                      return (
                        <Radio
                          key={item.ShippingId}
                          value={item?.ShippingId}
                          className="text-color-gray"
                        >
                          {item.Description}&nbsp;
                          <span className="txt-bold">- ${item.ShippingRate}</span>
                        </Radio>
                      );
                    })}
                  </Space>
                </Radio.Group>
              ) : (
                <span />
              )}
              <div className="error mp-8">{error && error?.ShippingMethodError}</div>
            </Space>
          ) : (
            <span />
          )}
          <Row align="middle" className="mt-5">
            <Col span={12}>
              <Text className="key-title">{translate("editOrder.trackingNumberTitle")}:</Text>
            </Col>
            <Col span={12}>
              <Input
                disabled={isUserExists}
                type="number"
                className="w-100"
                placeholder={translate("editOrder.enterTrackingNumber")}
                data-test-selector="txtTrackingNumber"
                value={trackingNumber}
                onChange={(e) => {
                  if (e.target.value.length <= 50) {
                    setTrackingNumber(e?.target?.value);
                    setError((prevState) => ({
                      ...prevState,
                      TrackingNumberError: "",
                    }));
                  }
                }}
                maxLength={50}
              />
              <div className="error">{error && error?.TrackingNumberError}</div>
            </Col>
          </Row>
        </Space>
      </Col>
      <Col span={8} className="d-flex">
        <Space direction="vertical" size={4}>
          <Row align="middle">
            <Col span={10}>
              <Text className="key-title required">In Hands Date:</Text>
            </Col>
            <Col span={14}>
              <DatePicker
                disabled={isUserExists}
                value={inHandsDate ? dayjs(inHandsDate, DATE_FORMATE) : null}
                format={DATE_FORMATE}
                className="w-100"
                onChange={onDateChange}
                disabledDate={disabledDate}
                data-test-selector="dateSelectDate"
              />
              <div className="error">{error && error?.ShipDateError}</div>
            </Col>
          </Row>
          <Space direction="vertical" size={0}>
            <div className="txt-bold text-color-gray mb-4">Shipping Options:</div>
            <Radio.Group
              onChange={(e: RadioChangeEvent) => {
                setShippingOption(e.target.value);
              }}
              value={shippingOption}
              data-test-selector="chkShippingOptions"
              disabled={isUserExists}
            >
              <Space direction="vertical" size={4}>
                <Radio value={translate("editOrder.shipCompleteLabel")} className="text-color-gray">
                  {translate("editOrder.shipCompleteLabel")}
                </Radio>
                <Radio value={translate("editOrder.shipPartialTitle")} className="text-color-gray">
                  {translate("editOrder.shipPartialTitle")}
                </Radio>
              </Space>
            </Radio.Group>
            <div className="error">{error && error?.ShippingOptionsError}</div>
          </Space>
          <Space direction="vertical">
            <Text className="txt-bold text-color-gray">
              {translate("editOrder.shippingNotesTitle")}:
            </Text>
            <TextArea
              disabled={isUserExists}
              className="shipping-notes-block"
              value={shippingNotes}
              onChange={(e) => {
                if (e.target.value.length <= 500) {
                  setShippingNotes(e.target.value);
                }
              }}
              maxLength={500}
              placeholder={translate("editOrder.addShippingNotesMessage")}
              rows={2}
              data-test-selector="txtShippingNotes"
            />
          </Space>
        </Space>
      </Col>
      <AddAddressModal
        title={translate("editOrder.customerAddressTitle")}
        isAddressModalVisible={isAddressModalVisible}
        setIsAddressModalVisible={setIsAddressModalVisible}
        onAddressSave={onAddressSaveHandler}
        addressDetails={addressData}
        setAddressDetails={setAddressData}
        onModalCancelPress={onModalCancelPress}
      />
    </Row>
  );
};

export default Shipping;
