import React from "react";
import { Typography, Space, Button } from "antd";
const { Title, Text } = Typography;
import { TitleHeader } from "components/Common/TitleHeader/TitleHeader";
import { useNavigate } from "react-router-dom";
import { ROUTES_PATH } from "routes/Routes.Constant";
import { IOrderSummaryEditProductProp } from "interfaces/ClientInterface/IProducts";
import { translate } from "i18n";

const EditProductHeader = ({
  orderSummary,
  onUpdateOrderProduct,
}: IOrderSummaryEditProductProp) => {
  const navigate = useNavigate();

  /**
   * This function is used to navigate to the edit order page.
   */
  const backToEditOrder = () => {
    navigate(`/${ROUTES_PATH.EDIT_ORDER}/${orderSummary?.OrderId}`);
  };

  return (
    <TitleHeader
      isBack={true}
      backClickHandler={backToEditOrder}
      title={
        <Space direction="horizontal" size={0}>
          <Space size={15}>
            <Title level={4} className="m-0">
              <strong>{translate("editProduct.editProductTitle")}</strong>
            </Title>
            <Text className="m-0">|</Text>
            <Text className="m-0 headerText">
              <strong>{translate("editProduct.orderLabel")}:</strong> {orderSummary?.ClassNumber}
            </Text>
            <Text className="m-0 headerText">
              <strong>{translate("editProduct.accountsLabel")}:</strong> {orderSummary?.AccountName}
            </Text>
            <Text className="m-0 headerText">
              <strong>{translate("editProduct.usersLabel")}:</strong> {orderSummary?.FullName}
            </Text>
          </Space>
        </Space>
      }
      lhsColSize={18}
      rhsColSize={6}
      rhsContent={
        <Space>
          <Button
            data-test-selector={"btnProductSave"}
            type="primary"
            className="save-btn"
            onClick={() => onUpdateOrderProduct(false)}
          >
            {translate("editProduct.saveBtn")}
          </Button>
          <Button
            data-test-selector={"btnProductSaveClose"}
            type="primary"
            className="save-close-btn"
            onClick={() => onUpdateOrderProduct(true)}
          >
            {translate("editProduct.saveAndCloseBtn")}
          </Button>
          <Button
            data-test-selector={"btnBackToOrder"}
            onClick={backToEditOrder}
            className="back-to-order"
          >
            {translate("editProduct.backToOrderBtn")}
          </Button>
        </Space>
      }
    />
  );
};

export default EditProductHeader;
