import React from "react";
import { Input, Space, Table } from "antd";
import { columns } from "./ProductFlags.Constant";
import {
  IUnAssociatedProductFlag,
  IUnAssociatedProductFlagList,
} from "interfaces/ClientInterface/IProductFlag";
import { SearchOutlined } from "@ant-design/icons";
/**
 * @returns This is a React functional component named `ProductFlagsList` which is rendering table.
 * Table is used to show product flags data.
 */

export const ProductFlagsList: React.FC<IUnAssociatedProductFlagList> = ({
  unAssociatedProductFlags,
  selectedRowKeys,
  setSelectedRowKeys,
  setSearchInput,
  searchInput,
}: IUnAssociatedProductFlagList) => {
  /**
   * const rowSelection` is an object that defines the behavior of row
   * selection in the `Table` component.
   */
  const rowSelection = {
    selectedRowKeys,
    onChange: (selectedRowKeys: React.Key[]) => {
      setSelectedRowKeys(selectedRowKeys);
    },
  };


  const onRowClick = (record: IUnAssociatedProductFlag) => {
    // Check if the row is already selected, and toggle its selection status
    const selectedRowKeyIndex = selectedRowKeys.indexOf(record.CPOrderFlagId);
    let newSelectedRowKeys;
    if (selectedRowKeyIndex > -1) {
      newSelectedRowKeys = [...selectedRowKeys];
      newSelectedRowKeys.splice(selectedRowKeyIndex, 1);
    } else {
      newSelectedRowKeys = [...selectedRowKeys, record.CPOrderFlagId];
    }
    setSelectedRowKeys(newSelectedRowKeys);
  };

  const filterData = unAssociatedProductFlags?.filter((item: IUnAssociatedProductFlag) => {
    return item?.NameUnchecked?.toLowerCase()?.includes(searchInput.toLowerCase());
  });

  return (
    <Space direction="vertical" size={"middle"} className="w-100">
      <div className="input-search">
        <Input
          allowClear={true}
          placeholder="Search Flag"
          suffix={<SearchOutlined />}
          onChange={(e) => setSearchInput(e.target.value)}
          value={searchInput}
        />
      </div>
      <Table
        dataSource={
          (searchInput && searchInput.trim() ? filterData : unAssociatedProductFlags) || []
        }
        columns={columns}
        className="order-flags w-100"
        rowKey={(record) => record?.CPOrderFlagId}
        pagination={false}
        data-test-selector="tblAddProductFlags"
        rowSelection={{
          type: "checkbox",
          ...rowSelection,
        }}
        onRow={(record) => ({
          onClick: () => onRowClick(record),
        })}
        style={{overflowY:"auto", maxHeight:"200px"}}
      />
    </Space>
  );
};
