/* eslint-disable max-lines */
/* eslint-disable max-len */
/* eslint-disable max-lines-per-function */
import React, { useContext, useState } from "react";
import { EyeInvisibleOutlined, EyeTwoTone } from "@ant-design/icons";
import { useAppDispatch } from "hooks/reduxHooks";
import { Button, Card, Col, Form, Input, Image, Row, Space, Checkbox } from "antd";
import { notificationController } from "components/Common/Notification/Notification";
import HeaderRibbon from "../Common/HeaderRibbon/HeaderRibbon";
import { Footer } from "../Common/Footer/Footer";
import { doLogin } from "store/slices/auth.slice";
import { ILogin } from "interfaces/ClientInterface/ILogin";
import { BAD_REQUEST, RefreshTokenSession } from "config/constant";
import { ROUTES_PATH } from "routes/Routes.Constant";
import { translate } from "i18n";
import { AbilityContext } from "ability/can";
import { getPermissionsData } from "api/services/permission.api";
import "./Login.scss";
import { ISecurityPermission } from "interfaces/ClientInterface/IAbility";
import { isObjectEmpty } from "utils";
import { getGeneralGlobalSetting } from "api/services/globalSetting.api";
import { PERMISSION_CODE, PERMISSION_SUBJECT } from "ability/utils";
import { getAPIToken } from "api/http.api";
import Cookies from "js-cookie";

export const Login: React.FC = () => {
  const ability = useContext(AbilityContext);
  const dispatch = useAppDispatch();
  const [isLoading, setLoading] = useState(false);

  const handleSubmit = (values: ILogin) => {
    setLoading(true);
    dispatch(doLogin(values))
      .unwrap()
      .then(async (res) => {
        const expirationInMinutes = RefreshTokenSession;
        const expirationTime = new Date(new Date().getTime() + expirationInMinutes * 60000);
        getAPIToken(res.User.User.Token);
        Cookies.set("DataT", res.User.User.Token, { expires: expirationTime });
        await getGeneralGlobalSetting();
        //fetching permissions and updating the ability state after successful login
        getPermissionsData(res?.User?.UserId, ability).then((res) => {
          setLoading(false);
          //check if the user has the login permissions
          const loginPermission = res?.RoleAndPermissionList?.find((item: ISecurityPermission) => {
            return (
              item?.Object == PERMISSION_SUBJECT.SECURITY &&
              item?.PermissionCode == PERMISSION_CODE.ACCESS_ORDER_MANAGEMENT
            );
          });
          if (!isObjectEmpty(loginPermission)) {
            //navigating to smart view dashboard
            window.location.href = `/${ROUTES_PATH.ORDERS}`;
          } else {
            notificationController.error({
              message: translate("login.invalidLoginPermission"),
              placement: "top",
            });
          }
        });
      })
      .catch((err) => {
        notificationController.error({
          message: err.code === BAD_REQUEST ? translate("login.invalidUserError") : err.message,
          placement: "top",
        });
        setLoading(false);
      });
  };

  return (
    <>
      <Space direction="vertical" size={98} className="d-flex login-container">
        <HeaderRibbon ribbonHeight={30} />
        <Row justify={"center"} align={"middle"} className="h-100">
          <Col span={8} md={{ span: 12 }} xl={{ span: 8 }} xs={{ span: 18 }} lg={{ span: 8 }}>
            <Card bordered={true}>
              <Space direction="vertical" size="middle" style={{ display: "flex" }}>
                <Row justify={"center"}>
                  <Col span={12}>
                    <Image className="login-card" src="/logo-massive.png" preview={false} />
                  </Col>
                </Row>
                <Row justify={"center"}>
                  <Col span={24}>
                    <Form
                      layout="vertical"
                      name="basic"
                      initialValues={{ remember: false }}
                      onFinish={handleSubmit}
                      autoComplete="off"
                      data-test-selector="frmLogin"
                      className="login-form-container"
                    >
                      <Space direction="vertical" size="small" style={{ display: "flex" }}>
                        <Form.Item
                          name="username"
                          label={translate("login.username")}
                          rules={[{ required: true, message: translate("login.userNameRequired") }]}
                        >
                          <Input
                            data-test-selector="txtLoginUsername"
                            placeholder={translate("login.username")}
                          />
                        </Form.Item>
                        <Form.Item
                          name="password"
                          label={translate("login.password")}
                          rules={[{ required: true, message: translate("login.passwordRequired") }]}
                        >
                          <Input.Password
                            iconRender={(visible) =>
                              visible ? <EyeTwoTone /> : <EyeInvisibleOutlined />
                            }
                            data-test-selector="pwdLoginPassword"
                            placeholder={translate("login.password")}
                          />
                        </Form.Item>

                        <Form.Item>
                          <Row>
                            <Col
                              span={12}
                              md={{ span: 12 }}
                              xl={{ span: 12 }}
                              xs={{ span: 24 }}
                              lg={{ span: 12 }}
                            >
                              <Button
                                type="primary"
                                htmlType="submit"
                                className="login-form-button"
                                loading={isLoading}
                                data-test-selector="btnLogin"
                              >
                                {translate("login.loginBtnText")}
                              </Button>
                            </Col>
                            <Col
                              span={12}
                              md={{ span: 12 }}
                              xl={{ span: 12 }}
                              xs={{ span: 24 }}
                              lg={{ span: 12 }}
                              style={{ textAlign: "right" }}
                            >
                              <a
                                className="login-form-forgot"
                                href="/forgot-password"
                                data-test-selector="linkLoginForgotPassword"
                              >
                                {translate("login.forgotPassword")}
                              </a>
                            </Col>
                          </Row>
                        </Form.Item>
                        <Form.Item name="remember" valuePropName="checked" noStyle>
                          <Checkbox data-test-selector="chkLoginRememberMe">
                            {translate("login.rememberMe")}
                          </Checkbox>
                        </Form.Item>
                      </Space>
                    </Form>
                  </Col>
                </Row>
              </Space>
            </Card>
          </Col>
        </Row>
      </Space>
      <Footer />
    </>
  );
};
