/* eslint-disable max-lines */
/* eslint-disable max-len */
/* eslint-disable max-lines-per-function */
import React, { useEffect, useState } from "react";
import { IInvoiceDocumentProps } from "interfaces/APIInterface/IInvoiceDocument";
import { convertDateTime } from "utils";
import { jsPDF } from "jspdf";
import "jspdf-autotable";

// Document Component
interface productProps {
  SKU: string;
  ProductName: string;
  ShortDescription : string;
  Quantity: number;
  Price: number;
}
const InvoiceDocument: React.FC<IInvoiceDocumentProps> = ({ data }: IInvoiceDocumentProps) => {
  const [datas, setDatas] = useState("");
  // const pdfMemo: string[] = useMemo(function name() {
  //   return [];
  // }, []);

  useEffect(() => {
    const headerData = [["SKU", "Item", "Description", "Qty", "Price", "Total"]];

    const bodyData: productProps[] = [];
    // const pdfMemo: string[] = [];
   
    const doc = new jsPDF();
    data.forEach((item, index) => {
      const orderDateString = `${convertDateTime(item?.OrderDate)}`;
      const orderDetails = item?.OrderDetail?.[0];
      const orderShipment = orderDetails?.OrderShipment?.[0] || "";
      const promotionList = item?.PromotionCodeList;
      const address = orderDetails?.Address;
      const products = orderDetails?.OrderProduct;
      const inHandsDate = `${convertDateTime(orderShipment?.ShipDate)}`;
      const billingDetails = address?.find((el) => {
        return el?.IsBilling;
      });
      const shippingDetails = address?.find((el) => {
        return el?.IsShipping;
      });
      // const fullName = `${item?.FirstName} ${item?.LastName}`;
      const shippingFullName = `${shippingDetails?.FirstName || ""} ${
        shippingDetails?.LastName || ""
      }`;
      const billingFullName = `${billingDetails?.FirstName || ""} ${
        billingDetails?.LastName || ""
      }`;
      const billingAddress = `${checkIfEmpty(billingDetails?.CityName)} ${checkIfEmpty(
        billingDetails?.StateName
      )} ${checkIfEmpty(billingDetails?.StateCode)} ${checkIfEmpty(
        billingDetails?.CountryName
      )} ${checkIfEmpty(billingDetails?.PostalCode)}`;
      const shippingAddress = `${checkIfEmpty(shippingDetails?.CityName)} ${checkIfEmpty(
        shippingDetails?.StateName
      )} ${checkIfEmpty(billingDetails?.StateCode)} ${checkIfEmpty(
        shippingDetails?.CountryName
      )} ${checkIfEmpty(shippingDetails?.PostalCode)}`;
      const shippingAddresses = `${shippingDetails?.CompanyName || ""} ${
        shippingDetails?.Address1 || ""
      } ${shippingDetails?.Address2 || ""}`;
      const billingAddresses = `${billingDetails?.CompanyName || ""} ${
        billingDetails?.Address1 || ""
      } ${billingDetails?.Address2 || ""}`;

      const getCouponCode = () => {
        const data =[];
        for (const promotionCodeList of promotionList) {
          data.push(promotionCodeList.PromotionCode);
        }
        return data;
      };

      const promotionCodeList = getCouponCode();
      const purchaseOrderNumber = item?.PurchaseOrderNumber != null? item.PurchaseOrderNumber : "" ;

      products.forEach((product) => {
        const productAttributes = product?.OrderProductAttributeValue[6];
        // eslint-disable-next-line
        // @ts-ignore
        let shortDescription = productAttributes && productAttributes.AttributeCode == "ShortDescription" ? productAttributes.AttributeValue : "" ;
        shortDescription = shortDescription.replace(/<.*?>/g, "");
        // eslint-disable-next-line
        // @ts-ignore
        bodyData.push([
          product.SKU,
          product.ProductName,
          shortDescription,
          product.Quantity,
          `$${product.Price}`,
          `$${(product?.Quantity * product?.Price).toFixed(2) || ""}`,
        ]);
      });

      doc.setFontSize(9);
      doc.text(new Date().toLocaleString(), 5, 4.1);
      doc.text("Commerce Portal | Znode®", 89, 4.1);
      doc.setDrawColor(169, 169, 169);
      doc
        .rect(5, 5, doc.internal.pageSize.width - 10, doc.internal.pageSize.height - 10, "S")
        .setFont("undefined", "bold");
      doc.setFontSize(14);
      doc.text("Maxwell's Hardware Order Receipt", 10, 12.5).setFontSize(11.5);
      doc.line(5, 16, doc.internal.pageSize.width - 5, 16);
      doc.text("Order Information", 10, 33.5).setFontSize(10);
      doc.text("Order Number:", 10, 40);
      doc.text("Order Date:", 10, 45);
      doc.text("Promotion Code:", 10, 50);
      doc.text("Payment Method:", 10, 55);
      doc.text(item?.PurchaseOrderNumber != null? "Purchase Order Number:" : "" , 10, 60);
      // doc.text("Job/Project Name:", 10, 60);
      doc.setFont("undefined", "normal");
      doc.text(item?.ClassNumber, 50, 40);
      doc.text(orderDateString, 50, 45);
      doc.text(`${promotionCodeList || ""}`, 50, 50);
      doc.text(item?.PurchaseOrderNumber != null? "Purchase Order" : "", 50, 55);
      doc.text(`${purchaseOrderNumber || ""}`, 50, 60).setFontSize(11.5);
      doc.setFont("undefined", "bold");
      doc.text("Customer Service", 110, 33.5).setFontSize(10);
      doc.text("Email:", 110, 40);
      doc.text("Phone No:", 110, 45);
      doc.setFont("undefined", "normal");
      doc.text(`${item?.CustomerServiceEmail || ""}`, 130, 40);
      doc.text(`${item?.CustomerServicePhoneNumber || ""}`, 130, 45);
      doc.setDrawColor(228, 228, 228);
      doc.line(10, 70, doc.internal.pageSize.width - 10, 70).setFontSize(11.5);
      doc.setFont("undefined", "bold");
      doc.text("Billing Address", 10, 80);
      doc.text("Shipping Address", 110, 80).setFontSize(10);
      doc.setFont("undefined", "normal");
      doc.text(billingFullName, 10, 90);
      doc.text(billingAddresses, 10, 95);
      doc.text(billingAddress, 10, 100);
      doc.text(`Phone Number: ${billingDetails?.PhoneNumber || ""}`, 10, 105);
      doc.text(shippingFullName, 110, 90);
      doc.text(shippingAddresses, 110, 95);
      doc.text(shippingAddress, 110, 100);
      doc.text(`Phone Number : ${shippingDetails?.PhoneNumber || ""}`, 110, 105);
      doc.text(`Email : ${item?.EmailAddress}`, 110, 110);
      doc.line(110, 120, doc.internal.pageSize.width - 10, 120).setFontSize(10.5);
      doc.setFont("undefined", "bold");
      doc.text("In Hands Date:", 110, 130);
      doc.text("Shipping Constraints:", 110, 135).setFontSize(10);
      doc.setFont("undefined", "normal");
      doc.text(inHandsDate, 150, 130);
      doc.text(orderShipment?.ShippingConstraintCode || "", 150, 135);
      doc.setFontSize(9);

      const styles = {
        theme: "grid",
        headStyles: {
          fillColor: "white",
          textColor: "black",
          fontStyle: "bold",
          lineColor: 10,
          lineWidth: 0.1,
        },
        bodyStyles: { fillColor: "white", lineColor: 10, lineWidth: 0.1, textColor: "black" },
      };
      const columnStyles = {
        0: { cellWidth: 24, fontSize: 9 },
        1: { cellWidth: 55, fontSize: 9 },
        2: { cellWidth: 55, fontSize: 9 },
        3: { cellWidth: 12, fontSize: 9 },
        4: { cellWidth: 18, fontSize: 9 },
        5: { halign: "right", cellWidth: 18, fontSize: 9 },
      };

      doc.setDrawColor(0, 0, 0);
      // eslint-disable-next-line
      // @ts-ignore
      doc.autoTable({
        head: headerData,
        body: bodyData,
        headStyles: styles.headStyles,
        bodyStyles: styles.bodyStyles,
        theme: styles.theme,
        startY: 150,
        columnStyles,
        tableLineWidth: 0.05,
        tableLineColor: [0, 0, 0],
        // eslint-disable-next-line
        // @ts-ignore
        didParseCell: (hookData) => {
          if (hookData.section === "head") {
            if (hookData.column.dataKey === 5) {
              hookData.cell.styles.halign = "right";
            }
          }
        },
      });

      //eslint-disable-next-line
      //@ts-ignore
      const heightOfTable1 = doc.lastAutoTable.finalY;

      const widthOfTable1 =
        //eslint-disable-next-line
        //@ts-ignore
        doc.lastAutoTable.columns[0].width +
        //eslint-disable-next-line
        //@ts-ignore
        doc.lastAutoTable.columns[1].width +
        //eslint-disable-next-line
        //@ts-ignore
        doc.lastAutoTable.columns[2].width +
        //eslint-disable-next-line
        //@ts-ignore
        doc.lastAutoTable.columns[3].width +
        //eslint-disable-next-line
        //@ts-ignore
        doc.lastAutoTable.columns[4].width +
        //eslint-disable-next-line
        //@ts-ignore
        doc.lastAutoTable.columns[5].width;

      const paddingLeftRect =
        //eslint-disable-next-line
        //@ts-ignore
        doc.lastAutoTable.columns[0].width + doc.lastAutoTable.columns[1].width;

      doc.setFont("undefined", "bold");
      doc.setFontSize(9);
      doc.text("Sub Total", paddingLeftRect + 19, heightOfTable1 + 5);

      doc.text(
        `Shipping ${addBrackets(orderShipment?.ShippingName) || ""}`,
        paddingLeftRect + 19,
        heightOfTable1 + 10
      );

      doc.text("Tax", paddingLeftRect + 19, heightOfTable1 + 15);

      {
        item?.HandlingFee > 0 &&
          doc.text("HandlingCharges", paddingLeftRect + 19, heightOfTable1 + 20);
      }

      {
        item?.Discount != 0 &&
          doc.text(
            "Discount (On Subtotal)",
            paddingLeftRect + 19,
            item?.HandlingFee > 0 ? heightOfTable1 + 25 : heightOfTable1 + 20
          );
      }
      {
        item?.CSRDiscountAmount > 0 &&
          doc.text(
            "CSR Discount",
            paddingLeftRect + 19,
            item?.HandlingFee > 0 && item?.Discount != 0
              ? heightOfTable1 + 30
              : item?.HandlingFee > 0 || item?.Discount != 0
              ? heightOfTable1 + 25
              : heightOfTable1 + 20
          );
      }
      {
        item?.VoucherAmount > 0 &&
          doc.text(
            "Voucher Amount",
            paddingLeftRect + 19,
            item?.HandlingFee > 0 && item?.Discount != 0 && item?.CSRDiscountAmount > 0
              ? heightOfTable1 + 35
              : item?.HandlingFee > 0 && item?.Discount != 0
              ? heightOfTable1 + 30
              : item?.Discount != 0 && item?.CSRDiscountAmount > 0
              ? heightOfTable1 + 30
              : item?.HandlingFee > 0 && item?.CSRDiscountAmount > 0
              ? heightOfTable1 + 30
              : item?.HandlingFee > 0 && item?.Discount == 0 && item?.CSRDiscountAmount == 0
              ? heightOfTable1 + 25
              : item?.HandlingFee == 0 && item?.Discount != 0 && item?.CSRDiscountAmount == 0
              ? heightOfTable1 + 25
              : item?.HandlingFee == 0 && item?.Discount == 0 && item?.CSRDiscountAmount > 0
              ? heightOfTable1 + 25
              : heightOfTable1 + 20
          );
      }
      doc.setFont("undefined", "normal");
      doc.text(`$${item?.SubTotal || "0"}`, 194, heightOfTable1 + 5, { align: "right" });
      doc.text(`+ $${item?.ShippingCost || "0"}`, 194, heightOfTable1 + 10, { align: "right" });
      doc.text(`+ $${item?.TaxCost || "0"}`, 194, heightOfTable1 + 15, { align: "right" });
      {
        item?.HandlingFee > 0 &&
          doc.text(`+ $${item?.HandlingFee || ""}`, 194, heightOfTable1 + 20, { align: "right" });
      }
      {
        item?.Discount != 0 &&
          doc.text(
            `- $${item?.Discount || ""}`,
            194,
            item?.HandlingFee > 0 ? heightOfTable1 + 25 : heightOfTable1 + 20,
            { align: "right" }
          );
      }
      {
        item?.CSRDiscountAmount > 0 &&
          doc.text(
            `- $${item?.CSRDiscountAmount || ""}`,
            194,
            item?.HandlingFee > 0 && item?.Discount != 0
              ? heightOfTable1 + 30
              : item?.HandlingFee > 0 || item?.Discount != 0
              ? heightOfTable1 + 25
              : heightOfTable1 + 20,
            {
              align: "right",
            }
          );
      }
      {
        item?.VoucherAmount > 0 &&
          doc.text(
            `- $${item?.VoucherAmount || ""}`,
            194,
            item?.HandlingFee > 0 && item?.Discount != 0 && item?.CSRDiscountAmount > 0
              ? heightOfTable1 + 35
              : item?.HandlingFee > 0 && item?.Discount != 0
              ? heightOfTable1 + 30
              : item?.Discount != 0 && item?.CSRDiscountAmount > 0
              ? heightOfTable1 + 30
              : item?.HandlingFee > 0 && item?.CSRDiscountAmount > 0
              ? heightOfTable1 + 30
              : item?.HandlingFee > 0 && item?.Discount == 0 && item?.CSRDiscountAmount == 0
              ? heightOfTable1 + 25
              : item?.HandlingFee == 0 && item?.Discount != 0 && item?.CSRDiscountAmount == 0
              ? heightOfTable1 + 25
              : item?.HandlingFee == 0 && item?.Discount == 0 && item?.CSRDiscountAmount > 0
              ? heightOfTable1 + 25
              : heightOfTable1 + 20,
            {
              align: "right",
            }
          );
      }
      const statusArr = [];
      if (item?.HandlingFee > 0) {
        statusArr.push(true);
      }
      if (item?.Discount != 0) {
        statusArr.push(true);
      }
      if (item?.CSRDiscountAmount > 0) {
        statusArr.push(true);
      }
      if (item?.VoucherAmount > 0) {
        statusArr.push(true);
      }

      const statusArrLen = statusArr.length;
      doc.setDrawColor(0, 0, 0);
      doc
        .line(
          paddingLeftRect + 14,
          statusArrLen === 4
            ? heightOfTable1 + 55
            : statusArrLen === 3
            ? heightOfTable1 + 45
            : statusArrLen === 2
            ? heightOfTable1 + 35
            : statusArrLen === 1
            ? heightOfTable1 + 25
            : heightOfTable1 + 20,
          doc.internal.pageSize.width - 14,
          statusArrLen === 4
            ? heightOfTable1 + 55
            : statusArrLen === 3
            ? heightOfTable1 + 45
            : statusArrLen === 2
            ? heightOfTable1 + 35
            : statusArrLen === 1
            ? heightOfTable1 + 25
            : heightOfTable1 + 20
        )
        .setFontSize(11)
        .setFont("undefined", "bold");

      doc.text(
        "Total",
        paddingLeftRect + 19,
        statusArrLen === 4
          ? heightOfTable1 + 60
          : statusArrLen === 3
          ? heightOfTable1 + 50
          : statusArrLen === 2
          ? heightOfTable1 + 40
          : statusArrLen === 1
          ? heightOfTable1 + 30
          : heightOfTable1 + 25
      );
      doc.text(
        `$${item?.Total || ""}`,
        194,
        statusArrLen === 4
          ? heightOfTable1 + 60
          : statusArrLen === 3
          ? heightOfTable1 + 50
          : statusArrLen === 2
          ? heightOfTable1 + 40
          : statusArrLen === 1
          ? heightOfTable1 + 30
          : heightOfTable1 + 25,
        { align: "right" }
      );

      doc.rect(
        paddingLeftRect + 14,
        heightOfTable1,
        widthOfTable1 - paddingLeftRect,
        statusArrLen === 4
          ? doc.internal.pageSize.height - 250 + 15
          : statusArrLen === 3
          ? doc.internal.pageSize.height - 250 + 5
          : statusArrLen === 2
          ? doc.internal.pageSize.height - 250 - 5
          : statusArrLen === 1
          ? doc.internal.pageSize.height - 250 - 15
          : doc.internal.pageSize.height - 250 - 20,
        "S"
      );

      const addPageNumber = (pageNum: number, totalPages: number) => {
        doc.setFont("undefined", "normal");
        doc.setFontSize(9);
        doc.text(
          `${pageNum} / ${totalPages}`,
          doc.internal.pageSize.width - 15,
          doc.internal.pageSize.height - 6
        );
      };
      //eslint-disable-next-line
      //@ts-ignore
      addPageNumber(doc.internal.getNumberOfPages(), data.length);
      if (index !== data.length - 1) {
        doc.addPage();
      }
    });
    setDatas(doc.output("datauristring"));
  }, [data]);

  // //To check if the data is not null and to append the commas only if data is not null.
  const checkIfEmpty = (text: string | undefined) => {
    return text ? text + "," : "";
  };

  // //To check if data is not null and append brackets if the data is not null.
  const addBrackets = (text: string | undefined) => {
    return text ? `(${text})` : "";
  };

  return (
    <iframe
      src={datas}
      title="PDF Preview"
      width="100%"
      style={{ zIndex: "99999" }}
      height="400px"
    />
  );
};

export default InvoiceDocument;
