/* eslint-disable max-len */
/* eslint-disable max-lines */
import React, { Dispatch, SetStateAction } from "react";
import { Space, Tooltip } from "antd";
import { EditOutlined, EyeOutlined, CopyOutlined, UsergroupAddOutlined } from "@ant-design/icons";
import { collapseItem, IDuplicateOrder } from "interfaces/ClientInterface/IOrderList";
import { themeSetting } from "config/defaultSettings";
import { IColumnProps } from "interfaces/ClientInterface/IEditOrder";
import QuickView from "components/Common/QuickViewOrder/QuickViewOrder";
import { IAssignModal, IQuickViewOpen } from "interfaces/ClientInterface/IQuickViewOrder";
import {
  IOrderDetails,
  IOrderDetailsForQuickView,
  IProductDetails,
} from "interfaces/APIInterface/IQuickViewOrder";
import { Link } from "react-router-dom";
import { ROUTES_PATH } from "routes/Routes.Constant";
import { IUsersListItem } from "interfaces/APIInterface/IAssignTo";
import { translate } from "i18n";
import { DOLLAR } from "config/constant";
import { PureAbility } from "@casl/ability";
import { convertDateTime } from "utils";
import { IData } from "interfaces/ClientInterface/IList";
import { AssignToUserModal } from "./AssignToUserModal";
import { adjustColor } from "components/Common/Status/Status.Constant";
import StatusTag from "components/Common/Status/StatusTag";
import { getGlobalSetting } from "api/services/localStorage.service";
import { PERMISSION_CODE, PERMISSION_SUBJECT } from "ability/utils";

const globalSettings = getGlobalSetting() ? JSON.parse(getGlobalSetting() || "") : {};
const priceRoundOff = globalSettings?.PriceRoundOff;
const defaultAmount = `${DOLLAR}` + 0?.toFixed(priceRoundOff);

export const initialColumns = () => {
  return [
    {
      title: "Order Number",
      dataIndex: "ClassNumber",
      key: "ClassNumber",
      sorter: (a: { ClassNumber: string }, b: { ClassNumber: string }) => {
        const orderCode = a?.ClassNumber || "";
        const orderName = b?.ClassNumber || "";
        return orderCode.localeCompare(orderName);
      },
      hidden: false,
      render: (ClassNumber: string, record: IData) => (
        <Link
          to={`/${ROUTES_PATH.EDIT_ORDER}/${record?.OrderId}`}
          target="_self"
          className="link-inherit"
        >
          {ClassNumber}
        </Link>
      ),
    },
    {
      title: "Account",
      dataIndex: "AccountName",
      key: "AccountName",
      sorter: (a: { AccountName: string }, b: { AccountName: string }) => {
        const accountCode = a?.AccountName || "";
        const accountName = b?.AccountName || "";
        return accountCode.localeCompare(accountName);
      },
      hidden: false,
    },
    {
      title: "Customer",
      dataIndex: "UserFullName",
      key: "UserFullName",
      sorter: (a: { UserFullName: string }, b: { UserFullName: string }) => {
        const customerCode = a?.UserFullName || "";
        const customerName = b?.UserFullName || "";
        return customerCode.localeCompare(customerName);
      },
      hidden: false,
    },
    {
      title: "Status",
      dataIndex: "OrderStateName",
      key: "OrderStateName",
      sorter: (a: { OrderStateName: string }, b: { OrderStateName: string }) => {
        const statusCode = a?.OrderStateName || "";
        const statusName = b?.OrderStateName || "";
        return statusCode.localeCompare(statusName);
      },
      hidden: false,
      render: (status: string, record: IData) => {
        // eslint-disable-next-line no-console
        const bgColor = record?.CPBackColor || "#318311";
        const color = record?.CPTextColor || "#B7EB8F";
        const darkerBorder = adjustColor(bgColor, -50);
        const style = {
          backgroundColor: bgColor,
          border: `1px solid ${darkerBorder}`,
          color: color,
        };
        return <StatusTag text={status} tagStyle={style} dataTestSelector="tagOrderStatus" />;
      },
    },
    {
      title: "Created",
      dataIndex: "CreatedDate",
      key: "CreatedDate",
      sorter: (a: { CreatedDate: string }, b: { CreatedDate: string }) => {
        const createdCode = a?.CreatedDate || "";
        const createdName = b?.CreatedDate || "";
        return createdCode.localeCompare(createdName);
      },
      hidden: false,

      render: (createdDate: string) => <span>{convertDateTime(createdDate)}</span>,
    },
    {
      title: "Age",
      dataIndex: "Age",
      key: "Age",
      sorter: (a: { Age: string }, b: { Age: string }) => {
        const ageCode = a?.Age || "";
        const ageName = b?.Age || "";
        return ageCode.localeCompare(ageName);
      },
      hidden: false,
    },
    {
      title: "Last Updated",
      dataIndex: "ModifiedDate",
      key: "ModifiedDate",
      sorter: (a: { ModifiedDate: string }, b: { ModifiedDate: string }) => {
        const lastCode = a?.ModifiedDate || "";
        const lastName = b?.ModifiedDate || "";
        return lastCode.localeCompare(lastName);
      },
      hidden: false,
      render: (ModifiedDate: string) => <span>{convertDateTime(ModifiedDate)}</span>,
    },
    {
      title: "Total",
      dataIndex: "OrderTotal",
      key: "OrderTotal",
      sorter: (a: { OrderTotal: string }, b: { OrderTotal: string }) => {
        const totalCode = a?.OrderTotal || "";
        const totalName = b?.OrderTotal || "";
        return totalCode.localeCompare(totalName);
      },
      hidden: false,
      render: (OrderTotal: string) => (
        <span>
          {OrderTotal != null && OrderTotal !== undefined
            ? DOLLAR + parseFloat(OrderTotal)?.toFixed(priceRoundOff)
            : defaultAmount}
        </span>
      ),
    },
    {
      title: "Owner",
      dataIndex: "AssignToFullName",
      key: "AssignToFullName",
      sorter: (a: { AssignToFullName: string }, b: { AssignToFullName: string }) => {
        const ownerCode = a?.AssignToFullName || "";
        const ownerName = b?.AssignToFullName || "";
        return ownerCode.localeCompare(ownerName);
      },
      hidden: false,
    },
  ];
};
export const initialFilterColumnList = () => {
  return [
    {
      title: "Order Number",
      dataIndex: "ClassNumber",
      key: "Order Number",
      sorter: true,
      hidden: false,
    },
    {
      title: "Account",
      dataIndex: "AccountId",
      key: "Account",
      sorter: true,
      hidden: false,
    },
    {
      title: "Customer",
      dataIndex: "UserName",
      key: "Customer",
      sorter: true,
      hidden: false,
    },
    {
      title: "Status",
      dataIndex: "OrderStateName",
      key: "Status",
      sorter: true,
      hidden: false,
    },
    {
      title: "Owner",
      dataIndex: "AssignToFullName",
      key: "Owner",
      sorter: true,
      hidden: false,
    },
    {
      title: "Total",
      dataIndex: "OrderTotal",
      key: "Total",
      sorter: true,
      hidden: false,
    },
  ];
};

export const filterColumns = (fetchedColumns: IColumnProps[]) => {
  const columns = initialColumns();
  const columnsData = columns?.filter((item) => {
    return fetchedColumns?.findIndex((ele) => {
      return item?.dataIndex == ele?.dataIndex;
    }) !== -1
      ? true
      : false;
  });
  return columnsData;
};

export const columns = (
  // eslint-disable-next-line no-unused-vars
  onEditItemPress: (data: string) => void,
  quickViewProps: {
    quickViewOpen: IQuickViewOpen;
    setQuickViewOpen: Dispatch<SetStateAction<IQuickViewOpen>>;
    quickViewData: IOrderDetails;
    // eslint-disable-next-line no-unused-vars
    onQuickView: (id: string) => void;
    quickViewLoading: boolean;
  },
  setIsDuplicateOrder: Dispatch<SetStateAction<IDuplicateOrder>>,
  activeAccordionKey: string | string[],
  assignToProps: {
    assignToModalOpen: IAssignModal;
    setAssignToModalOpen: Dispatch<SetStateAction<IAssignModal>>;
    refetchList: () => void;
    myTeam: IUsersListItem[];
    selectedRowKeys?: React.Key[];
    setSelectedRowKeys: Dispatch<SetStateAction<React.Key[]>>;
    // eslint-disable-next-line no-unused-vars
    onAssignClick: (id: string, orderStateId: number) => void;
  },
  ability: PureAbility<[string, string]>
) => {
  const { quickViewOpen, setQuickViewOpen, quickViewData, onQuickView, quickViewLoading } =
    quickViewProps;
  const canCreateOrder = ability.can(PERMISSION_CODE.CREATE_ORDERS, PERMISSION_SUBJECT.ORDERS);

  const {
    assignToModalOpen,
    setAssignToModalOpen,
    refetchList,
    myTeam,
    selectedRowKeys,
    setSelectedRowKeys,
    onAssignClick,
  } = assignToProps;
  return [
    {
      key: "action",
      title: "Actions",
      dataIndex: "Actions",
      sorter: false,
      hidden: false,
      render: (text: string, record: IData) => {
        return (
          <>
            <Space size="middle">
              <Tooltip title="Edit">
                <EditOutlined
                  style={{ color: themeSetting.token.colorIcon }}
                  onClick={() => onEditItemPress(record?.OrderId)}
                />
              </Tooltip>
              <QuickView
                data={quickViewData}
                open={quickViewOpen?.visible && record?.OrderId == quickViewOpen?.id}
                setOpen={(newOpen: boolean) => {
                  setQuickViewOpen({
                    id: record?.OrderId,
                    visible: newOpen,
                  });
                }}
                loading={quickViewLoading}
                key={`quickView${record?.OrderId}`}
              >
                <div
                  className={
                    quickViewOpen?.visible && record?.OrderId == quickViewOpen?.id
                      ? "eye-icon-style eye-icon-active"
                      : "eye-icon-style eye-icon-inactive"
                  }
                >
                  <Tooltip title="Quick View">
                    <EyeOutlined
                      onClick={() => {
                        onQuickView(record?.OrderId);
                      }}
                    />
                  </Tooltip>
                </div>
              </QuickView>
              {canCreateOrder && (
                <Tooltip title="Duplicate">
                  <CopyOutlined
                    onClick={() => {
                      setIsDuplicateOrder({
                        orderId: record?.OrderId,
                        visible: true,
                      });
                    }}
                    style={{ color: themeSetting.token.colorIcon }}
                  />
                </Tooltip>
              )}
              <>
                <AssignToUserModal
                  calledFromTools={false}
                  open={assignToModalOpen?.visible && record?.OrderId == assignToModalOpen?.id}
                  orderId={record?.OrderId}
                  setOpen={(newOpen: boolean) => {
                    setAssignToModalOpen({
                      id: record.OrderId,
                      visible: newOpen,
                      IsDelegatedToMe: assignToModalOpen?.IsDelegatedToMe,
                    });
                  }}
                  refetchList={refetchList}
                  myTeam={myTeam}
                  selectedRowKeys={selectedRowKeys}
                  setSelectedRowKeys={setSelectedRowKeys}
                  key={`assignedTo${record?.OrderId}`}
                  IsDelegateToMe={assignToModalOpen?.IsDelegatedToMe}
                >
                  <div
                    className={
                      assignToModalOpen?.visible && record?.OrderId == assignToModalOpen?.id
                        ? "eye-icon-style eye-icon-active"
                        : "eye-icon-style eye-icon-inactive"
                    }
                  >
                    <UsergroupAddOutlined
                      onClick={() => {
                        onAssignClick(record?.OrderId, record?.OmsOrderStateId);
                      }}
                    />
                  </div>
                </AssignToUserModal>
              </>
            </Space>
          </>
        );
      },
    },
  ];
};

export const subFilterMenu = [
  {
    label: "Contains",
    value: "contains",
  },
  {
    label: "Is",
    value: "is",
  },
  {
    label: "Begins With",
    value: "beginsWith",
  },
  {
    label: "Ends With",
    value: "endsWith",
  },
];

export const subFilterMenuForTotal = [
  {
    label: "Equals",
    value: "equals",
  },
  {
    label: "Greater Than",
    value: "greaterThan",
  },
  {
    label: "Greater or Equal",
    value: "greaterOrEqual",
  },
  {
    label: "Less Than",
    value: "lessThan",
  },
  {
    label: "Less or Equal",
    value: "lessOrEqual",
  },
];

export const getSmartViewOrderList = (ability: PureAbility<[string, string]>) => {
  let manageOrderListData: collapseItem[] = [
    {
      key: "MyOrder_IN PROGRESS",
      title: translate("manageOrder.tabMyOrderInProgress"),
      classSelector: "my-order-inprogress",
      content: "",
    },
    {
      key: "DelegatedToMe_IN PROGRESS",
      title: translate("manageOrder.tabDelegatesInProgress"),
      classSelector: "delegate-inprogress",
      content: "",
    },
    {
      key: "MyTeam_Unassigned",
      title: translate("manageOrder.tabMyTeamOrderUnassigned"),
      classSelector: "my-team-order-unassigned",
      content: "",
    },
    {
      key: "MyTeam_IN PROGRESS",
      title: translate("manageOrder.tabMyTeamOrdersInProgress"),
      classSelector: "my-team-order-inprogress",
      content: "",
    },
    {
      key: "Following_IN PROGRESS",
      title: translate("manageOrder.tabFollowingInProgress"),
      classSelector: "following-inprogress",
      content: "",
    },
    {
      key: "MyOrder_SHIPPED",
      title: translate("manageOrder.tabMyOrdersInFulfillment"),
      classSelector: "my-order-infulfillment",
      content: "",
    },
    {
      key: "MyTeam_SHIPPED",
      title: translate("manageOrder.tabMyTeamOrdersInFulfillment"),
      classSelector: "my-team-order-infulfillment",
      content: "",
    },
    {
      key: "Following_SHIPPED",
      title: translate("manageOrder.tabFollowingInFulfillment"),
      classSelector: "following-infulfillment",
      content: "",
    },
    {
      key: "MyOrder_RecentFulfillment",
      title: translate("manageOrder.tabMyOrdersRecentFulfill"),
      classSelector: "my-order-recently-fulfilled",
      content: "",
    },
    {
      key: "Following_RecentFulfillment",
      title: translate("manageOrder.tabFollowingRecentFulfilled"),
      classSelector: "following-recently-fulfilled",
      content: "",
    },
  ];

  const canSeeAllOrders = ability.can(PERMISSION_CODE.SELL_ALL_ORDERS, PERMISSION_SUBJECT.ORDERS);
  const canSeeMyUserGroupsOrders = ability.can(
    PERMISSION_CODE.SEE_MY_USER_GROUPS_ORDERS,
    PERMISSION_SUBJECT.ORDERS
  );

  /**
   * My Team Order's tab will be shown
   * - if the user has SeeAllOrders Permission
   * Else - if the user don't have SeeAllOrders permission then it will check the following permission
   * SeeMyUserGroupsOrders
   */
  if (!(canSeeAllOrders || (!canSeeAllOrders && canSeeMyUserGroupsOrders))) {
    manageOrderListData = manageOrderListData.filter((item) => {
      if (
        item?.title == translate("manageOrder.tabMyTeamOrdersInProgress") ||
        item?.title == translate("manageOrder.tabMyTeamOrdersInFulfillment")
      ) {
        return false;
      }
      return true;
    });
  }

  /**
   * My Team Unassigned order tab will be shown
   * - if the user has SeeAllOrders Permission
   * Else - if the user don't have SeeAllOrders permission then it will check the following permission
   * SeeAllUnassignedOrders or
   * SeeNextUnassignedOrder or
   * SeeMyUserGroupsOrders
   */
  const canSeeAllUnassignedOrders = ability.can(
    PERMISSION_CODE.SEE_ALL_UNASSIGNED_ORDERS,
    PERMISSION_SUBJECT.ORDERS
  );
  const canSeeNextUnassignedOrder = ability.can(
    PERMISSION_CODE.SEE_NEXT_UNASSIGNED_ORDERS,
    PERMISSION_SUBJECT.ORDERS
  );
  if (
    !(
      canSeeAllOrders ||
      (!canSeeAllOrders && canSeeAllUnassignedOrders) ||
      (!canSeeAllOrders && canSeeMyUserGroupsOrders) ||
      (!canSeeAllOrders && canSeeNextUnassignedOrder)
    )
  ) {
    manageOrderListData = manageOrderListData.filter((item) => {
      return item?.title == translate("manageOrder.tabMyTeamOrderUnassigned") ? false : true;
    });
  }

  return manageOrderListData;
};

export const getQuickViewData = (data: IOrderDetailsForQuickView) => {
  const orderDetails = JSON.parse(data?.OrderDetail)[0];
  const address = orderDetails.Address;
  const shippingAddress = address?.find((el: { IsShipping: boolean }) => {
    return el?.IsShipping;
  });
  const shippingName = orderDetails?.OrderShipment?.[0]?.ShippingName;
  const products = orderDetails?.OrderProduct;
  const shippingTo =
    shippingAddress?.CityName && shippingAddress?.StateName
      ? `${shippingAddress?.CityName || ""}, ${shippingAddress?.StateName || ""}`
      : "N/A";
  const result = {
    OrderNumber: data?.ClassNumber,
    OrderTotal: data?.OrderTotal
      ? DOLLAR + parseFloat(data?.OrderTotal || "0.00").toFixed(priceRoundOff)
      : "N/A",
    OrderStateName: data?.OrderStateName,
    CustomerName: data?.FullName,
    OrderDate: data?.OrderDate ? `${convertDateTime(data?.OrderDate)}` : "N/A",
    Owner: data?.AssignToFullName,
    CompanyName: data?.AccountName
      ? data?.AccountName
      : shippingAddress?.CompanyName
      ? shippingAddress?.CompanyName
      : "N/A",
    OrderTypeName: data?.OrderTypeName,
    LastUpdated: data?.ModifiedDate ? `${convertDateTime(data?.ModifiedDate)}` : "N/A",
    ShippingTo: shippingTo,
    ShippingMethod: shippingName ? shippingName : "N/A",
    FulfilledDate: data?.FinalizedDate ? `${convertDateTime(data?.FinalizedDate)}` : "N/A",
    ProductsList:
      products &&
      products?.map((product: IProductDetails) => {
        return {
          SKU: product?.SKU,
          ProductName: product?.ProductName,
          Quantity: product?.Quantity,
          Price:
            DOLLAR +
            parseFloat(product?.Price !== undefined ? product.Price || "0.00" : "0.00").toFixed(
              priceRoundOff
            ),
          Total:
            DOLLAR +
            (
              Number(product?.Quantity || 0) *
              Number(product?.Price !== undefined ? product?.Price || 0.0 : 0.0)
            ).toFixed(priceRoundOff),
          totalProductsCount: products?.length,
          totalProductPrice: products?.reduce(
            (total: number, product: IProductDetails) =>
              total + Number(product?.Quantity || 0) * Number(product?.Price || 0.0),
            0
          ),
          totalProductQuantity: products?.reduce(
            (total: number, product: IProductDetails) => total + Number(product?.Quantity),
            0
          ),
        };
      }),
  };
  return result;
};

export const checkAssignToMePermission = (ability: PureAbility<[string, string]>) => {
  const assignToMePermission = ability.can(PERMISSION_CODE.ASSIGN_TO_ME, PERMISSION_SUBJECT.ORDERS);
  const assignToAnyonePermission = ability.can(
    PERMISSION_CODE.ASSIGN_TO_ANYONE,
    PERMISSION_SUBJECT.ORDERS
  );
  const canBeAssignedToOrdersPermission = ability.can(
    PERMISSION_CODE.CAN_BE_ASSIGNED_TO_ORDERS,
    PERMISSION_SUBJECT.ORDERS
  );
  if (assignToAnyonePermission) {
    /**
     * if user has assign to anyone permission as well as the can be assign to orders,
     * then it should show the assign to my checkbox / return true
     */
    return assignToAnyonePermission && canBeAssignedToOrdersPermission;
  } else {
    /**
     * if user don't have assign to anyone permission then it check the child permission assign to me.
     * if user has assign to me permission as well as the can be assign to orders,
     * then it should show the assign to my checkbox / return true
     */
    return assignToMePermission && canBeAssignedToOrdersPermission;
  }
};

export const checkAssignToMyTeamPermission = (ability: PureAbility<[string, string]>) => {
  const assignToMyTeamPermission = ability.can(
    PERMISSION_CODE.ASSIGN_TO_MY_TEAM,
    PERMISSION_SUBJECT.ORDERS
  );
  const assignToAnyonePermission = ability.can(
    PERMISSION_CODE.ASSIGN_TO_ANYONE,
    PERMISSION_SUBJECT.ORDERS
  );
  if (assignToAnyonePermission) {
    return true;
  } else {
    return assignToMyTeamPermission;
  }
};
