/* eslint-disable max-len */
// eslint-disable-next-line max-len
/* eslint-disable max-lines-per-function */
import React, { useContext, useState } from "react";
import { Divider, Dropdown, Input, Modal, Popover, Typography } from "antd";
import { Space } from "antd";
import { CaretDownOutlined, SearchOutlined } from "@ant-design/icons";
import { IColumnProps } from "interfaces/ClientInterface/IEditOrder";
import { CheckBoxComponent } from "components/Common/Checkbox/Checkbox";
import { CheckboxChangeEvent } from "antd/es/checkbox";
import { IFilterItemProps, OrderActionFiltersProps } from "interfaces/ClientInterface/IOrderList";
import { Filters } from "./Filters";
import { translate } from "i18n";

import { MenuProps } from "rc-menu";
import { AssignToUserModal } from "./AssignToUserModal";
import { notificationController } from "components/Common/Notification/Notification";
import { AbilityContext } from "ability/can";
import { PureAbility } from "@casl/ability";
import {
  checkAssignToMePermission,
  checkAssignToMyTeamPermission,
  initialFilterColumnList,
} from "./Order.Constant";
import { Age, TABLECOLUMN } from "config/constant";
import { PERMISSION_CODE, PERMISSION_SUBJECT } from "ability/utils";
import { setLocalStorageDataForColumns } from "utils/localStorage";
const { Text } = Typography;
let disableColumns = false;
const OrderActionFilters = ({
  columnsList,
  setColumnsList,
  manageFilter,
  toolsClickHandler,
  assignToMyTeamModal,
  setAssignToMyTeamModal,
  refetchList,
  myTeam,
  selectedRowKeys,
  setSelectedRowKeys,
  filterValue,
  setFilterValue,
  setOrderListParams,
  appliedFilters,
  setAppliedFilters,
  setFilterColumnListData,
  filterColumnListData,
  isFilterClear,
  setIsFilterClear,
  clickedAppliedFilter,
  setClickedAppliedFilter,
}: OrderActionFiltersProps) => {
  const ability: PureAbility<[string, string]> = useContext(AbilityContext);
  const [openFilter, setOpenFilter] = useState(false);
  const [openColumnsPopup, setOpenColumnsPopup] = useState(false);
  const [modalStyle, setModalStyle] = useState({});
  const [searchInput, setSearchInput] = useState("");
  const canAssignToMyTeamPermission = checkAssignToMyTeamPermission(ability);
  const canAssignToMePermission = checkAssignToMePermission(ability);
  const unAssignPermission = ability.can(
    PERMISSION_CODE.UNASSIGN_ORDERS,
    PERMISSION_SUBJECT.ORDERS
  );

  const handleAssign = () => {
    if (selectedRowKeys?.length) {
      setTimeout(() => {
        setAssignToMyTeamModal(true);
      });
    } else {
      notificationController.error({
        message: translate("manageOrder.isRecordsSelectedCheckMsg"),
      });
    }
  };

  const items: MenuProps["items"] = [
    {
      label: (
        <div onClick={() => toolsClickHandler("Assign_to_Me")}>
          {translate("manageOrder.orderToolAssignToMe")}
        </div>
      ),
      key: 1,
      className: !canAssignToMePermission ? "display-none" : "",
    },
    {
      label: (
        <Space>
          <div onClick={handleAssign}>{translate("manageOrder.orderToolAssignTo")}</div>
          <AssignToUserModal
            calledFromTools={true}
            open={assignToMyTeamModal}
            setOpen={(newOpen: boolean) => {
              setAssignToMyTeamModal(newOpen);
            }}
            refetchList={refetchList}
            myTeam={myTeam}
            selectedRowKeys={selectedRowKeys}
            setSelectedRowKeys={setSelectedRowKeys}
          >
            <div />
          </AssignToUserModal>
        </Space>
      ),
      key: 2,
      className: !canAssignToMyTeamPermission ? "display-none" : "",
    },
    {
      label: (
        <div onClick={() => toolsClickHandler("Unassign_Order")}>
          {translate("manageOrder.orderToolUnassignOrder")}
        </div>
      ),
      key: 3,
      className: !unAssignPermission ? "display-none" : "",
    },
    {
      label: (
        <div onClick={() => toolsClickHandler("Follow")}>
          {translate("manageOrder.orderToolFollow")}
        </div>
      ),
      key: 4,
    },
    {
      label: (
        <div onClick={() => toolsClickHandler("Unfollow")}>
          {translate("manageOrder.orderToolUnfollow")}
        </div>
      ),
      key: 5,
    },
    {
      label: (
        <div onClick={() => toolsClickHandler("print")}>
          {translate("manageOrder.orderToolPrint")}
        </div>
      ),
      key: 6,
    },
  ];

  const openModal = () => {
    const filterColumnData = initialFilterColumnList();
    setFilterColumnListData(filterColumnData);
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    const element: any = document?.getElementById("filter-view-modal-wrapper");
    const { top } = element.getBoundingClientRect();
    const topPosition = top + 40;
    setModalStyle({
      top: `${topPosition}px`,
      marginRight: "80px",
    });
    if (isFilterClear) {
      setFilterValue([]);
      setFilterValue((prevState) => {
        const filterData: IFilterItemProps[] = [...prevState];
        filterData.push({
          FilterName: "",
          FilterOperator: "",
          FilterValue: "",
        });
        return filterData;
      });
    }
    setClickedAppliedFilter("filterTitle");
    setOpenFilter(true);
  };

  const handleOnCheckBoxPress = (value: boolean, title: string) => {
    const field = "hidden";
    const tableData: IColumnProps[] = [...columnsList];
    const index = tableData.findIndex((el: IColumnProps) => {
      return el.title == title;
    });
    const row: IColumnProps = tableData[index];
    row[field] = !row?.hidden;
    tableData[index] = row;
    setColumnsList(tableData);
    setLocalStorageDataForColumns(TABLECOLUMN, tableData);
  };

  const handleOpenChange = (newOpen: boolean) => {
    setSearchInput("");
    setOpenColumnsPopup(newOpen);
  };

  const filterColumnsOnSearch = columnsList.filter((item: IColumnProps) => {
    return item?.title?.toLowerCase()?.includes(searchInput.toLowerCase());
  });

  const filteredColumns =
    (searchInput && searchInput.trim() ? filterColumnsOnSearch : columnsList) || [];

  return (
    <Space wrap>
      <Space
        id="filter-view-modal-wrapper"
        onClick={openModal}
        className="title-name cursor-pointer"
      >
        {translate("manageOrder.filterTitle")}
        <CaretDownOutlined />
      </Space>
      <Dropdown
        menu={{ items }}
        trigger={["click"]}
        {...(assignToMyTeamModal ? { open: assignToMyTeamModal } : {})}
        getPopupContainer={(triggerNode: HTMLElement) => triggerNode.parentNode as HTMLElement}
      >
        <Space className="title-name cursor-pointer">
          Tools
          <CaretDownOutlined />
        </Space>
      </Dropdown>
      <Popover
        title=""
        content={
          <Space
            className="m-0"
            size={16}
            direction="vertical"
            style={{ maxHeight: "200px", overflowY: "scroll" }}
          >
            <Input
              placeholder="Search Option"
              data-test-selector="txtColumnSearch"
              onChange={(e) => setSearchInput(e.target.value)}
              value={searchInput}
              suffix={
                <div>
                  <SearchOutlined
                    style={{ color: "rgba(0,0,0,.45)" }}
                    className="search-icon-style"
                  />
                </div>
              }
              allowClear={true}
            />
            <Space direction="vertical" className="d-flex">
              {filteredColumns?.map((item: IColumnProps, i: number) => {
                if (item?.title != Age) {
                  if (
                    item?.title == "Order Number" ||
                    item?.title == "Customer" ||
                    item?.title == "Total"
                  ) {
                    disableColumns = true;
                  } else {
                    disableColumns = false;
                  }
                  return (
                    <>
                      <CheckBoxComponent
                        key={i}
                        name={item?.title}
                        checked={Boolean(!item?.hidden)}
                        closable={false}
                        dataTestSelector={"chkMyself"}
                        onChangeHandle={(e: CheckboxChangeEvent) => {
                          handleOnCheckBoxPress(e?.target?.checked, item?.title);
                        }}
                        disabled={disableColumns}
                      />
                      <Divider className="m-0" />
                    </>
                  );
                }
              })}
            </Space>
          </Space>
        }
        trigger="click"
        open={openColumnsPopup}
        placement="bottomLeft"
        onOpenChange={handleOpenChange}
      >
        <Space
          onClick={() => {
            setOpenColumnsPopup(true);
          }}
          className="title-name cursor-pointer"
        >
          {translate("manageOrder.columnTitle")}
          <CaretDownOutlined />
        </Space>
      </Popover>
      <Modal
        title={
          <Space direction="vertical" className="d-flex">
            <Text>{translate("manageOrder.filterResult")}</Text>
            <Divider className="m-0" />
          </Space>
        }
        open={openFilter}
        onCancel={() => {
          setOpenFilter(false);
        }}
        zIndex={10}
        mask={false}
        footer={null}
        width={600}
        style={modalStyle}
        closable={false}
      >
        <Filters
          setOpenFilter={setOpenFilter}
          manageFilter={manageFilter}
          filterValue={filterValue}
          setFilterValue={setFilterValue}
          setOrderListParams={setOrderListParams}
          setAppliedFilters={setAppliedFilters}
          appliedFilters={appliedFilters}
          filterColumnListData={filterColumnListData}
          setFilterColumnListData={setFilterColumnListData}
          isFilterClear={isFilterClear}
          setIsFilterClear={setIsFilterClear}
          clickedAppliedFilter={clickedAppliedFilter}
        />
      </Modal>
    </Space>
  );
};

export default OrderActionFilters;
