/* eslint-disable max-lines-per-function */
/* eslint-disable max-len */
import React, { useContext, useState } from "react";
import { Button, Space, Select, Modal } from "antd";
import { DownOutlined } from "@ant-design/icons";
import {
  IFilterItemProps,
  OrderFiltersProps,
  filters,
  priorityView,
} from "interfaces/ClientInterface/IOrderList";
import { SavedViewPopup } from "./SavedViewPopup";
import { translate } from "i18n";
import { PureAbility } from "@casl/ability";
import { AbilityContext } from "ability/can";
import { PERMISSION_CODE, PERMISSION_SUBJECT } from "ability/utils";
import { setLocalStorageData, removeLocalStorageData } from "utils/localStorage";
import { FILTERVALUE, ORDERTYPE, STORELIST, SAVEDVIEWFILTER } from "config/constant";

const OrderFilters = ({
  filters,
  setFilters,
  storeList,
  userGroupList,
  savedView,
  setSavedView,
  manageSavedView,
  manageGetView,
  setOrderListParams,
  priorityView,
  setPriorityView,
  setCheckedSavedView,
  checkedSaveView,
  selectedSaveView,
  setFilterValue,
  setAppliedFilters,
  setSelectedRowKeys,
  shareWithUserGroup,
  setShareWithUserGroup,
  shareWithEveryone,
  setShareWithEveryone,
  setViewRedirection,
  isAppliedSearchOrFilters,
  setIsAppliedSearchOrFilters,
  setCurrentPage,
}: OrderFiltersProps) => {
  const ability: PureAbility<[string, string]> = useContext(AbilityContext);
  const [openSavedViewModal, setOpenSavedViewModal] = useState(false);
  const [modalStyle, setModalStyle] = useState({});

  const openModal = () => {
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    const element: any = document?.getElementById("saved-view-modal-wrapper");
    const { top } = element.getBoundingClientRect();
    const topPosition = top + 40;
    setModalStyle({
      top: `${topPosition}px`,
    });

    setOpenSavedViewModal(true);
  };

  let ORDERS_TYPES = [
    { label: translate("manageOrder.orderTypesMyTeamsOrder"), value: "MyTeam" },
    { label: translate("manageOrder.orderTypesManagedOrders"), value: "ManagedOrder" },
    { label: translate("manageOrder.orderTypesDelegateToMe"), value: "DelegatedToMe" },
    { label: translate("manageOrder.orderTypesFollowing"), value: "Following" },
    { label: translate("manageOrder.orderTypesMyOrders"), value: "MyOrder" },
    { label: translate("manageOrder.orderTypesAllOrders"), value: "AllOrder" },
  ];

  const canSeeAllOrders = ability.can(PERMISSION_CODE.SELL_ALL_ORDERS, PERMISSION_SUBJECT.ORDERS);
  const canSeeMyUserGroupsOrders = ability.can(
    PERMISSION_CODE.SEE_MY_USER_GROUPS_ORDERS,
    PERMISSION_SUBJECT.ORDERS
  );
  //remove AllOrder option if SeeAllOrders permission is false
  if (!canSeeAllOrders) {
    ORDERS_TYPES = ORDERS_TYPES.filter((el) => {
      return el?.label !== translate("manageOrder.orderTypesAllOrders");
    });
  }
  //remove MyTeam option if orderTypesMyTeamsOrder permission is false along with SeeAllOrders permission
  if (!(canSeeAllOrders || (!canSeeAllOrders && canSeeMyUserGroupsOrders))) {
    ORDERS_TYPES = ORDERS_TYPES.filter((el) => {
      return el?.label !== translate("manageOrder.orderTypesMyTeamsOrder");
    });
  }

  // const canCreatePublicViews = ability.can(
  //   PERMISSION_CODE.CREATE_PUBLIC_VIEWS,
  //   PERMISSION_SUBJECT.DASHBOARD
  // );
  // const canCreateUserGroupViews = ability.can(
  //   PERMISSION_CODE.CREATE_USER_GROUP_VIEWS,
  //   PERMISSION_SUBJECT.DASHBOARD
  // );

  const preferredViewClickHandler = (ViewId: number) => {
    setLocalStorageData(SAVEDVIEWFILTER, ViewId.toString());
    removeLocalStorageData(STORELIST);
    removeLocalStorageData(ORDERTYPE);
    removeLocalStorageData(FILTERVALUE);
    setFilters((prevState: filters) => ({
      ...prevState,
      selectedOrderTypeClass: "",
      selectedStoreClass: "",
    }));
    setOpenSavedViewModal(false);
    manageGetView && manageGetView(ViewId);
  };

  return (
    <Space wrap>
      <Button
        type={
          filters?.orderType == "" &&
          filters?.storeName == -1 &&
          filters?.selectedView == 0 &&
          isAppliedSearchOrFilters == false
            ? "primary"
            : "default"
        }
        data-test-selector="btnSmartView"
        onClick={() => {
          removeLocalStorageData(STORELIST);
          removeLocalStorageData(ORDERTYPE);
          removeLocalStorageData(FILTERVALUE);
          removeLocalStorageData(SAVEDVIEWFILTER);
          setFilters((prevState: filters) => ({
            ...prevState,
            orderType: "",
            storeName: -1,
            selectedView: 0,
            selectedOrderTypeClass: "",
            selectedStoreClass: "",
          }));
          setOrderListParams({
            portalId: -1,
            classNumber: "",
            category: "MyOrder_IN PROGRESS",
            account: "",
            userFullName: "",
            orderStateName: "",
            orderTotal: "",
            globalSearch: "",
            operatorClassNumber: "",
            operatorAccountName: "",
            operatorUserName: "",
            operatorOrderStateName: "",
            operatorOrderTotal: "",
            operatorAssignToFullName: "",
            assignToFullName: "",
            operatormodifiedDate: "",
            modifiedDate: "",
            operatorcreatedDate: "",
            createdDate: "",
            columnSorting: "",
          });
          setSelectedRowKeys([]);
          setViewRedirection(false);
          setIsAppliedSearchOrFilters(false);
          setAppliedFilters([]);
          setFilterValue([]);
          setFilterValue((prevState) => {
            const filterData: IFilterItemProps[] = [...prevState];
            filterData.push({
              FilterName: "",
              FilterOperator: "",
              FilterValue: "",
            });
            return filterData;
          });
        }}
      >
        {translate("manageOrder.btnSmartView")}
      </Button>

      <Select
        className={filters?.selectedOrderTypeClass}
        size="middle"
        value={isAppliedSearchOrFilters ? "Search Results" : filters?.orderType || undefined}
        options={ORDERS_TYPES}
        onChange={(selectedValue: string): void => {
          setLocalStorageData(ORDERTYPE, selectedValue);
          removeLocalStorageData(STORELIST);
          removeLocalStorageData(FILTERVALUE);
          removeLocalStorageData(SAVEDVIEWFILTER);
          setCurrentPage(1);
          setFilters((prevState: filters) => ({
            ...prevState,
            orderType: selectedValue,
            selectedOrderTypeClass: "active-select",
            selectedStoreClass: "",
            selectedView: 0,
          }));
        }}
        bordered={true}
        data-test-selector="drpOrderType"
        placeholder="Select Orders"
        dropdownStyle={{ minWidth: "15%" }}
      />
      <Select
        className={filters?.selectedStoreClass}
        size="middle"
        value={filters?.storeName != -1 ? filters?.storeName : undefined}
        options={storeList}
        onChange={(selectedValue: number): void => {
          setLocalStorageData(STORELIST, selectedValue.toString());
          removeLocalStorageData(ORDERTYPE);
          removeLocalStorageData(FILTERVALUE);
          removeLocalStorageData(SAVEDVIEWFILTER);
          setFilters((prevState: filters) => ({
            ...prevState,
            storeName: selectedValue,
            selectedOrderTypeClass: "",
            selectedStoreClass: "active-select",
            selectedView: 0,
          }));
        }}
        data-test-selector="drpStoreList"
        placeholder="Select Stores"
        dropdownStyle={{ minWidth: "15%" }}
        fieldNames={{ label: "Name", value: "Id" }}
      />
      {priorityView?.map((el: priorityView) => {
        if (el?.ViewId !== -1) {
          return (
            <Button
              type={filters?.selectedView == el?.ViewId ? "primary" : "default"}
              key={el.ViewId}
              data-test-selector="btnFavoriteView"
              onClick={() => preferredViewClickHandler(Number(el.ViewId))}
            >
              {el.viewName}
            </Button>
          );
        }
      })}
      {/* {(canCreatePublicViews || canCreateUserGroupViews) && ( */}
      <Button id="saved-view-modal-wrapper" data-test-selector="btnSavedView" onClick={openModal}>
        {translate("manageOrder.btnSavedView")} <DownOutlined />
      </Button>
      {/* )} */}
      <Modal
        title={""}
        open={openSavedViewModal}
        onCancel={() => {
          setOpenSavedViewModal(false);
        }}
        zIndex={10}
        mask={false}
        footer={null}
        width={360}
        style={modalStyle}
        closable={false}
        className="saved-view-popup"
      >
        <SavedViewPopup
          openSavedViewModal={openSavedViewModal}
          setOpenSavedViewModal={setOpenSavedViewModal}
          manageSavedView={manageSavedView}
          manageGetView={manageGetView}
          userGroupList={userGroupList}
          savedView={savedView}
          setSavedView={setSavedView}
          filters={filters}
          setFilters={setFilters}
          priorityView={priorityView}
          setPriorityView={setPriorityView}
          checkedSaveView={checkedSaveView}
          setCheckedSavedView={setCheckedSavedView}
          selectedSaveView={selectedSaveView}
          shareWithUserGroup={shareWithUserGroup}
          setShareWithUserGroup={setShareWithUserGroup}
          shareWithEveryone={shareWithEveryone}
          setShareWithEveryone={setShareWithEveryone}
        />
      </Modal>
    </Space>
  );
};

export default OrderFilters;
