/* eslint-disable max-len */
/* eslint-disable max-lines-per-function */
import React, { useContext, useEffect, useState } from "react";
import { Button, Col, Divider, Input, Row, Space, Radio, Tooltip, Select, Typography } from "antd";
import Checkbox, { CheckboxChangeEvent } from "antd/es/checkbox";
import { CheckBoxComponent } from "components/Common/Checkbox/Checkbox";
//import SelectInput from "components/Common/Select/Select";
import {
  ISavedViewListProps,
  SavedViewPopupProps,
  filters,
} from "interfaces/ClientInterface/IOrderList";
import {
  EditOutlined,
  //SearchOutlined,
  DeleteOutlined,
  SaveOutlined,
  CloseOutlined,
  CaretDownOutlined,
  GlobalOutlined,
  UsergroupAddOutlined,
} from "@ant-design/icons";
import { AbilityContext } from "ability/can";
import { translate } from "i18n";
import { PERMISSION_CODE, PERMISSION_SUBJECT } from "ability/utils";
import { setLocalStorageData } from "utils/localStorage";
import { SAVEDVIEWFILTER } from "config/constant";

const { Text } = Typography;

export const SavedViewPopup: React.FC<SavedViewPopupProps> = ({
  //openSavedViewModal,
  setOpenSavedViewModal,
  manageSavedView,
  manageGetView,
  userGroupList,
  savedView,
  //setSavedView,
  filters,
  setFilters,
  priorityView,
  setPriorityView,
  checkedSaveView,
  setCheckedSavedView,
  selectedSaveView,
  shareWithUserGroup,
  setShareWithUserGroup,
  shareWithEveryone,
  setShareWithEveryone,
}: SavedViewPopupProps) => {
  const ability = useContext(AbilityContext);
  // const canCreatePublicViews = ability.can(
  //   PERMISSION_CODE.CREATE_PUBLIC_VIEWS,
  //   PERMISSION_SUBJECT.DASHBOARD
  // );
  // const canCreateUserGroupViews = ability.can(
  //   PERMISSION_CODE.CREATE_USER_GROUP_VIEWS,
  //   PERMISSION_SUBJECT.DASHBOARD
  // );
  const canShareViewswithEveryone = ability.can(
    PERMISSION_CODE.SHARE_VIEWS_WITH_EVERYONE,
    PERMISSION_SUBJECT.ORDERS
  );
  const canShareViewswithUserGroups = ability.can(
    PERMISSION_CODE.SHARE_VIEWS_WITH_USER_GROUPS,
    PERMISSION_SUBJECT.ORDERS
  );

  const [userGroup, setUserGroup] = useState<number>(0);
  const [newViewName, setNewViewName] = useState("");
  const [newViewValidation, setNewViewValidation] = useState("");
  const [edit, setEdit] = useState({
    viewName: "",
    viewId: -1,
  });
  const handleSavedView = () => {
    setNewViewValidation("");
    setOpenSavedViewModal(false);
    setNewViewName("");
    const data = {
      shareWithUserGroup: shareWithUserGroup,
      shareWithEveryone: shareWithEveryone,
      userGroup: userGroup,
      newViewName: newViewName,
      viewId: 0,
      type: "",
      isDefault: false,
      viewPriority: 0,
    };
    manageSavedView && manageSavedView(data);
  };
  // eslint-disable-next-line @typescript-eslint/no-explicit-any
  const handleEditSavedView = (item: any, type: string) => {
    if (type == "remove") {
      setEdit({
        viewName: "",
        viewId: -1,
      });
    }
    if (type == "Edit") {
      setEdit((prevState) => ({
        ...prevState,
        viewName: item?.ViewName,
        viewId: item?.ViewId,
      }));
    }
    if (type == "Editsave") {
      setEdit({
        viewName: "",
        viewId: -1,
      });
      setOpenSavedViewModal(false);
    }
    const data = {
      shareWithUserGroup: item.shareWithUserGroup,
      shareWithEveryone: item.shareWithEveryone,
      userGroup: item.userGroup,
      newViewName: edit.viewName ? edit.viewName : item?.ViewName,
      viewId: item.ViewId,
      type: type,
      isDefault: false,
      viewPriority: 0,
    };
    manageSavedView && manageSavedView(data);
  };
  const handelMultipleShare = (type: string) => {
    const data = {
      shareWithUserGroup: shareWithUserGroup,
      shareWithEveryone: shareWithEveryone,
      userGroup: userGroup,
      newViewName: newViewName,
      viewId: 0,
      type: type,
      isDefault: false,
      viewPriority: 0,
    };
    setOpenSavedViewModal(false);
    manageSavedView && manageSavedView(data);
  };
  const SaveViewNameValidate = (viewName: string) => {
    setNewViewName(viewName);
    setNewViewValidation("");
  };
  useEffect(() => {
    allowSetUserGroup(filters?.userGroup);
  }, [filters?.userGroup]);
  // eslint-disable-next-line @typescript-eslint/no-explicit-any
  const allowSetUserGroup = (userGroup: any) => {
    setUserGroup(userGroup);
  };
  const handleGetViewView = (viewId: number) => {
    setLocalStorageData(SAVEDVIEWFILTER, viewId.toString());
    setOpenSavedViewModal(false);
    manageGetView && manageGetView(viewId);
  };

  /**
   * This function handles the change in priority of a view by updating the viewId in the savedView
   * array.
   * @param {number} checkedVal - The priority value that has been checked/selected.
   * @param {number} viewId - viewId is a number parameter that represents the unique identifier of a
   * view.
   */
  const handlePriorityChange = (checkedVal: number, ViewId: number) => {
    const data = [...priorityView];
    const checkIsViewPresent = data.findIndex((el) => {
      return el?.ViewId == ViewId;
    });
    //needs to remove the viewId if it is already present for other priority
    if (checkIsViewPresent !== -1) {
      data[checkIsViewPresent]["ViewId"] = -1;
    }
    const iData = data[checkedVal - 1];
    iData.ViewId = ViewId;
    setPriorityView(data);
  };

  const handleViewListCheck = (isChecked: boolean, viewId: number) => {
    setCheckedSavedView((prevState) => {
      let checkedData: number[] = [...prevState];
      if (isChecked) {
        checkedData.push(viewId);
      } else {
        checkedData = checkedData?.filter((item) => item !== viewId);
      }
      return checkedData;
    });
  };

  return (
    <Space size={16} direction="vertical" className="w-100">
      <Space direction="vertical" size={8} className="view-container w-100">
        {savedView &&
          savedView.map((item: ISavedViewListProps, i: number) => {
            const check = priorityView.find((el) => {
              return el?.ViewId == item?.ViewId;
            });
            return (
              <>
                {edit?.viewId == item?.ViewId ? (
                  <Space size={14} key={i}>
                    <CaretDownOutlined className="down-caret" />
                    <Input
                      value={edit?.viewName}
                      onChange={(e) => {
                        setEdit((prevState) => ({
                          ...prevState,
                          viewName: e?.target?.value,
                        }));
                      }}
                      data-test-selector="txtNewView"
                      placeholder="Enter View Name"
                      style={{ width: 200 }}
                    />
                    <CloseOutlined
                      className="text-color-gray"
                      onClick={() => handleEditSavedView(item, "remove")}
                    />
                    <DeleteOutlined
                      className="text-color-gray"
                      onClick={() => handleEditSavedView(item, "Delete")}
                    />
                    <SaveOutlined
                      className="text-color-gray"
                      onClick={() => handleEditSavedView(item, "Editsave")}
                    />
                  </Space>
                ) : (
                  <Space size={24} key={i} className="w-100">
                    <Space>
                      {canShareViewswithUserGroups || canShareViewswithEveryone ? (
                        <Checkbox
                          checked={
                            checkedSaveView?.findIndex((el: number) => {
                              return el == item?.ViewId;
                            }) != -1
                              ? true
                              : false
                          }
                          onChange={(e: CheckboxChangeEvent) => {
                            handleViewListCheck(e.target.checked, item?.ViewId);
                          }}
                        />
                      ) : null}
                      {item?.IsPublic ? (
                        <GlobalOutlined />
                      ) : item?.UserGroupId != 0 ? (
                        <UsergroupAddOutlined />
                      ) : (
                        <div className="blank-icon" />
                      )}
                      <Tooltip placement="top" title={"Edit"}>
                        <EditOutlined
                          className="text-color-gray"
                          onClick={() => handleEditSavedView(item, "Edit")}
                        />
                      </Tooltip>
                    </Space>
                    <Space size={24} className="priority-group w-100">
                      <div
                        className={
                          selectedSaveView == item.ViewId
                            ? "active-view title-name cursor-pointer"
                            : "title-name cursor-pointer"
                        }
                        onClick={() => handleGetViewView(item.ViewId)}
                      >
                        {item?.ViewName}
                      </div>
                      <Radio.Group
                        size="small"
                        onChange={(e) => handlePriorityChange(e?.target?.value, item?.ViewId)}
                        value={check ? check?.priority : -1}
                      >
                        <Radio.Button
                          value={1}
                          className="priority-btn"
                          onClick={() => handleEditSavedView(item, "Priority1")}
                        >
                          1
                        </Radio.Button>
                        <Radio.Button
                          value={2}
                          className="priority-btn"
                          onClick={() => handleEditSavedView(item, "Priority2")}
                        >
                          2
                        </Radio.Button>
                        <Radio.Button
                          value={3}
                          className="priority-btn"
                          onClick={() => handleEditSavedView(item, "Priority3")}
                        >
                          3
                        </Radio.Button>
                      </Radio.Group>
                    </Space>
                  </Space>
                )}
              </>
            );
          })}
      </Space>
      <Divider className="m-0" />
      <Space direction="vertical" size={16} className="d-flex">
        {checkedSaveView?.length == 0 ? (
          <>
            <Space size={24}>
              <Input
                data-test-selector="txtNewView"
                placeholder="New View"
                onChange={(e) => SaveViewNameValidate(e?.target?.value)}
                value={newViewName}
                style={{ width: 245 }}
              />

              <Button
                type="primary"
                data-test-selector={"btnSaveView"}
                onClick={() =>
                  newViewName == ""
                    ? setNewViewValidation(translate("manageOrder.RequiredViewName"))
                    : handleSavedView()
                }
              >
                {translate("editOrder.saveBtn")}
              </Button>
            </Space>
            {newViewValidation == "" ? (
              ""
            ) : (
              <Space>
                {" "}
                <Text type="danger">{newViewValidation}</Text>
              </Space>
            )}
          </>
        ) : null}
        {canShareViewswithUserGroups ? (
          <Row className="d-flex align-center">
            <Col>
              <CheckBoxComponent
                name={<div className="text-color-gray">{translate("editOrder.shareWith")}</div>}
                checked={shareWithUserGroup}
                closable={false}
                dataTestSelector={"chkShareWithUserGroup"}
                onChangeHandle={(e: CheckboxChangeEvent) => setShareWithUserGroup(e.target.checked)}
              />
            </Col>
            <Col>
              <Select
                size="middle"
                options={userGroupList}
                onChange={(selectedValue: number): void =>
                  setFilters((prevState: filters) => ({
                    ...prevState,
                    userGroup: selectedValue,
                  }))
                }
                bordered={true}
                data-test-selector="drpuserGroupList"
                placeholder="Select User Group"
                dropdownStyle={{ minWidth: "15%" }}
                fieldNames={{ label: "GroupName", value: "CPUserGroupId" }}
              />
            </Col>
          </Row>
        ) : null}
        {canShareViewswithEveryone ? (
          <Row className="d-flex align-center">
            <Col>
              <CheckBoxComponent
                name={
                  <span className="text-color-gray">
                    {translate("editOrder.shareWithEveryone")}
                  </span>
                }
                checked={shareWithEveryone}
                closable={false}
                dataTestSelector={"chkShareWithEveryone"}
                onChangeHandle={(e: CheckboxChangeEvent) => setShareWithEveryone(e.target.checked)}
              />
            </Col>
          </Row>
        ) : null}
        {checkedSaveView?.length > 0 ? (
          <Row className="d-flex justify-end">
            <Button
              type="primary"
              data-test-selector={"btnSaveView"}
              onClick={() => handelMultipleShare("MultipleShare")}
            >
              {translate("editOrder.share")}
            </Button>
          </Row>
        ) : null}
      </Space>
    </Space>
  );
};
