/* eslint-disable max-lines-per-function */
import { Col, Row, Space, Button, Form, Input, Card, Typography } from "antd";
import { getUserDetails } from "api/services/localStorage.service";

import { changeUserPassword } from "api/services/userProfile.api";
import Heading from "components/Common/Heading/Heading";
import { notificationController } from "components/Common/Notification/Notification";
import { translate } from "i18n";
import {
  IChanePasswordUserProfile,
  IProfileChangePassword,
} from "interfaces/ClientInterface/IUserProfile";
import React from "react";
import { useNavigate } from "react-router-dom";
import { ROUTES_PATH } from "routes/Routes.Constant";
import { isPasswordMatched } from "utils/validation";

const { Text } = Typography;
const ChangePassword = () => {
  const navigate = useNavigate();
  const handlebackToProfile = () => {
    navigate(-1);
  };
  const [form] = Form.useForm();

  const userData = getUserDetails() ? JSON.parse(getUserDetails() || "") : {};
  const email = userData?.UserName;

  /**
   * Use for change the password of the user
   * @param values
   */

  const onUserChangePassword = (values: IChanePasswordUserProfile) => {
    const changePasswordPayload: IProfileChangePassword = {
      user: {
        Password: values?.currentPassword,
        newPassword: values?.newPassword,
        conFirmPassword: values?.confirmNewPassword,
        username: email,
      },
      IsChangePasswordFromProfile: true,
    };
    changeUserPassword(changePasswordPayload)
      .then((response) => {
        const errorCode = response?.data?.HasError;
        if (!errorCode) {
          notificationController.success({
            message: translate("userProfile.passwordChangedSuccessMessage"),
            placement: "top",
          });
          navigate(ROUTES_PATH.REDIRECT_TO_LOGIN);
        } else {
          navigate(ROUTES_PATH.CHANGE_PASSWORD);
        }
      })
      .catch((err) => {
        notificationController.error({
          message:
            err?.response?.status === 500
              ? err.message
              : translate("userProfile.passwordChangedErrorMessage"),
          placement: "top",
        });
      });
  };

  return (
    <Space direction="vertical" className="d-flex" size={"middle"}>
      <Row>
        <Col span={24}>
          <Heading textFontLevel={3} titleClass={"section-title"} titleText={"Change Password"} />
        </Col>
      </Row>
      <Card>
        <Row gutter={[15, 15]}>
          <Col span={24} className="change-password-container">
            <div className="change-password-form">
              <div className="form-header mb-15">
                <Text>{translate("userProfile.changePasswordInformationHeaderMessage")}</Text>
              </div>
              <Form
                name="user_profile"
                labelCol={{ span: 24 }}
                wrapperCol={{ span: 24 }}
                onFinish={onUserChangePassword}
                form={form}
                layout="vertical"
              >
                <Row gutter={[15, 15]}>
                  <Col span={24}>
                    <Form.Item
                      rules={[
                        {
                          required: true,
                          message: translate("userProfile.placeholderCurrentPassword"),
                        },
                      ]}
                      label={translate("userProfile.labelCurrentPassword")}
                      name="currentPassword"
                      className="form-label"
                      validateTrigger="onBlur"
                    >
                      <Input.Password />
                    </Form.Item>
                  </Col>
                </Row>
                <Row gutter={[15, 15]}>
                  <Col span={12}>
                    <Form.Item
                      rules={[
                        () => ({
                          validator(_, value) {
                            if (!value) {
                              return Promise.reject(
                                new Error(translate("userProfile.errorMessageInputNewPassword"))
                              );
                            }

                            return Promise.resolve();
                          },
                        }),
                      ]}
                      label={translate("userProfile.labelNewPassword")}
                      name="newPassword"
                      className="form-label"
                      validateTrigger="onBlur"
                    >
                      <Input.Password />
                    </Form.Item>
                  </Col>
                  <Col span={12}>
                    <Form.Item
                      label={translate("userProfile.labelConfirmNewPassword")}
                      name="confirmNewPassword"
                      dependencies={["newPassword"]}
                      rules={[
                        ({ getFieldValue }) => ({
                          validator(_, value) {
                            if (!value) {
                              return Promise.reject(
                                new Error(translate("userProfile.errorMessageInputConfirmPassword"))
                              );
                            }
                            if (
                              value.trim() !== "" &&
                              !isPasswordMatched(getFieldValue("newPassword"), value)
                            ) {
                              return Promise.reject(
                                new Error(translate("userProfile.errorMessagePasswordNotMatch"))
                              );
                            }
                            return Promise.resolve();
                          },
                        }),
                      ]}
                      validateTrigger="onBlur"
                      className="form-label"
                    >
                      <Input.Password />
                    </Form.Item>
                  </Col>
                </Row>
                <Row gutter={[15, 15]}>
                  <Col span={24} className="text-right">
                    <Form.Item wrapperCol={{ span: 24 }} className="form-action-btn">
                      <Space size={"middle"}>
                        <Button type="primary" htmlType="submit">
                          {translate("userProfile.btnResetPassword")}
                        </Button>
                        <Button onClick={handlebackToProfile}>
                          {translate("userProfile.btnCancel")}
                        </Button>
                      </Space>
                    </Form.Item>
                  </Col>
                </Row>
              </Form>
            </div>
          </Col>
        </Row>
      </Card>
    </Space>
  );
};

export default ChangePassword;
