/* eslint-disable max-lines-per-function */
/* eslint-disable max-lines */
/* eslint-disable max-len */
import {
  Col,
  Row,
  Space,
  Button,
  Form,
  Input,
  Typography,
  Card,
  Divider,
  Select,
  Spin,
} from "antd";
import Heading from "components/Common/Heading/Heading";
import { DeleteFilled, CloseOutlined } from "@ant-design/icons";
import React, { useContext, useEffect, useState } from "react";
import "./UserProfile.scss";
import {
  ICpRoleUserListParams,
  IDelegateUser,
  IManagerDelegateParams,
  ISavedDelegateParams,
  IUpdateProfileParams,
  IUpdateUserProfileParams,
} from "interfaces/ClientInterface/IUserProfile";
import { getUserDetails, readUserId } from "api/services/localStorage.service";
import {
  getCpRoleUsers,
  getMangerDelegateList,
  getUserProfileList,
  saveCpRoleUsersDelegate,
  updateUserProfile,
} from "api/services/userProfile.api";
import { notificationController } from "components/Common/Notification/Notification";
import { ICpUserProfileData, IUserProfileData } from "interfaces/APIInterface/IUserProfile";
import { translate } from "i18n";
import { DELEGATES, MANAGERS, ORDER_ORIGIN } from "config/constant";
import { useNavigate } from "react-router-dom";
import { ROUTES_PATH } from "routes/Routes.Constant";
import { isValidAlphabetsOnly, isValidEmailAddress, isValidPhoneNumber } from "utils/validation";
import { AbilityContext } from "ability/can";
import { PERMISSION_CODE, PERMISSION_SUBJECT } from "ability/utils";

const { Text, Title } = Typography;

const UserProfile = () => {
  const ability = useContext(AbilityContext);
  // eslint-disable-next-line @typescript-eslint/no-unused-vars, no-unused-vars
  const canDelegate = ability.can(PERMISSION_CODE.CAN_DELEGATE, PERMISSION_SUBJECT.USER_PROFILE);

  const userData = getUserDetails() ? JSON.parse(getUserDetails() || "") : {};
  const email = userData?.UserName;

  const [addRowValue, setAddRowValue] = useState<IDelegateUser[]>([]);
  const [userProfile, setUserProfile] = useState<IUserProfileData>({} as IUserProfileData);
  const [cpUsers, setcpUsers] = useState<ICpUserProfileData[]>([]);
  const [searchTerm, setSearchTerm] = useState<string>("");
  const [user, setUser] = useState<string>("");
  const [isAddDelegate, setIsAddDelegate] = useState(false);
  const [managers, setManagers] = useState<IDelegateUser[]>([]);

  const [loader, setLoader] = useState({
    userLoading: false,
  });
  const [error, setError] = useState({
    userError: "",
  });
  const [form] = Form.useForm();
  const [managerListLoader, setManagerListLoader] = useState(false);

  useEffect(() => {
    form.setFieldsValue({
      ...userProfile,
    });
  }, [userProfile, form]);
  useEffect(() => {
    getUserProfile();
    getManagerDelegateList();
    // eslint-disable-next-line react-hooks/exhaustive-deps
  }, []);
  useEffect(() => {
    if (searchTerm) {
      searchTerm.length >= 3 && getCpRoleUser();
    } else {
      setcpUsers([]);
    }
    // eslint-disable-next-line react-hooks/exhaustive-deps
  }, [searchTerm]);
  const setLoading = (key: string, loaderState: boolean) => {
    setLoader((prevState) => ({
      ...prevState,
      [key]: loaderState,
    }));
  };
  /**
   * Get the user profile data
   */
  const getUserProfile = () => {
    const userId = readUserId();
    getUserProfileList(userId).then((response) => {
      const data: IUserProfileData = response?.data?.User;
      setUserProfile(data);
    });
  };
  /**
   * Get the commerce portal role user list
   */
  const getCpRoleUser = () => {
    setLoading("userLoading", true);
    const getCpRoleUserPayload: ICpRoleUserListParams = {
      userId: parseInt(readUserId()) || 0,
      userName: email,
      roleName: ORDER_ORIGIN,
    };
    getCpRoleUsers(getCpRoleUserPayload)
      .then((response) => {
        const data: ICpUserProfileData[] = response?.data?.CpUsersRole;

        // Filter the options based on addRowValue
        const filteredOptions = data?.filter((option) => {
          // Check if the option's UserName is not present in addRowValue
          return !addRowValue?.some((row) => row?.attributeValue === option?.UserName);
        });

        setLoading("userLoading", false);
        setcpUsers(filteredOptions);
      })
      .catch(() => {
        notificationController.error({
          message: translate("userProfile.errorFailedToGetUserList"),
        });
      });
  };

  const createUserProfileDelegate = () => {
    if (
      (addRowValue[addRowValue.length - 1].attributeValue == "" ||
        (addRowValue.length == 1 && addRowValue[0].attributeValue == "")) &&
      user != "" &&
      user != undefined
    ) {
      const data: IDelegateUser[] = [...addRowValue];
      const dataString =
        data
          ?.map((el: IDelegateUser) => {
            return el?.attributeValue;
          })
          ?.join(",") || "";
      saveUserProfileDelegate(dataString + user, false);
      setIsAddDelegate(false);
    }
  };

  /**
   * save the user profile delegates
   */
  const saveUserProfileDelegate = (delegateData: string | null, isDelete: boolean) => {
    setLoading("userLoading", true);
    const saveCpUserProfileDelegate: ISavedDelegateParams = {
      globalAttributeCode: DELEGATES,
      globalAttributeValue: delegateData,
      userId:readUserId(),
    };
    saveCpRoleUsersDelegate(saveCpUserProfileDelegate)
      .then((response) => {
        const data: ICpUserProfileData[] = response?.data?.Users;
        setLoading("userLoading", false);
        if (delegateData == "") {
          setUser("");
        }
        setcpUsers(data);
        getManagerDelegateList();
        setIsAddDelegate(false);
        if (!isDelete) {
          notificationController.success({
            message: translate("userProfile.saveDelegates"),
            placement: "top",
          });
        }
      })
      .catch(() => {
        notificationController.error({ message: translate("userProfile.errorInSaveDelegates") });
      });
  };
  /**
   * Get the Manager list of user profile
   */
  const getManagerDelegateList = () => {
    const getManagerDelegatePayload: IManagerDelegateParams = {
      entityId: readUserId(),
      entityType: "User",
    };
    setManagerListLoader(true);
    getMangerDelegateList(getManagerDelegatePayload).then((response) => {
      const data: ICpUserProfileData[] = response?.data?.EntityDetails?.Attributes;
      data?.forEach((element) => {
        if (element.AttributeName == DELEGATES) {
          const attributeValue = element?.AttributeValue ?? "";
          const delegates = attributeValue?.split(",");
          const delegatesValue = delegates?.map((item) => {
            return {
              attributeValue: item,
            };
          });
          const delegateData = attributeValue ? delegatesValue : [];
          setAddRowValue(delegateData);
        } else if (element.AttributeName == MANAGERS) {
          const managerAttibuteValue = element?.AttributeValue ?? "";
          const managers = managerAttibuteValue?.split(",");
          const managersValue = managers?.length > 0 && managers?.[0]
            ? managers?.map((item) => {
              return {
                attributeValue: item,
              };
            })
            : [];
          setManagers(managersValue);
        }
      });
      setManagerListLoader(false);
    });
  };

  const onUserProfileChange = (values: IUpdateUserProfileParams) => {
    const createNotePayload: IUpdateProfileParams = {
      userId: userProfile.UserId,
      email: values.Email,
      phoneNumber: values.PhoneNumber,
      firstName: values.FirstName,
      lastName: values.LastName,
      userName: email,
      aspNetUserId: userProfile.AspNetUserId,
      customerPaymentGUID: userProfile.CustomerPaymentGUID,
      RoleId: userProfile.RoleId,
      RoleName: userProfile.RoleName,
    };
    updateUserProfile(createNotePayload)
      .then((response) => {
        if (!response?.HasError) {
          getUserProfile();
        }
        notificationController.success({
          message: translate("userProfile.updateProfileSuccessMessage"),
          placement: "top",
        });
      })
      .catch(() => {
        notificationController.error({ message: translate("userProfile.errorFailedToUpdate") });
      });
  };

  const navigate = useNavigate();
  /**
   * for navigate the change password page
   */
  const handleChangePassword = () => {
    navigate(ROUTES_PATH.CHANGE_PASSWORD);
  };
  /**
   * use for logout the user
   */
  const Logout = () => {
    navigate(ROUTES_PATH.LOGOUT);
  };
  const deleteRow = (attributeValue: string) => {
    const filteredData = addRowValue.map((item: IDelegateUser) => {
      if (attributeValue != item?.attributeValue) {
        return item?.attributeValue;
      }
    });
    notificationController.success({
      message: translate("userProfile.deleteDelegates"),
    });
    const filteredDataDelegates = filteredData.filter((item) => {
      if (item !== undefined && item !== "") {
        return item;
      }
    });
    saveUserProfileDelegate(
      filteredDataDelegates?.length ? filteredDataDelegates?.join(",") : "",
      true
    );
  };

  const removeDelegateInput = (index: number) => {
    setIsAddDelegate(false);
    setAddRowValue((prevState) => {
      const addRowData: IDelegateUser[] = [...prevState];
      addRowData.splice(index, 1);
      return addRowData;
    });
  };
  
  const onAddRowPress = () => {
    setIsAddDelegate(true);
    if (addRowValue[addRowValue?.length - 1]?.attributeValue !== "") {
      setUser("");
      setAddRowValue((prevState) => {
        const addRowData: IDelegateUser[] = [...prevState];
        addRowData.push({
          attributeValue: "",
        });
        return addRowData;
      });
    }
  };
  const handlebackToListPage = () => {
    navigate(-1);
  };

  return (
    <Space direction="vertical" className="d-flex" size={"middle"}>
      <Row>
        <Col span={24}>
          <Title level={3} className="m-0">
            {translate("userProfile.headerTitle")}
          </Title>
        </Col>
      </Row>
      <Card>
        <Row gutter={[15, 15]}>
          <Col span={16} className="edit-profile-container">
            <div className="edit-profile-form">
              <Form
                name="user_profile"
                labelCol={{ span: 6 }}
                wrapperCol={{ span: 18 }}
                onFinish={onUserProfileChange}
                form={form}
                initialValues={userProfile}
                scrollToFirstError
              >
                <Form.Item
                  rules={[
                    { required: true, message: translate("userProfile.placeholderInputUsername") },
                  ]}
                  label={translate("userProfile.labelUsername")}
                  name={"UserName"}
                  className="form-label"
                >
                  <Input disabled placeholder={email} />
                </Form.Item>
                <Form.Item
                  label={translate("userProfile.labelFirstName")}
                  name={"FirstName"}
                  rules={[
                    {
                      required: true,
                      message: translate("userProfile.placeholderInputFirstName"),
                    },
                    {
                      validator: (_, value) => {
                        if (value && value.length > 30) {
                          return Promise.reject(
                            new Error(translate("userProfile.firstNameValidationMessage"))
                          );
                        }
                        if (value && !isValidAlphabetsOnly.test(value)) {
                          return Promise.reject(
                            new Error(translate("userProfile.firstNameValidationMessage"))
                          );
                        }

                        return Promise.resolve();
                      },
                    },
                  ]}
                  className="form-label"
                >
                  <Input data-test-selector="txtFirstName" />
                </Form.Item>
                <Form.Item
                  label={translate("userProfile.labelLastName")}
                  name={"LastName"}
                  rules={[
                    {
                      required: true,
                      message: translate("userProfile.placeholderInputLastName"),
                    },
                    {
                      validator: (_, value) => {
                        if (value && value.length > 30) {
                          return Promise.reject(
                            new Error(translate("userProfile.lastNameValidationMessage"))
                          );
                        }
                        if (value && !isValidAlphabetsOnly.test(value)) {
                          return Promise.reject(
                            new Error(translate("userProfile.lastNameValidationMessage"))
                          );
                        }

                        return Promise.resolve();
                      },
                    },
                  ]}
                  className="form-label"
                >
                  <Input data-test-selector="txtLastName" />
                </Form.Item>
                <Form.Item
                  label={translate("userProfile.labelEmailAddress")}
                  name={"Email"}
                  rules={[
                    {
                      required: true,
                      pattern: isValidEmailAddress,
                      message: translate("userProfile.emailAddressValidationMessage"),
                    },
                  ]}
                  className="form-label"
                >
                  <Input data-test-selector="txtEmail" />
                </Form.Item>
                <Form.Item
                  label={translate("userProfile.labelPhoneNumber")}
                  name={"PhoneNumber"}
                  rules={[
                    {
                      required: true,
                      message: translate("userProfile.placeholderInputPhoneNumber"),
                    },
                    {
                      validator: (_, value) => {
                        if (value && value.length > 30) {
                          return Promise.reject(
                            new Error(translate("userProfile.phoneNumberValidationMessage"))
                          );
                        }
                        if (value && !isValidPhoneNumber.test(value)) {
                          return Promise.reject(
                            new Error(translate("userProfile.phoneNumberValidationMessage"))
                          );
                        }

                        return Promise.resolve();
                      },
                    },
                  ]}
                  className="form-label"
                >
                  <Input data-test-selector="txtPhoneNumber" />
                </Form.Item>

                <Form.Item wrapperCol={{ span: 24 }} className="form-action-btn">
                  <Space size={"middle"}>
                    <Button onClick={handlebackToListPage}>
                      {translate("userProfile.btnCancel")}
                    </Button>

                    <Button type="primary" htmlType="submit">
                      {translate("userProfile.btnUpdateProfile")}
                    </Button>
                  </Space>
                </Form.Item>
              </Form>
            </div>
          </Col>
          <Col span={8} className="profile-right-container">
            <Space direction="vertical" className="d-flex" size={"middle"}>
              <div className="profile-action-buttons">
                <Space size={"middle"}>
                  <Button type="primary" onClick={handleChangePassword}>
                    {translate("userProfile.btnChangePassword")}
                  </Button>
                  <Button type="primary" onClick={Logout}>
                    {translate("userProfile.btnLogout")}
                  </Button>
                </Space>
              </div>
              <Divider />
              <div className="my-managers-container">
                <Heading
                  textFontLevel={5}
                  titleClass={"sub-section-title"}
                  titleText={"My Managers"}
                />
                {managers?.length > 0 ? (
                  <>
                    {managers?.map((item: IDelegateUser, i: number) => {
                      return (
                        <div className="managers-list-item" key={`managers${i}`}>
                          <Text>{item?.attributeValue}</Text>
                        </div>
                      );
                    })}
                  </>
                ) : (
                  !managerListLoader && (
                    <Space className="d-flex justify-center align-center empty-view text-color-gray">
                      Currently, no managers have been assigned.
                    </Space>
                  )
                )}
              </div>
              <Divider className="m-0" />
              <div className="my-delegates-container">
                <Space className="justify-between w-100 head-btn">
                  <Heading
                    textFontLevel={5}
                    titleClass={"sub-section-title"}
                    titleText={"My Delegates"}
                  />
                  {canDelegate && (
                    <Button type="primary" onClick={onAddRowPress} disabled={isAddDelegate}>
                      {translate("userProfile.btnAddDelegate")}
                    </Button>
                  )}
                </Space>
                {addRowValue?.length > 0 ? (
                  <Space direction="vertical" className="d-flex">
                    <div>
                      {addRowValue.map((item: IDelegateUser, i: number) => {
                        return (
                          <>
                            {item?.attributeValue ? (
                              <div className="managers-list-item">
                                <Space className="d-flex justify-between align-center">
                                  <Text>{item?.attributeValue}</Text>
                                  <Button
                                    type="text"
                                    onClick={() => deleteRow(item?.attributeValue)}
                                    disabled={!canDelegate}
                                  >
                                    <DeleteFilled />
                                  </Button>
                                </Space>
                              </div>
                            ) : (
                              <Row
                                key={`row${i}`}
                                gutter={[20, 20]}
                                className="d-flex justify-center align-center mt-16 flex-baseline"
                              >
                                <Col span={16}>
                                  <Select
                                    className="w-100"
                                    showSearch
                                    options={cpUsers}
                                    placeholder={"Select User"}
                                    allowClear
                                    value={user || undefined}
                                    onChange={(user: string) => {
                                      setUser(user);
                                      setError((prevState) => ({
                                        ...prevState,
                                        userError: "",
                                      }));
                                    }}
                                    notFoundContent={
                                      loader?.userLoading ? <Spin size="small" /> : null
                                    }
                                    // eslint-disable-next-line @typescript-eslint/no-explicit-any
                                    filterOption={(input, option?: any) =>
                                      option?.UserName?.toLowerCase()?.indexOf(
                                        input?.toLowerCase()
                                      ) >= 0
                                    }
                                    onSearch={(searchTerm: string) => setSearchTerm(searchTerm)}
                                    data-test-selector="drpUserList"
                                    fieldNames={{ label: "UserName", value: "UserName" }}
                                    loading={loader?.userLoading}
                                  />
                                  <span className="error">{error && error?.userError}</span>
                                </Col>
                                <Col span={4}>
                                  <Button
                                    type="primary"
                                    onClick={() => {
                                      createUserProfileDelegate();
                                    }}
                                    disabled={!canDelegate}
                                  >
                                    {translate("userProfile.btnAdd")}
                                  </Button>
                                </Col>
                                <Col span={4}>
                                  <Button
                                    type="text"
                                    onClick={() => removeDelegateInput(i)}
                                    disabled={!canDelegate}
                                  >
                                    <CloseOutlined />
                                  </Button>
                                </Col>
                              </Row>
                            )}
                            {item?.attributeValue && <Divider className="m-0" />}
                          </>
                        );
                      })}
                    </div>
                  </Space>
                ) : (
                  !isAddDelegate && (
                    <Space className="d-flex justify-center align-center empty-view text-color-gray">
                      Currently, no delegates have been assigned.
                    </Space>
                  )
                )}
              </div>
            </Space>
          </Col>
        </Row>
      </Card>
    </Space>
  );
};

export default UserProfile;
