export interface IInvoiceDocumentProps {
  data: InvoiceList[];
}

export interface IInvoiceListResponse {
  OrderId: string;
  ClassNumber: string;
  OrderDate: string;
  FirstName: string;
  LastName: string;
  ShippedQuantity: string;
  TrackingNumber: string;
  ShipDate: string;
  ShippingConstraintCode: string;
  ShippingHandlingCharges: string;
  ShippingCost: number;
  DiscountAmount: number;
  CSRDiscountAmount: number;
  ShippingDiscount: string;
  TaxCost: number;
  SubTotal: number;
  Total: number;
  OrderDetail: string;
}

export interface InvoiceList {
  OrderId: string;
  ClassNumber: string;
  OrderDate: string;
  FirstName: string;
  LastName: string;
  ShippedQuantity: string;
  TrackingNumber: string;
  ShipDate: string;
  ShippingConstraintCode: string;
  HandlingFee: number;
  ShippingCost: number;
  Discount: number;
  CSRDiscountAmount: number;
  ShippingDiscount: string;
  VoucherAmount: number;
  TaxCost: number;
  SubTotal: number;
  Total: number;
  OrderDetail: OrderDetailProps[];
  EmailAddress: string;
  ShippingTypeName:string;
  PurchaseOrderNumber:string;
  CustomerServicePhoneNumber:string;
  CustomerServiceEmail:string;
  PromotionCodeList:IPromotionCodeList[]
}

export interface IPromotionCodeList {
  PromotionName: string;
  PromotionCode: string
}

export interface OrderDetailProps {
  Address: Address[];
  OrderProduct: IOrderProductList[];
  OrderPayment: OrderPayment[];
  OrderShipment: OrderShipment[];
  OrderDiscount: IOrderDiscount[];
  OrderProductTax: string;
}

export interface Address {
  OrderAddressId: string;
  OrderId: string;
  ClassId: number;
  FirstName: string;
  LastName: string;
  DisplayName: string;
  CompanyName: string;
  Address1: string;
  Address2: string;
  CountryName: string;
  StateName: string;
  StateCode:string;
  CityName: string;
  PostalCode: string;
  PhoneNumber: string;
  IsActive: boolean;
  CreatedBy: number;
  CreatedDate: string;
  ModifiedBy: number;
  ModifiedDate: string;
  IsShipping: boolean;
  IsBilling: boolean;
  AddressId?: number;
  Mobilenumber?: string;
  EmailAddress?: string;
}

export interface IOrderProductList {
  OrderProductId: string;
  OrderId: string;
  ClassId: number;
  SKU: string;
  ProductName: string;
  ProductType: string;
  Description: string;
  Quantity: number;
  Price: number;
  OmsOrderStateId: number;
  OmsPaymentStateId: number;
  CreatedBy: number;
  CreatedDate: string;
  ModifiedBy: number;
  ModifiedDate: string;
  OrderProductTax: string;
  OrderProductDiscount: string;
  OrderProductNote: string;
  OrderProductAttributeValue: string;
  OrderFlag: string;
  OrderStateName: string;
  PaymentStateName: string;
  ShortDescription: string
}

export interface OrderPayment {
  OrderPaymentDetailId: string;
  ClassId: number;
  OrderId: string;
  PaymentTypeId: number;
  PaymentSettingId: number;
  TaxCost: number;
  ShippingCost: number;
  SubTotal: number;
  DiscountAmount: number;
  CurrencyCode: string;
  OverDueAmount: number;
  Total: number;
  PaymentTransactionToken: string;
  CreditCardNumber: string;
  CardType: string;
  CreditCardExpMonth: string;
  PaymentDisplayName: string;
  ShippingDiscount: number;
  ShippingHandlingCharges: number;
  CreatedBy: number;
  CreatedDate: string;
  ModifiedBy: number;
  ModifiedDate: string;
  OrderAddressId: string;
}

export interface OrderShipment {
  OrderShipmentId: string;
  OrderId: string;
  OrderAddressId: string;
  ClassId: number;
  ShippingId: number;
  TrackingNumber: string;
  ShippingConstraintCode: string;
  ShipDate: string;
  CreatedBy: number;
  CreatedDate: string;
  ModifiedBy: number;
  ModifiedDate: string;
  IsShipCompletely: boolean;
  ShippingAddress: ShippingAddress[];
  ShippingName: string;
}

export interface ShippingAddress {
  OrderAddressId: string;
  OrderId: string;
  ClassId: number;
  FirstName: string;
  LastName: string;
  DisplayName: string;
  CompanyName: string;
  Address1: string;
  Address2: string;
  CountryName: string;
  StateName: string;
  CityName: string;
  PostalCode: string;
  PhoneNumber: string;
  IsActive: boolean;
  CreatedBy: number;
  CreatedDate: string;
  ModifiedBy: number;
  ModifiedDate: string;
  IsShipping: boolean;
  IsBilling: boolean;
  AddressId: number;
}

export interface IOrderDiscount{
  OrderDiscountId : string;
  DiscountCode : string;
  DiscountTypeName : string
}