
export interface IProduct {
  ZnodeProductId: number;
  ImageThumbNailPath: string;
  Name: string;
  SKU: string;
  RetailPrice: string;
  SalesPrice: string;
  Price: string;
  CurrencySuffix: string;
  VersionId: number;
  ImageSmallPath: string;
  Attributes?: IProductFacet[];
  ParentProductId:number;
}

export interface IProductFacetAttributeValue {
  Label: string;
  FacetCount: number;
  IsChecked: boolean | false;
  ActionMode: boolean | false;
}

export interface IProductFacet {
  ActionMode: string | "1";
  AttributeCode: string;
  AttributeName: string;
  AttributeValues: IProductFacetAttributeValue[] | null;
}

export interface IConfigurableAttribute {
  AttributeCode: string;
  AttributeValue: string;
  SwatchText: string;
  SelectValues: ISelectValues[];
  IsNAAttributeAvailable:boolean;  
}

export interface ISelectValues {
  Custom1: string;
  Custom2: string;
}
export interface IConfigurableAttributeList {
  ConfigurableAttributeList: IConfigurableAttribute[];
}

export interface IProductAttribute {
  AttributeCode: string;
  AttributeName: string;
  AttributeValues: string;
  ConfigurableAttribute: IConfigurableAttribute[];
}

export interface IPriceTier {
  Price: string | null;
  Quantity: number | null;
}

export interface IProductDetailsProp {  
  OrderProductAttributeValue: ICustomAttribute[];
  PublishProductId: number;
  Name: string;
  SKU: string;
  OriginalImagepath: string;
  RetailPrice: number;
  SalesPrice: number;
  Price: string;
  Attributes: IProductAttribute[];
  TierPriceList: IPriceTier[];
  Quantity: number | null;
  IsConfigurableProduct: boolean;
  ConfigurableProductSKU: string;
  CurrencySuffix: string;
  VersionId: number;
  ImageThumbNailPath: string;
  ConfigurableAttribute: IConfigurableAttribute[];
  configurableAttributes: IProductDetailsProp[];
  ConfigurableProductId: number;
  ParentConfiguarableProductName: string;
  ParentProductName:string;
  ParentProductId:number;
  ParentProductImageSmallPath:string;
}

export interface IProductVariant {
  ZnodeProductId: number;
  GroupingCode: string;
  IsAddOn: boolean;
  ParentDetail: string;
  Customization: string;
  Quantity: number | null;
  Price: string | undefined;
  ProductNote: string;
  Attributes: IProductAttribute[];
  NAAttribute: ICustomAttribute[];
  ParentProductId: number|undefined;  
}

export interface IAddProductProp {
  OrderId: string | undefined;
  VersionId: number;
  ProductVariantDetails: IProductVariant[];
  UserId: string;
  OrderProductId: string;
  OrderProductAttributeValueId?: string | null;
  OmsOrderStateId?: number;
  ConfigurableProductSKU: string;
  SKU: string;
}

export interface IDictionary<T> {
  [Key: string]: T;
}

export interface ISearchRequest {
  CatalogId: number;
  Category: string | null | undefined;
  CategoryId: number | undefined;
  IsFacetList: boolean;
  LocaleId: number;
  PageNumber: number;
  PageSize: number;
  PortalId: number;
  ProfileId: number;
  UseSuggestion: boolean;
  RefineBy: IDictionary<string[]>;
  Keyword: string | null;
  ColumnName: string;
  OrderType: string;
}

export interface IConfigurableProductModel {
  Codes: string;
  IsProductEdit: boolean;
  IsQuickView: boolean;
  IsQuote: boolean;
  LocaleId: number;
  ParentOmsSavedCartLineItemId: number | null;
  ParentProductId: number;
  ParentProductSKU: string;
  PortalId: number;
  PublishCatalogId: number;
  Sku: string;
  SelectedAttributes: IDictionary<string>;
  SelectedCode: string;
  SelectedValue: string;
  Values: string;
  IsNAAttributeAvailable: boolean;
}

export interface ICategory {
  PublishCategoryId: number;
  Name: string;
}

export interface IOrderEditProduct {
  OrderId: string | undefined;
  PublishProductId: number;
  ParentPublishProductId: number;
  PortalId: number;
  ZnodeCatalogId: number;
  LocaleId: number;
  Quantity: number;
  Price: number;
  OmsOrderStateId: number;
  OrderStateName: string;
  ProductNote: string | null;
  OrderProductId: string;
  ProductFlags: string;
  VersionId: number;
  ProductDetails: string;
  IsNAAttributeAvailable: boolean;
  parentProductId:number;
}

export interface IOrderProductCatalogProfile {
  ProfileId: number;
  CatalogId: number;
}

export interface IKeywordSearchRequest {
  Keyword: string | null;
  LocaleId: number;
  PortalId: number;
  CatalogId: number;
  PageSize: number;
}

export interface IQuickOrderParameter {
  SKUs: string;
}
export interface IOnClickProductParameter {
  CatalogName: string;
  ConfigurableProductSKU: string;
  ConfigurableProductId: number;
  SKU: string;
  SalesPrice: number;
  RetailPrice: number;
  PublishProductId: number;
}
export interface ICustomAttribute {
  AttributeCode: string;
  AttributeValues: string;
  
}

// create an new iterface NaImplementation

export interface IOrderProductDetails {
  OrderProduct: IOrderProduct[];
}
export interface IOrderProduct {
  ParentProductId?:number;
  OrderProductId: string;
  OrderId: string;
  ClassId: number;
  SKU: string;
  ProductName: string;
  GroupingCode: string;
  IsAddOn: boolean;
  ParentDetail: string;
  Customization: string;
  Quantity: number;
  OmsOrderStateId: number;
  OmsPaymentStateId: number;
  CreatedBy: number;
  CreatedDate: string;
  ModifiedBy: number;
  ModifiedDate: string;
  IsPriceUpdated: boolean;
  VersionId: number;
  ZnodeCatalogId: number;
  ZnodeProductId: number;
  OrderProductNote: IOrderProductNote[];
  OrderProductAttributeValue: IOrderProductAttributeValue[];
  ParentOrderProductAttributeValue: IParentOrderProductAttributeValue[];
  OrderStateName: string;
  PaymentStateName: string;
}

export interface IOrderProductNote {
  OrderNoteId: string;
  MappingId: string;
  TypeOfMapping: string;
  Note: string;
  CreatedBy: number;
  CreatedDate: string;
  ModifiedBy: number;
  ModifiedDate: string;
}

export interface IOrderProductAttributeValue {
  OrderProductAttributeValueId: string;
  OrderProductId: string;
  OrderId: string;
  ClassId: number;
  AttributeCode: string;
  AttributeValue: string;
  CreatedBy: number;
  CreatedDate: string;
  ModifiedBy: number;
  ModifiedDate: string;
}

export interface IParentOrderProductAttributeValue {
  OrderParentProductAttributeValueId: string;
  OrderProductId: string;
  OrderId: string;
  ClassId: number;
  AttributeCode: string;
  AttributeValue: string;
  CreatedBy: number;
  CreatedDate: string;
  ModifiedBy: number;
  ModifiedDate: string;
}
