/* eslint-disable no-unused-vars */
/* eslint-disable max-len */
import { Dispatch, SetStateAction } from "react";
import { IColumn, IData } from "./IList";
import { ICalculate } from "../APIInterface/ICalculate";

export interface OrderSummaryHeaderProps {
  orderDetails: IOrder;
  orderStatusList: OrderStatusListProps[];
  setOrder: Dispatch<SetStateAction<IOrder>>;
  orderTotal?: number;
  notesChildRef: () => void;
}

export interface productDataProps {
  key: string;
  image: string;
  productName: string;
  sku: string;
  flags: string;
  status: string;
  shipTo: string;
  quantity: string | undefined;
  price: string;
  shipping: string;
  total: string;
}

export interface IOrder {
  MappingId: string;
  TypeOfMapping : string;
  OrderId: string;
  ClassId: number;
  ClassNumber: string;
  OmsOrderStateId: number;
  OmsPaymentStateId: number;
  OmsCookieMappingId: number;
  UserId: number;
  BillingAddressId: string;
  OrderDetail: string;
  AccountId: number;
  PortalId: number;
  OrderType: string;
  OrderOrigin: string;
  ProductionDate?: string;
  OrderDate?: string;
  OrderStateName: string;
  OrderPaymentState: string;
  UserName: string;
  StoreName: string;
  OrderTotal: string;
  AccountName: string;
  FullName: string;
  CreatedBy: number;
  CreatedByFullName: string;
  CreatedDate: string;
  ModifiedBy: number;
  ModifiedByFullName: string;
  ModifiedDate: string;
  AssignTo: number;
  AssignToFullName: string;
  AssignToName: string;
  FinalizedDate?: string;
  OrderTypeName: string;
  LocaleId: number;
  ShipDate?: string;
  OrderPermission: string;
}

export interface IUpdateOrder {
  OrderId: string;
  UserId?: number | string;
  AccountId?: number;
  PortalId?: number;
  OrderTypeCode?: string;
  ClassCode?: string;
  OrderOrigin?: string;
  OmsOrderStateId?: number;
  IsOrderFinalized?: boolean;
  IsSetOrderLineItem?: boolean;
  IsSendEmail?: boolean;
  IsOrderTypeChanged?: boolean;
  IsAccountTypeChanged?: boolean;
  IsAssignedUserChanged?: boolean;
  AssignTo?:number;
}

export interface OrderSummaryContentProps {
  orderDetails: IOrder;
  orderData: IOrderData;
  setOrderData: Dispatch<SetStateAction<IOrderData>>;
  editOrderError: IEditOrderError;
  setEditOrderError: Dispatch<SetStateAction<IEditOrderError>>;
  orderCalculation: ICalculate;
  getOrderDetailsWithFlag: () => void;
  initialOrderTypeCode: string;
  initialAccountId: number;
  initialAssignedUserId: number;
}

export interface IOrderData {
  storeId: number;
  storeName: string;
  accountId: number;
  accountName: string;
  userId: number;
  userName: string;
  orderTypeCode: string;
  orderTypeName?: string;
  orderTypeId?: number;
  isOrderTypeChanged?: boolean;
  isAccountTypeChanged?: boolean;
  isAssignedUserChanged?: boolean;
}

export interface OrderStatusListProps {
  IsCPRequireCompleteness: boolean;
  OrderStateName: string;
  OmsOrderStateId: string;
  CPBackColor: string;
  CPTextColor: string;
  IsEdit?: boolean;
  OrderProductId?: string;
  SKU?: string;
  IsPriceUpdated?:boolean
}

export interface notesListItemProps {
  date: string;
  time: string;
  createdBy: string;
  noteDetails: string;
}

export interface IOrderFlags {
  key: number;
  grpName: string;
}

export interface IOrderFlagsHeaderProps {
  setIsModalVisible: Dispatch<SetStateAction<boolean>>;
}

//TODO : Need to Map proper parameter as per the API responce

export interface IColumnProps {
  title: string;
  dataIndex: string;
  key: string;
  // eslint-disable-next-line @typescript-eslint/no-explicit-any
  sorter?: any;
  hidden?: boolean;
}

export interface OrderListingProps {
  data: IData[];
  columns: IColumn[];
}

export interface IOrderNotesParams {
  orderId: string;
  classId: number;
  userId: number;
  note: string;
}

export interface IProductList {
  OrderId?: string;
  OrderProductId?: string;
  ProductImage?: string;
  ProductName?: string;
  SKU?: string;
  FlagsStatus?: string;
  Flags?: string;
  Status?: string;
  Quantity?: string;
  Price?: string;
  Total?: string;
  OrderStateName?: string;
  OmsOrderStateId?: string;
  IsPriceUpdated?: boolean;
  IsDeleteAll?: boolean;
  OrderProductAttributeValue?: IOrderProductAttributeValue[];
  OrderFlag?: IOrderFlagList[];
  onChangePrice?: string;
  onChangeQuantity?: string;
  ProductNote?: string;
  IsNAAttributeAvailable? : boolean;
  SkuStatus?: boolean;
  ZnodeCatalogId? :number;  
  LocaleId?:number;
}

export interface IIsPriceResetProductList{
  SKU?:string,
  Quantity?:string;
  Price?:string;
  OrderId?:string;
  orderProductId?:number;
  SkuQuantityDetails?:ISKUQTY[]
}

export interface ISKUQTY {
  SKU:string;
  Quantity?:string;
} 

export interface IStausListOnProductLevel {
  orderStatusList: OrderStatusListProps[];
}

export interface IOrderProductAttributeValue {
  AttributeCode: string;
  AttributeValue: string;
  IsConfigurable?: boolean;
  Color: string;
  Size:string;
  IsNAAttributeAvailable:boolean;
}

export interface IOrderFlagList {
  IsChecked?: boolean;
  IsActiveOverridden?: boolean;
  OrderFlagId: string;
}

export interface IProductListHeader {
  IsExpandable: boolean;
  setIsExpandable: Dispatch<SetStateAction<boolean>>;
  // eslint-disable-next-line no-unused-vars
  ProductToolshandler: (action: string) => void;
  setIsQuickAddModalVisible: Dispatch<SetStateAction<boolean>>;
  productList: IProductList[];
}

export interface IOrderSummaryProp {
  orderSummary: IOrder;
}

export interface IActionButtonList {
  ButtonId: number;
  ButtonText: string;
  PermissionCode?: string;
  TypeOfPermission?: string;
  DisplayOrder?: number;
  IsClassButton?: boolean;
}

export interface IActionButton {
  ButtonId: number;
  ButtonText: string;
  OmsOrderStateId: number;
}

export interface IOrderStatus {
  OmsOrderStateId: number;
  OrderStateName: string;
  IsCPTriggerFulfilledData: boolean;
  IsCPRequireCompleteness: boolean;
  IsEdit: boolean;
  IsOrderLineItemState: boolean;
  IsSendEmail: boolean;
}

export interface IProductListProps {
  orderStatusList: OrderStatusListProps[];
  productList: IProductList[];
  setProductList: Dispatch<SetStateAction<IProductList[]>>;
  calculateOrder: () => void;
  isCalledByEditOrder: boolean;
  setIsCalledByEditOrder: Dispatch<SetStateAction<boolean>>;
  handleLineItemsValidationOnStatusChange: (
    // eslint-disable-next-line no-unused-vars
    omsOrderStateId: number,
    // eslint-disable-next-line no-unused-vars
    orderId: string,
    // eslint-disable-next-line no-unused-vars
    orderProductId: string
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
  ) => any;
  // eslint-disable-next-line no-unused-vars
  showValidationMessages: (result: string[]) => void;
  getOrderDetails: () => void;
}
export interface IProductSetLineItems {
  orderId: string;
  lineItemIds: string;
}

export interface ICompleteOrder {
  OrderId: string;
  PaymentData: string;
  ProductDetail: string;
  OrderStateId: number;
  IsFinalized: boolean;
}
export interface IorderStatusSendEmail {
  OmsOrderStateId: number;
  StatusCode: string;
  OrderStateName: string;
  IsShowToCustomer: boolean;
  IsSendEmail: boolean;
  IsCPRequireCompleteness: boolean;
  IsAccountStatus: boolean;
}

export interface IEditOrderPermissions {
  IsDelete?: boolean;
  IsEdit?: boolean;
  IsView?: boolean;
  allowEditing?: boolean;
  IsDelegatedToMe?: boolean;
}

export interface IEditOrderError {
  userError: string;
  orderTypeError: string;
}

export interface ISkuStatusList{
  Sku: string,
  Status: boolean
}