/* eslint-disable no-unused-vars */
import { Dispatch, SetStateAction } from "react";
import { IColumnProps, IOrder } from "./IEditOrder";
import { IUsersListItem } from "interfaces/APIInterface/IAssignTo";

export interface IOrderList {
  orderNumber: string;
  account: string;
  customer: string;
  status: string;
  created: string;
  time: string;
  total: string;
  type?: string;
}

export interface collapseItem {
  key: string;
  title: string | React.ReactNode;
  classSelector: string;
  content: string;
}

export interface filters {
  orderTools: string;
  orderType?: string;
  storeName?: number;
  userGroup?: number;
  selectedView: number;
  selectedOrderTypeClass: string;
  selectedStoreClass: string;
}
export interface priorityView {
  priority?: number;
  ViewId?: number;
  viewName?: string;
}

export interface OrderFiltersProps {
  filters: filters;
  // eslint-disable-next-line @typescript-eslint/no-explicit-any
  setFilters: Dispatch<SetStateAction<any>>;
  storeList: StoreListProps[];
  userGroupList: IUserGroupListProps[];
  savedView: ISavedViewListProps[];
  // eslint-disable-next-line @typescript-eslint/no-explicit-any
  setSavedView: Dispatch<SetStateAction<any>>;
  manageFilter?: (data: IFilterItemProps[]) => void;
  manageSavedView?: (data: ISavedViewItemProps) => void;
  manageGetView?: (viewId: number) => void;
  setOrderListParams: Dispatch<SetStateAction<IOrderListData>>;
  priorityView: priorityView[];
  setPriorityView: Dispatch<SetStateAction<priorityView[]>>;
  checkedSaveView: number[];
  setCheckedSavedView: Dispatch<SetStateAction<number[]>>;
  selectedSaveView: number;
  filterValue: IFilterItemProps[];
  setFilterValue: Dispatch<SetStateAction<IFilterItemProps[]>>;
  setAppliedFilters: Dispatch<SetStateAction<IFilterItemProps[]>>;
  setSelectedRowKeys: Dispatch<SetStateAction<React.Key[]>>;
  shareWithUserGroup: boolean;
  setShareWithUserGroup: Dispatch<SetStateAction<boolean>>;
  shareWithEveryone: boolean;
  setShareWithEveryone: Dispatch<SetStateAction<boolean>>;
  isFilterClear: boolean;
  setViewRedirection: Dispatch<SetStateAction<boolean>>;
  setCurrentPage: Dispatch<SetStateAction<number>>;
  isAppliedSearchOrFilters: boolean;
  setIsAppliedSearchOrFilters: Dispatch<SetStateAction<boolean>>;
}

export interface StoreListProps {
  Id: number;
  Name: string;
}
export interface ISavedViewListProps {
  ViewId: number;
  ViewName: string;
  UserGroupId?: number;
  IsPublic: boolean;
}
export interface IUserGroupListProps {
  CPUserGroupId: number;
  GroupName: string;
}

export interface FiltersProps {
  setOpenFilter: Dispatch<SetStateAction<boolean>>;
  manageFilter?: (data: IFilterItemProps[]) => void;
  filterValue: IFilterItemProps[];
  setFilterValue: Dispatch<SetStateAction<IFilterItemProps[]>>;
  setOrderListParams: Dispatch<SetStateAction<IOrderListData>>;
  setAppliedFilters: Dispatch<SetStateAction<IFilterItemProps[]>>;
  appliedFilters: IFilterItemProps[];
  filterColumnListData: IColumnProps[];
  setFilterColumnListData: Dispatch<SetStateAction<IColumnProps[]>>;
  isFilterClear: boolean;
  setIsFilterClear: Dispatch<SetStateAction<boolean>>;
  clickedAppliedFilter?:string
}

export interface IFilterItemProps {
  FilterName: string;
  FilterOperator: string;
  FilterValue: string;
}

export interface OrderActionFiltersProps {
  columnsList: IColumnProps[];
  setColumnsList: Dispatch<SetStateAction<IColumnProps[]>>;
  manageFilter?: (data: IFilterItemProps[]) => void;

  toolsClickHandler: (toolsActions: string) => void;
  assignToMyTeamModal: boolean;
  setAssignToMyTeamModal: Dispatch<SetStateAction<boolean>>;
  refetchList: () => void;
  myTeam: IUsersListItem[];
  selectedRowKeys: React.Key[];
  setSelectedRowKeys: Dispatch<SetStateAction<React.Key[]>>;
  activeAccordionKey: string | string[];

  filters: filters;
  filterValue: IFilterItemProps[];
  setFilterValue: Dispatch<SetStateAction<IFilterItemProps[]>>;
  setOrderListParams: Dispatch<SetStateAction<IOrderListData>>;
  appliedFilters: IFilterItemProps[];
  setAppliedFilters: Dispatch<SetStateAction<IFilterItemProps[]>>;
  filterColumnListData: IColumnProps[];
  setFilterColumnListData: Dispatch<SetStateAction<IColumnProps[]>>;
  isFilterClear: boolean;
  setIsFilterClear: Dispatch<SetStateAction<boolean>>;
  clickedAppliedFilter:string;
  setClickedAppliedFilter: Dispatch<SetStateAction<string>>;
}

export interface SavedViewPopupProps {
  openSavedViewModal: boolean;
  setOpenSavedViewModal: Dispatch<SetStateAction<boolean>>;
  manageSavedView?: (data: ISavedViewItemProps) => void;
  manageGetView?: (viewId: number) => void;
  userGroupList: IUserGroupListProps[];
  savedView: ISavedViewListProps[];
  filters: filters;
  // eslint-disable-next-line @typescript-eslint/no-explicit-any
  setFilters: Dispatch<SetStateAction<any>>;
  // eslint-disable-next-line @typescript-eslint/no-explicit-any
  setSavedView: Dispatch<SetStateAction<any>>;
  priorityView: priorityView[];
  setPriorityView: Dispatch<SetStateAction<priorityView[]>>;
  checkedSaveView: number[];
  setCheckedSavedView: Dispatch<SetStateAction<number[]>>;
  selectedSaveView: number;
  shareWithUserGroup: boolean;
  setShareWithUserGroup: Dispatch<SetStateAction<boolean>>;
  shareWithEveryone: boolean;
  setShareWithEveryone: Dispatch<SetStateAction<boolean>>;
}
export interface ISavedViewItemProps {
  shareWithUserGroup: boolean;
  shareWithEveryone: boolean;
  userGroup: number;
  newViewName: string;
  viewId: number;
  type: string;
  isDefault: boolean;
  viewPriority: number;
}
export interface IOrderListData {
  category: string;
  portalId: number;
  globalSearch: string;
  classNumber: string;
  account: string;
  userFullName: string;
  orderStateName: string;
  orderTotal: string;
  operatorClassNumber: string;
  operatorAccountName: string;
  operatorUserName: string;
  operatorOrderStateName: string;
  operatorOrderTotal: string;
  assignToFullName: string;
  operatorAssignToFullName: string;
  operatormodifiedDate: string;
  modifiedDate: string;
  operatorcreatedDate: string;
  createdDate: string;
  columnSorting: string;
}
export interface ISavedViewList {
  viewName: string;
  xmlSetting: string;
  xmlSettingName: string;
  IsPublic: boolean;
  viewId: number;
  isDefault: boolean;
  userId: string;
  viewPriority: number;
  sortColumn: string;
  sortType: string;
  Filters?: IFilterItemProps[];
  filterCategory?:string
}
export interface IDeleteSavedView {
  ids: number;
}

export interface IDuplicateOrder {
  visible: boolean;
  orderId: string;
}

export interface IDuplicateLineItem {
  visible: boolean;
  OrderProductId: string;
}

export interface IOpenPriceNote {
  visible: boolean;
  OrderProductId: string;
  index: number;
  notes?: string
}

export interface IAddRowProps {
  column: string;
  filterType: string;
  value: string;
}
export interface ICreateMappingSavedView {
  listViewId: number;
  userGroupId: number;
}
export interface IUpdateViewPriorityList {
  viewName: string;
  userId: string;
  viewPriority: number;
  viewId: number;
  xmlSettingName: string;
}
export interface IMultipleShareSavedView {
  listViewIds: string | null;
  userGroupId: number;
}
export interface IMultipleShareViewForEveryOne {
  listViewIds: string | null;
  isPublic: boolean;
  xmlSettingName: string;
}
export interface IFilterTypes {
  label: string;
  value: string;
}
