/* eslint-disable no-unused-vars */
import { IOrder } from "interfaces/ClientInterface/IEditOrder";
import {
  ICategory,
  IConfigurableAttribute,
  ICustomAttribute,
  IOrderProductCatalogProfile,
  IProduct,
  IProductDetailsProp,
  IProductFacet,
} from "interfaces/APIInterface/IProducts";
import { Dispatch, SetStateAction } from "react";

export interface IProductsImage {
  imageWidth: string;
  imageHeight: string;
  isPreview: boolean;
  className: string;
  imageUrl: string;
  alt?: string;
}

export interface IProductsTitle {
  titleClass?: string;
  titleText: string;
  textFontLevel: 1 | 5 | 2 | 3 | 4;
}

export interface ISku {
  productSku: string;
  labelClass?: string;
}

export interface IProductDescription {
  descClass?: string;
  descriptionData: string;
}

export interface IProductPrice {
  priceClass?: string;
  currency: string;
  price: string;
  priceFontLevel: 1 | 5 | 2 | 3 | 4;
  inStockQuantity: number | null;
  IsNAAttributeAvailable:boolean;
  showStock:boolean;
}

export interface IAddProductFilterProp {
  facets: IProductFacet[];
  categoryListData: ISelectInputOption[];
  searchKeyword: string | null;
  order: IOrder;
  orderProductCatalogProfileData: IOrderProductCatalogProfile;
  setProductFacets: Dispatch<SetStateAction<IProductFacet[]>>;
  setCategory: Dispatch<SetStateAction<ICategory>>;
  onFilterApplied: (clearProductFilter? : boolean | false) => void;
  fetchProductList: (
    selectedCategory: ICategory,
    orderData: IOrder,
    orderProductCatalogProfileDetails: IOrderProductCatalogProfile,
    page: number,
    pageSize: number,
    columnName: string,
    orderType: string,
    clearProductFilter?: boolean | false,
  ) => void;
  setSearchKeyword: Dispatch<SetStateAction<string | null>>;
  currentPageSize: number;
  sortingColumnForProductFilter: { sortByColumnNameFilter: string; sortTypeFilter: string };
  setSortingColumnForProductFilter: Dispatch<{
    sortByColumnNameFilter: string;
    sortTypeFilter: string;
  }>;
  handleSort: (columnName: string, orderType: string) => void;
  setCurrentPage: Dispatch<number>;
  isProductFilter: boolean | false;
}

export interface IProductListTableProps {
  productListData: IProduct[];
  // eslint-disable-next-line no-unused-vars
  onProductClick: (row: IProduct) => void;
  totalProductCount: number;
  currentPage: number;
  setCurrentPage: Dispatch<number>;
  currentPageSize: number;
  setCurrentPageSize: Dispatch<number>;
  onPaginationChange: (page: number, pageSize: number) => void;
  sortingColumn: { sortByColumnName: string; sortType: string };
  setSortingColumn: Dispatch<{ sortByColumnName: string; sortType: string }>;
  handleSort: (columnName: string, orderType: string) => void;
}

export interface IConfigurableAttributeProp {
  configurableAttributes: IConfigurableAttribute[];
  setProduct: Dispatch<SetStateAction<IProductDetailsProp>>;
  selectedVariant: ISelectedVariant;
  setSelectedVariant: Dispatch<SetStateAction<ISelectedVariant>>;
  configurableProductModel: IConfigurableProductRequestModel;
  variant:string[];
  index:number;
  selectCustomAttribute:ICustomAttribute[];
  setCustomatrribute :Dispatch<SetStateAction<ICustomAttribute[]>>;
  setshowStock:Dispatch<SetStateAction<boolean>>;
  ParentProductImage:string;
}

export interface ISetProductProp {
  product: IProductDetailsProp;
  orderId: string | undefined;
  quantity: number | null;
  productNote: string;
  selectedVariant: ISelectedVariant;
  configurableProductModel: IConfigurableProductRequestModel;
  setProduct: Dispatch<SetStateAction<IProductDetailsProp>>;
  setIsProductAdded: Dispatch<SetStateAction<boolean>>;
  setQuantity: Dispatch<SetStateAction<number | null>>;
  setProductNote: Dispatch<SetStateAction<string>>;
  setSelectedVariant: Dispatch<SetStateAction<ISelectedVariant>>;
  editQuantity: number | null;
  setEditQuantity: Dispatch<SetStateAction<number | null>>;
  variant: string[];
  selectCustomAttribute:ICustomAttribute[];
  setCustomatrribute :Dispatch<SetStateAction<ICustomAttribute[]>>;
  showStock:boolean;  
  setshowStock:Dispatch<SetStateAction<boolean>>;
  ParentProductImage:string;
}

export interface ICollapseItem {
  key: string;
  title: string | React.ReactNode;
  content: string;
  classSelector: string;
}

export interface IDrawerProp {
  setOpenDrawer: Dispatch<SetStateAction<boolean>>;
  setProductFacets: Dispatch<SetStateAction<IProductFacet[]>>;
  onFilterApplied: (clearProductFilter : boolean | false) => void;
  facets: IProductFacet[];
  isProductFilter: boolean | false;
  facetsBeforeUpdate: IProductFacet[];
}

export interface ISpaceProps {
  spaceDirection?: "vertical" | "horizontal" | undefined;
  size?: "small" | "middle" | "large" | number;
  className?: string;
  quantity: number | null;
  setQuantity: Dispatch<SetStateAction<number | null>>;
  editQuantity: number | null;
  setEditQuantity: Dispatch<SetStateAction<number | null>>;
}

export interface IProductStatus {
  productStatus: string;
  errorText: string;
}

export interface IProductDescriptionProp {
  productSpecificationData: ICollapseItem[];
}

export interface IPriceTierProp {
  productQuantityTierColumn: IRowQuantityColumnItem[];
  productPriceTierColumn: IRowPriceColumnItem;
}

/**
 * The property names for this interface is following the camelCase naming convention
 * as this is directly mapped to the in-build library
 * which is using camelCase naming convention properties.
 */
export interface IRowQuantityColumnItem {
  title: string | number;
  dataIndex: string;
  key: string;
}

export interface IRowPriceColumnItem {
  [key: string]: unknown;
}

export interface ISelectedVariant {
  defaultVariant: string[];
}

export interface ISelectInputOption {
  label: string;
  value: string;
}

export interface ISelectInputOptionWithOrderBy {
  label: string;
  value: string;
  sortByColumnNameFilter: string;
  sortTypeFilter: string;
}

export interface IOrderIdProp {
  orderId: string | undefined;
}

export interface IProductNoteProp {
  productNote: string;
  setProductNote: Dispatch<SetStateAction<string>>;
}

export interface IOrderSummaryEditProductProp {
  orderSummary: IOrder;
  // eslint-disable-next-line no-unused-vars
  onUpdateOrderProduct: (isSaveAndClose: boolean) => void;
}

export interface IConfigurableProductRequestModel {
  localeId: number;
  parentProductId: number;
  parentProductSKU: string;
  portalId: number;
  publishCatalogId: number;
  sku: string;
  ParentProductName : string;
}

export interface IConfigurableProductVarientNAModel {
  
  AttributeName?: string;
  AttributeValues?:string[];
  AttributeCode?:string;
}
