const REGEX = {
  validUsernameRegex:
    // eslint-disable-next-line max-len, no-useless-escape
    /^(([^<>()[\]\.,;:\s@\"]+(\.[^<>()[\]\.,;:\s@\"]+)*)|(\".+\"))@(([^<>()[\]\.,;:\s@\"]+\.)+[^<>()[\]\.,;:\s@\"]{2,})$/i,
  passwordStrengthRegex: /^(?=.*[0-9])(?=.*[a-zA-Z]).{8,}$/i,
  validPostalCodeRegex: /^[0-9-]*$/i,
  validAlphabetRegex: /^[a-zA-Z]+$/i,
  validEmailAddressRegex: /^[A-Za-z0-9._%+-]+@[A-Za-z0-9.-]+\.[A-Za-z]{2,}$/i,
  validPhoneNumberRegex: /^[0-9+-]*$/i,
};

export const isUsernameValid = (username: string) => {
  return username && REGEX.validUsernameRegex.test(username);
};

export const isPasswordStrength = (password: string) => {
  return password && REGEX.passwordStrengthRegex.test(password);
};

export const isPasswordMatched = (newPassword: string, confirmPassword: string) => {
  return newPassword === confirmPassword;
};

export const isPostalCodeValid = (postalCode: string) => {
  return postalCode && REGEX.validPostalCodeRegex.test(postalCode);
};

export const isValidAlphabetsOnly = REGEX.validAlphabetRegex;

export const isValidEmailAddress = REGEX.validEmailAddressRegex;

export const isValidPhoneNumber = REGEX.validPhoneNumberRegex;
